
module Make

# 55 "asllib/Parser.mly"
          (Config : ParserConfig.CONFIG)
# 7 "asllib/Parser.ml"

= struct
  
  module MenhirBasics = struct
    
    exception Error
    
    let _eRR =
      fun _s ->
        raise Error
    
    type token = Tokens.token
    
  end
  
  include MenhirBasics
  
# 63 "asllib/Parser.mly"
  

open AST
open ASTUtils
open Desugar

let version = V1
let t_bit ~loc = T_Bits (E_Literal (L_Int Z.one) |> add_pos_from loc, [])
let zero ~loc = E_Literal (L_Int Z.zero) |> add_pos_from loc

let make_ldi_vars (xs, ty) =
  let make_one x =
    S_Decl (LDK_Var, LDI_Var x.desc, Some ty, None) |> add_pos_from x
  in
  List.map make_one xs |> stmt_from_list |> desc

let make_ty_decl_subtype (x, s) =
  let name, _fields = s.desc in
  let ty = ASTUtils.add_pos_from s (T_Named name) in
  D_TypeDecl (x, ty, Some s.desc)

let prec =
  let open AST in
  function
  | `BOR | `BAND | `IMPL | `BEQ -> 1
  | `EQ_OP | `NEQ -> 2
  | `PLUS | `MINUS | `OR | `XOR | `AND | `CONCAT -> 3
  | `MUL | `DIV | `DIVRM | `RDIV | `MOD | `SHL | `SHR -> 4
  | `POW -> 5
  | `GT | `GEQ | `LT | `LEQ -> 0 (* Non assoc *)

let check_not_same_prec loc op op' =
  if prec op = prec op' then Error.(fatal_from loc CannotParse)

let check_not_binop_same_prec op e =
  match e.desc with
  | E_Binop (op', _, _) when op != op' -> check_not_same_prec e op op'
  | _ -> ()

let e_binop (e1, op, e2) =
  let () = check_not_binop_same_prec op e1
  and () = check_not_binop_same_prec op e2
  in
  E_Binop (op, e1, e2)

let e_call call = E_Call { call with call_type = ST_Function }
let s_call call = S_Call { call with call_type = ST_Procedure }

let le_var x = LE_Var x.desc |> add_pos_from x


# 77 "asllib/Parser.ml"
  
  type ('s, 'r) _menhir_state = 
    | MenhirState000 : ('s, _menhir_box_opn) _menhir_state
      (** State 000.
        Stack shape : .
        Start symbol: opn. *)

    | MenhirState001 : (('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_state
      (** State 001.
        Stack shape : WHILE.
        Start symbol: <undetermined>. *)

    | MenhirState004 : (('s, 'r) _menhir_cell1_NOT, 'r) _menhir_state
      (** State 004.
        Stack shape : NOT.
        Start symbol: <undetermined>. *)

    | MenhirState005 : (('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 005.
        Stack shape : MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState006 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 006.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState008 : (('s, 'r) _menhir_cell1_IF, 'r) _menhir_state
      (** State 008.
        Stack shape : IF.
        Start symbol: <undetermined>. *)

    | MenhirState009 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 009.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState010 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 010.
        Stack shape : IDENTIFIER LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState012 : (('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_state
      (** State 012.
        Stack shape : BNOT.
        Start symbol: <undetermined>. *)

    | MenhirState015 : (('s, 'r) _menhir_cell1_ARBITRARY _menhir_cell0_COLON, 'r) _menhir_state
      (** State 015.
        Stack shape : ARBITRARY COLON.
        Start symbol: <undetermined>. *)

    | MenhirState018 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 018.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState019 : (('s, 'r) _menhir_cell1_INTEGER, 'r) _menhir_state
      (** State 019.
        Stack shape : INTEGER.
        Start symbol: <undetermined>. *)

    | MenhirState020 : (('s, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 020.
        Stack shape : LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState022 : ((('s, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 022.
        Stack shape : LBRACE MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState025 : ((('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 025.
        Stack shape : MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState026 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_state
      (** State 026.
        Stack shape : expr LLBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState027 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 027.
        Stack shape : expr LLBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState028 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_XOR, 'r) _menhir_state
      (** State 028.
        Stack shape : expr XOR.
        Start symbol: <undetermined>. *)

    | MenhirState029 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_XOR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 029.
        Stack shape : expr XOR expr.
        Start symbol: <undetermined>. *)

    | MenhirState030 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHR, 'r) _menhir_state
      (** State 030.
        Stack shape : expr SHR.
        Start symbol: <undetermined>. *)

    | MenhirState031 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 031.
        Stack shape : expr SHR expr.
        Start symbol: <undetermined>. *)

    | MenhirState032 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_POW, 'r) _menhir_state
      (** State 032.
        Stack shape : expr POW.
        Start symbol: <undetermined>. *)

    | MenhirState033 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_POW, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 033.
        Stack shape : expr POW expr.
        Start symbol: <undetermined>. *)

    | MenhirState034 : (('s, 'r) _menhir_cell1_LBRACKET, 'r) _menhir_state
      (** State 034.
        Stack shape : LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState035 : (('s, 'r) _menhir_cell1_COLON, 'r) _menhir_state
      (** State 035.
        Stack shape : COLON.
        Start symbol: <undetermined>. *)

    | MenhirState036 : ((('s, 'r) _menhir_cell1_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 036.
        Stack shape : COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState037 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHL, 'r) _menhir_state
      (** State 037.
        Stack shape : expr SHL.
        Start symbol: <undetermined>. *)

    | MenhirState038 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 038.
        Stack shape : expr SHL expr.
        Start symbol: <undetermined>. *)

    | MenhirState039 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_IN, 'r) _menhir_state
      (** State 039.
        Stack shape : expr IN.
        Start symbol: <undetermined>. *)

    | MenhirState040 : (('s, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 040.
        Stack shape : LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState041 : (('s, 'r) _menhir_cell1_NOT, 'r) _menhir_state
      (** State 041.
        Stack shape : NOT.
        Start symbol: <undetermined>. *)

    | MenhirState042 : ((('s, 'r) _menhir_cell1_NOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 042.
        Stack shape : NOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState044 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_state
      (** State 044.
        Stack shape : expr DOT LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState046 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 046.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState053 : (('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 053.
        Stack shape : MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState054 : ((('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 054.
        Stack shape : MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState056 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 056.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState057 : (('s, 'r) _menhir_cell1_LEQ, 'r) _menhir_state
      (** State 057.
        Stack shape : LEQ.
        Start symbol: <undetermined>. *)

    | MenhirState058 : ((('s, 'r) _menhir_cell1_LEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 058.
        Stack shape : LEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState059 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RDIV, 'r) _menhir_state
      (** State 059.
        Stack shape : expr RDIV.
        Start symbol: <undetermined>. *)

    | MenhirState060 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RDIV, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 060.
        Stack shape : expr RDIV expr.
        Start symbol: <undetermined>. *)

    | MenhirState061 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS, 'r) _menhir_state
      (** State 061.
        Stack shape : expr PLUS.
        Start symbol: <undetermined>. *)

    | MenhirState062 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 062.
        Stack shape : expr PLUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState063 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MUL, 'r) _menhir_state
      (** State 063.
        Stack shape : expr MUL.
        Start symbol: <undetermined>. *)

    | MenhirState064 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MUL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 064.
        Stack shape : expr MUL expr.
        Start symbol: <undetermined>. *)

    | MenhirState065 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MOD, 'r) _menhir_state
      (** State 065.
        Stack shape : expr MOD.
        Start symbol: <undetermined>. *)

    | MenhirState066 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MOD, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 066.
        Stack shape : expr MOD expr.
        Start symbol: <undetermined>. *)

    | MenhirState067 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIVRM, 'r) _menhir_state
      (** State 067.
        Stack shape : expr DIVRM.
        Start symbol: <undetermined>. *)

    | MenhirState068 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIVRM, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 068.
        Stack shape : expr DIVRM expr.
        Start symbol: <undetermined>. *)

    | MenhirState069 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIV, 'r) _menhir_state
      (** State 069.
        Stack shape : expr DIV.
        Start symbol: <undetermined>. *)

    | MenhirState070 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIV, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 070.
        Stack shape : expr DIV expr.
        Start symbol: <undetermined>. *)

    | MenhirState071 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OR, 'r) _menhir_state
      (** State 071.
        Stack shape : expr OR.
        Start symbol: <undetermined>. *)

    | MenhirState072 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 072.
        Stack shape : expr OR expr.
        Start symbol: <undetermined>. *)

    | MenhirState073 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_NEQ, 'r) _menhir_state
      (** State 073.
        Stack shape : expr NEQ.
        Start symbol: <undetermined>. *)

    | MenhirState075 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_NEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 075.
        Stack shape : expr NEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState076 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 076.
        Stack shape : expr MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState077 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 077.
        Stack shape : expr MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState078 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LT, 'r) _menhir_state
      (** State 078.
        Stack shape : expr LT.
        Start symbol: <undetermined>. *)

    | MenhirState079 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 079.
        Stack shape : expr LT expr.
        Start symbol: <undetermined>. *)

    | MenhirState080 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON_COLON, 'r) _menhir_state
      (** State 080.
        Stack shape : expr COLON_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState081 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 081.
        Stack shape : expr COLON_COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState082 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_AND, 'r) _menhir_state
      (** State 082.
        Stack shape : expr AND.
        Start symbol: <undetermined>. *)

    | MenhirState083 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_AND, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 083.
        Stack shape : expr AND expr.
        Start symbol: <undetermined>. *)

    | MenhirState084 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LEQ, 'r) _menhir_state
      (** State 084.
        Stack shape : expr LEQ.
        Start symbol: <undetermined>. *)

    | MenhirState085 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 085.
        Stack shape : expr LEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState086 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GT, 'r) _menhir_state
      (** State 086.
        Stack shape : expr GT.
        Start symbol: <undetermined>. *)

    | MenhirState087 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 087.
        Stack shape : expr GT expr.
        Start symbol: <undetermined>. *)

    | MenhirState088 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GEQ, 'r) _menhir_state
      (** State 088.
        Stack shape : expr GEQ.
        Start symbol: <undetermined>. *)

    | MenhirState089 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 089.
        Stack shape : expr GEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState090 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_IMPL, 'r) _menhir_state
      (** State 090.
        Stack shape : expr IMPL.
        Start symbol: <undetermined>. *)

    | MenhirState091 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_IMPL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 091.
        Stack shape : expr IMPL expr.
        Start symbol: <undetermined>. *)

    | MenhirState092 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_EQ_OP, 'r) _menhir_state
      (** State 092.
        Stack shape : expr EQ_OP.
        Start symbol: <undetermined>. *)

    | MenhirState094 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_EQ_OP, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 094.
        Stack shape : expr EQ_OP expr.
        Start symbol: <undetermined>. *)

    | MenhirState095 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BOR, 'r) _menhir_state
      (** State 095.
        Stack shape : expr BOR.
        Start symbol: <undetermined>. *)

    | MenhirState096 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BOR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 096.
        Stack shape : expr BOR expr.
        Start symbol: <undetermined>. *)

    | MenhirState097 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BEQ, 'r) _menhir_state
      (** State 097.
        Stack shape : expr BEQ.
        Start symbol: <undetermined>. *)

    | MenhirState098 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 098.
        Stack shape : expr BEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState099 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BAND, 'r) _menhir_state
      (** State 099.
        Stack shape : expr BAND.
        Start symbol: <undetermined>. *)

    | MenhirState100 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BAND, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 100.
        Stack shape : expr BAND expr.
        Start symbol: <undetermined>. *)

    | MenhirState101 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_AS, 'r) _menhir_state
      (** State 101.
        Stack shape : expr AS.
        Start symbol: <undetermined>. *)

    | MenhirState105 : (('s, 'r) _menhir_cell1_BITS _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 105.
        Stack shape : BITS LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState106 : ((('s, 'r) _menhir_cell1_BITS _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 106.
        Stack shape : BITS LPAR expr.
        Start symbol: <undetermined>. *)

    | MenhirState107 : (((('s, 'r) _menhir_cell1_BITS _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RPAR, 'r) _menhir_state
      (** State 107.
        Stack shape : BITS LPAR expr RPAR.
        Start symbol: <undetermined>. *)

    | MenhirState108 : (('s, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 108.
        Stack shape : LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState113 : (('s, 'r) _menhir_cell1_slices _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 113.
        Stack shape : slices IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState114 : (('s, 'r) _menhir_cell1_COLON, 'r) _menhir_state
      (** State 114.
        Stack shape : COLON.
        Start symbol: <undetermined>. *)

    | MenhirState117 : (('s, 'r) _menhir_cell1_ARRAY, 'r) _menhir_state
      (** State 117.
        Stack shape : ARRAY.
        Start symbol: <undetermined>. *)

    | MenhirState118 : ((('s, 'r) _menhir_cell1_ARRAY, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 118.
        Stack shape : ARRAY expr.
        Start symbol: <undetermined>. *)

    | MenhirState120 : (((('s, 'r) _menhir_cell1_ARRAY, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RRBRACKET, 'r) _menhir_state
      (** State 120.
        Stack shape : ARRAY expr RRBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState126 : (('s, 'r) _menhir_cell1_bitfield, 'r) _menhir_state
      (** State 126.
        Stack shape : bitfield.
        Start symbol: <undetermined>. *)

    | MenhirState132 : (('s, 'r) _menhir_cell1_IF, 'r) _menhir_state
      (** State 132.
        Stack shape : IF.
        Start symbol: <undetermined>. *)

    | MenhirState133 : ((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 133.
        Stack shape : IF expr.
        Start symbol: <undetermined>. *)

    | MenhirState134 : (((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 134.
        Stack shape : IF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState135 : ((((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 135.
        Stack shape : IF expr THEN expr.
        Start symbol: <undetermined>. *)

    | MenhirState136 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_state
      (** State 136.
        Stack shape : expr THEN expr ELSIF.
        Start symbol: <undetermined>. *)

    | MenhirState137 : (((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 137.
        Stack shape : expr THEN expr ELSIF expr.
        Start symbol: <undetermined>. *)

    | MenhirState138 : ((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 138.
        Stack shape : expr THEN expr ELSIF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState139 : (((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 139.
        Stack shape : expr THEN expr ELSIF expr THEN expr.
        Start symbol: <undetermined>. *)

    | MenhirState140 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSE, 'r) _menhir_state
      (** State 140.
        Stack shape : expr THEN expr ELSE.
        Start symbol: <undetermined>. *)

    | MenhirState141 : (((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSE, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 141.
        Stack shape : expr THEN expr ELSE expr.
        Start symbol: <undetermined>. *)

    | MenhirState144 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 144.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState145 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 145.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState146 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 146.
        Stack shape : IDENTIFIER LBRACE MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState148 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 148.
        Stack shape : IDENTIFIER LBRACE IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState149 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 149.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState150 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 150.
        Stack shape : IDENTIFIER LBRACE MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState153 : (('s, 'r) _menhir_cell1_field_assign, 'r) _menhir_state
      (** State 153.
        Stack shape : field_assign.
        Start symbol: <undetermined>. *)

    | MenhirState154 : ((('s, 'r) _menhir_cell1_field_assign, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 154.
        Stack shape : field_assign IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState155 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_EQ, 'r) _menhir_state
      (** State 155.
        Stack shape : IDENTIFIER EQ.
        Start symbol: <undetermined>. *)

    | MenhirState156 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_EQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 156.
        Stack shape : IDENTIFIER EQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState158 : (('s, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 158.
        Stack shape : expr.
        Start symbol: <undetermined>. *)

    | MenhirState159 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 159.
        Stack shape : expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState165 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_clist1_expr_ _menhir_cell0_RBRACE _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 165.
        Stack shape : IDENTIFIER LBRACE clist1(expr) RBRACE LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState171 : (('s, 'r) _menhir_cell1_GEQ, 'r) _menhir_state
      (** State 171.
        Stack shape : GEQ.
        Start symbol: <undetermined>. *)

    | MenhirState172 : ((('s, 'r) _menhir_cell1_GEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 172.
        Stack shape : GEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState173 : (('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_state
      (** State 173.
        Stack shape : BNOT.
        Start symbol: <undetermined>. *)

    | MenhirState174 : ((('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 174.
        Stack shape : BNOT LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState176 : (('s, 'r) _menhir_cell1_ARBITRARY _menhir_cell0_COLON, 'r) _menhir_state
      (** State 176.
        Stack shape : ARBITRARY COLON.
        Start symbol: <undetermined>. *)

    | MenhirState183 : (('s, 'r) _menhir_cell1_pattern, 'r) _menhir_state
      (** State 183.
        Stack shape : pattern.
        Start symbol: <undetermined>. *)

    | MenhirState184 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 184.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState185 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_XOR, 'r) _menhir_state
      (** State 185.
        Stack shape : expr_pattern XOR.
        Start symbol: <undetermined>. *)

    | MenhirState186 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_XOR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 186.
        Stack shape : expr_pattern XOR expr.
        Start symbol: <undetermined>. *)

    | MenhirState187 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SLICING, 'r) _menhir_state
      (** State 187.
        Stack shape : expr_pattern SLICING.
        Start symbol: <undetermined>. *)

    | MenhirState188 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SLICING, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 188.
        Stack shape : expr_pattern SLICING expr.
        Start symbol: <undetermined>. *)

    | MenhirState189 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SHR, 'r) _menhir_state
      (** State 189.
        Stack shape : expr_pattern SHR.
        Start symbol: <undetermined>. *)

    | MenhirState190 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SHR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 190.
        Stack shape : expr_pattern SHR expr.
        Start symbol: <undetermined>. *)

    | MenhirState191 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SHL, 'r) _menhir_state
      (** State 191.
        Stack shape : expr_pattern SHL.
        Start symbol: <undetermined>. *)

    | MenhirState192 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_SHL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 192.
        Stack shape : expr_pattern SHL expr.
        Start symbol: <undetermined>. *)

    | MenhirState193 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_RDIV, 'r) _menhir_state
      (** State 193.
        Stack shape : expr_pattern RDIV.
        Start symbol: <undetermined>. *)

    | MenhirState194 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_RDIV, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 194.
        Stack shape : expr_pattern RDIV expr.
        Start symbol: <undetermined>. *)

    | MenhirState195 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_POW, 'r) _menhir_state
      (** State 195.
        Stack shape : expr_pattern POW.
        Start symbol: <undetermined>. *)

    | MenhirState196 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_POW, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 196.
        Stack shape : expr_pattern POW expr.
        Start symbol: <undetermined>. *)

    | MenhirState197 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_PLUS, 'r) _menhir_state
      (** State 197.
        Stack shape : expr_pattern PLUS.
        Start symbol: <undetermined>. *)

    | MenhirState198 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_PLUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 198.
        Stack shape : expr_pattern PLUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState199 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_OR, 'r) _menhir_state
      (** State 199.
        Stack shape : expr_pattern OR.
        Start symbol: <undetermined>. *)

    | MenhirState200 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_OR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 200.
        Stack shape : expr_pattern OR expr.
        Start symbol: <undetermined>. *)

    | MenhirState201 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_NEQ, 'r) _menhir_state
      (** State 201.
        Stack shape : expr_pattern NEQ.
        Start symbol: <undetermined>. *)

    | MenhirState203 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_NEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 203.
        Stack shape : expr_pattern NEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState204 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MUL, 'r) _menhir_state
      (** State 204.
        Stack shape : expr_pattern MUL.
        Start symbol: <undetermined>. *)

    | MenhirState205 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MUL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 205.
        Stack shape : expr_pattern MUL expr.
        Start symbol: <undetermined>. *)

    | MenhirState206 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MOD, 'r) _menhir_state
      (** State 206.
        Stack shape : expr_pattern MOD.
        Start symbol: <undetermined>. *)

    | MenhirState207 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MOD, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 207.
        Stack shape : expr_pattern MOD expr.
        Start symbol: <undetermined>. *)

    | MenhirState208 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 208.
        Stack shape : expr_pattern MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState209 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 209.
        Stack shape : expr_pattern MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState210 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LT, 'r) _menhir_state
      (** State 210.
        Stack shape : expr_pattern LT.
        Start symbol: <undetermined>. *)

    | MenhirState211 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 211.
        Stack shape : expr_pattern LT expr.
        Start symbol: <undetermined>. *)

    | MenhirState212 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_state
      (** State 212.
        Stack shape : expr_pattern LLBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState213 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 213.
        Stack shape : expr_pattern LLBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState215 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LEQ, 'r) _menhir_state
      (** State 215.
        Stack shape : expr_pattern LEQ.
        Start symbol: <undetermined>. *)

    | MenhirState216 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 216.
        Stack shape : expr_pattern LEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState217 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_IN, 'r) _menhir_state
      (** State 217.
        Stack shape : expr_pattern IN.
        Start symbol: <undetermined>. *)

    | MenhirState218 : ((('s, 'r) _menhir_cell1_IN, 'r) _menhir_cell1_BNOT, 'r) _menhir_state
      (** State 218.
        Stack shape : IN BNOT.
        Start symbol: <undetermined>. *)

    | MenhirState220 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_IMPL, 'r) _menhir_state
      (** State 220.
        Stack shape : expr_pattern IMPL.
        Start symbol: <undetermined>. *)

    | MenhirState221 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_IMPL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 221.
        Stack shape : expr_pattern IMPL expr.
        Start symbol: <undetermined>. *)

    | MenhirState222 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_GT, 'r) _menhir_state
      (** State 222.
        Stack shape : expr_pattern GT.
        Start symbol: <undetermined>. *)

    | MenhirState223 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_GT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 223.
        Stack shape : expr_pattern GT expr.
        Start symbol: <undetermined>. *)

    | MenhirState224 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_GEQ, 'r) _menhir_state
      (** State 224.
        Stack shape : expr_pattern GEQ.
        Start symbol: <undetermined>. *)

    | MenhirState225 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_GEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 225.
        Stack shape : expr_pattern GEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState226 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_EQ_OP, 'r) _menhir_state
      (** State 226.
        Stack shape : expr_pattern EQ_OP.
        Start symbol: <undetermined>. *)

    | MenhirState228 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_EQ_OP, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 228.
        Stack shape : expr_pattern EQ_OP expr.
        Start symbol: <undetermined>. *)

    | MenhirState230 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_state
      (** State 230.
        Stack shape : expr_pattern DOT LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState234 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_DIVRM, 'r) _menhir_state
      (** State 234.
        Stack shape : expr_pattern DIVRM.
        Start symbol: <undetermined>. *)

    | MenhirState235 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_DIVRM, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 235.
        Stack shape : expr_pattern DIVRM expr.
        Start symbol: <undetermined>. *)

    | MenhirState236 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_DIV, 'r) _menhir_state
      (** State 236.
        Stack shape : expr_pattern DIV.
        Start symbol: <undetermined>. *)

    | MenhirState237 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_DIV, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 237.
        Stack shape : expr_pattern DIV expr.
        Start symbol: <undetermined>. *)

    | MenhirState238 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_COLON_COLON, 'r) _menhir_state
      (** State 238.
        Stack shape : expr_pattern COLON_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState239 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_COLON_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 239.
        Stack shape : expr_pattern COLON_COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState240 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BOR, 'r) _menhir_state
      (** State 240.
        Stack shape : expr_pattern BOR.
        Start symbol: <undetermined>. *)

    | MenhirState241 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BOR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 241.
        Stack shape : expr_pattern BOR expr.
        Start symbol: <undetermined>. *)

    | MenhirState242 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BEQ, 'r) _menhir_state
      (** State 242.
        Stack shape : expr_pattern BEQ.
        Start symbol: <undetermined>. *)

    | MenhirState243 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 243.
        Stack shape : expr_pattern BEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState244 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BAND, 'r) _menhir_state
      (** State 244.
        Stack shape : expr_pattern BAND.
        Start symbol: <undetermined>. *)

    | MenhirState245 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_BAND, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 245.
        Stack shape : expr_pattern BAND expr.
        Start symbol: <undetermined>. *)

    | MenhirState246 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_AS, 'r) _menhir_state
      (** State 246.
        Stack shape : expr_pattern AS.
        Start symbol: <undetermined>. *)

    | MenhirState249 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_AND, 'r) _menhir_state
      (** State 249.
        Stack shape : expr_pattern AND.
        Start symbol: <undetermined>. *)

    | MenhirState250 : (((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_AND, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 250.
        Stack shape : expr_pattern AND expr.
        Start symbol: <undetermined>. *)

    | MenhirState255 : ((('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 255.
        Stack shape : BNOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState257 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_pattern, 'r) _menhir_state
      (** State 257.
        Stack shape : LPAR pattern.
        Start symbol: <undetermined>. *)

    | MenhirState259 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 259.
        Stack shape : LPAR expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState267 : (('s, 'r) _menhir_cell1_slice, 'r) _menhir_state
      (** State 267.
        Stack shape : slice.
        Start symbol: <undetermined>. *)

    | MenhirState268 : (('s, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 268.
        Stack shape : expr.
        Start symbol: <undetermined>. *)

    | MenhirState269 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_STAR_COLON, 'r) _menhir_state
      (** State 269.
        Stack shape : expr STAR_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState270 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_STAR_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 270.
        Stack shape : expr STAR_COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState271 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS_COLON, 'r) _menhir_state
      (** State 271.
        Stack shape : expr PLUS_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState272 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 272.
        Stack shape : expr PLUS_COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState273 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON, 'r) _menhir_state
      (** State 273.
        Stack shape : expr COLON.
        Start symbol: <undetermined>. *)

    | MenhirState274 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 274.
        Stack shape : expr COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState280 : (('s, 'r) _menhir_cell1_int_constraint, 'r) _menhir_state
      (** State 280.
        Stack shape : int_constraint.
        Start symbol: <undetermined>. *)

    | MenhirState281 : (('s, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 281.
        Stack shape : expr.
        Start symbol: <undetermined>. *)

    | MenhirState282 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SLICING, 'r) _menhir_state
      (** State 282.
        Stack shape : expr SLICING.
        Start symbol: <undetermined>. *)

    | MenhirState283 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SLICING, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 283.
        Stack shape : expr SLICING expr.
        Start symbol: <undetermined>. *)

    | MenhirState290 : (('s, 'r) _menhir_cell1_ty, 'r) _menhir_state
      (** State 290.
        Stack shape : ty.
        Start symbol: <undetermined>. *)

    | MenhirState296 : ((('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 296.
        Stack shape : BNOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState299 : ((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 299.
        Stack shape : IF expr.
        Start symbol: <undetermined>. *)

    | MenhirState300 : (((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 300.
        Stack shape : IF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState301 : ((((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 301.
        Stack shape : IF expr THEN expr.
        Start symbol: <undetermined>. *)

    | MenhirState303 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 303.
        Stack shape : LPAR expr.
        Start symbol: <undetermined>. *)

    | MenhirState305 : (((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 305.
        Stack shape : LPAR expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState309 : ((('s, 'r) _menhir_cell1_NOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 309.
        Stack shape : NOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState310 : ((('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 310.
        Stack shape : WHILE expr.
        Start symbol: <undetermined>. *)

    | MenhirState311 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_state
      (** State 311.
        Stack shape : expr LOOPLIMIT.
        Start symbol: <undetermined>. *)

    | MenhirState312 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 312.
        Stack shape : expr LOOPLIMIT expr.
        Start symbol: <undetermined>. *)

    | MenhirState314 : (((('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_loop_limit, 'r) _menhir_state
      (** State 314.
        Stack shape : WHILE expr loop_limit.
        Start symbol: <undetermined>. *)

    | MenhirState315 : (('s, 'r) _menhir_cell1_VAR, 'r) _menhir_state
      (** State 315.
        Stack shape : VAR.
        Start symbol: <undetermined>. *)

    | MenhirState317 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 317.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState321 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_discard_or_identifier, 'r) _menhir_state
      (** State 321.
        Stack shape : LPAR discard_or_identifier.
        Start symbol: <undetermined>. *)

    | MenhirState323 : ((('s, 'r) _menhir_cell1_discard_or_identifier, 'r) _menhir_cell1_discard_or_identifier, 'r) _menhir_state
      (** State 323.
        Stack shape : discard_or_identifier discard_or_identifier.
        Start symbol: <undetermined>. *)

    | MenhirState329 : ((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 329.
        Stack shape : VAR IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState331 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 331.
        Stack shape : IDENTIFIER IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState334 : ((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_state
      (** State 334.
        Stack shape : VAR decl_item.
        Start symbol: <undetermined>. *)

    | MenhirState335 : (((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_EQ, 'r) _menhir_state
      (** State 335.
        Stack shape : VAR decl_item EQ.
        Start symbol: <undetermined>. *)

    | MenhirState336 : ((((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_EQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 336.
        Stack shape : VAR decl_item EQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState340 : (((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_as_ty, 'r) _menhir_state
      (** State 340.
        Stack shape : VAR decl_item as_ty.
        Start symbol: <undetermined>. *)

    | MenhirState341 : ((('s, 'r) _menhir_cell1_as_ty, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 341.
        Stack shape : as_ty IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState342 : (((('s, 'r) _menhir_cell1_as_ty, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 342.
        Stack shape : as_ty IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState344 : ((((('s, 'r) _menhir_cell1_as_ty, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_RBRACE _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 344.
        Stack shape : as_ty IDENTIFIER LBRACE RBRACE LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState347 : ((((('s, 'r) _menhir_cell1_as_ty, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 347.
        Stack shape : as_ty IDENTIFIER LBRACE COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState350 : (((((('s, 'r) _menhir_cell1_as_ty, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_cell1_COMMA, 'r) _menhir_cell1_clist1_expr_ _menhir_cell0_RBRACE _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 350.
        Stack shape : as_ty IDENTIFIER LBRACE COMMA clist1(expr) RBRACE LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState353 : ((((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_as_ty, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 353.
        Stack shape : VAR decl_item as_ty expr.
        Start symbol: <undetermined>. *)

    | MenhirState357 : ((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_clist2_annotated_IDENTIFIER__, 'r) _menhir_state
      (** State 357.
        Stack shape : VAR clist2(annotated(IDENTIFIER)).
        Start symbol: <undetermined>. *)

    | MenhirState364 : (('s, 'r) _menhir_cell1_TRY, 'r) _menhir_state
      (** State 364.
        Stack shape : TRY.
        Start symbol: <undetermined>. *)

    | MenhirState365 : (('s, 'r) _menhir_cell1_THROW, 'r) _menhir_state
      (** State 365.
        Stack shape : THROW.
        Start symbol: <undetermined>. *)

    | MenhirState367 : ((('s, 'r) _menhir_cell1_THROW, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 367.
        Stack shape : THROW expr.
        Start symbol: <undetermined>. *)

    | MenhirState369 : (('s, 'r) _menhir_cell1_RETURN, 'r) _menhir_state
      (** State 369.
        Stack shape : RETURN.
        Start symbol: <undetermined>. *)

    | MenhirState372 : ((('s, 'r) _menhir_cell1_RETURN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 372.
        Stack shape : RETURN expr.
        Start symbol: <undetermined>. *)

    | MenhirState373 : (('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_state
      (** State 373.
        Stack shape : REPEAT.
        Start symbol: <undetermined>. *)

    | MenhirState375 : (('s, 'r) _menhir_cell1_PRINTLN _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 375.
        Stack shape : PRINTLN LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState380 : (('s, 'r) _menhir_cell1_PRINT _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 380.
        Stack shape : PRINT LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState385 : (('s, 'r) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 385.
        Stack shape : PRAGMA IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState391 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 391.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState393 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 393.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState394 : (('s, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_state
      (** State 394.
        Stack shape : LLBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState395 : ((('s, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 395.
        Stack shape : LLBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState396 : (((('s, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RRBRACKET, 'r) _menhir_state
      (** State 396.
        Stack shape : LLBRACKET expr RRBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState398 : (('s, 'r) _menhir_cell1_DOT _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 398.
        Stack shape : DOT IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState401 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_access, 'r) _menhir_state
      (** State 401.
        Stack shape : IDENTIFIER access.
        Start symbol: <undetermined>. *)

    | MenhirState404 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_discard_or_basic_lexpr, 'r) _menhir_state
      (** State 404.
        Stack shape : LPAR discard_or_basic_lexpr.
        Start symbol: <undetermined>. *)

    | MenhirState406 : ((('s, 'r) _menhir_cell1_discard_or_basic_lexpr, 'r) _menhir_cell1_discard_or_basic_lexpr, 'r) _menhir_state
      (** State 406.
        Stack shape : discard_or_basic_lexpr discard_or_basic_lexpr.
        Start symbol: <undetermined>. *)

    | MenhirState412 : (('s, 'r) _menhir_cell1_LET, 'r) _menhir_state
      (** State 412.
        Stack shape : LET.
        Start symbol: <undetermined>. *)

    | MenhirState414 : ((('s, 'r) _menhir_cell1_LET, 'r) _menhir_cell1_decl_item, 'r) _menhir_state
      (** State 414.
        Stack shape : LET decl_item.
        Start symbol: <undetermined>. *)

    | MenhirState415 : (((('s, 'r) _menhir_cell1_LET, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_EQ, 'r) _menhir_state
      (** State 415.
        Stack shape : LET decl_item EQ.
        Start symbol: <undetermined>. *)

    | MenhirState416 : ((((('s, 'r) _menhir_cell1_LET, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_EQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 416.
        Stack shape : LET decl_item EQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState419 : (((('s, 'r) _menhir_cell1_LET, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_as_ty, 'r) _menhir_state
      (** State 419.
        Stack shape : LET decl_item as_ty.
        Start symbol: <undetermined>. *)

    | MenhirState420 : ((((('s, 'r) _menhir_cell1_LET, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_as_ty, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 420.
        Stack shape : LET decl_item as_ty expr.
        Start symbol: <undetermined>. *)

    | MenhirState424 : (('s, 'r) _menhir_cell1_IF, 'r) _menhir_state
      (** State 424.
        Stack shape : IF.
        Start symbol: <undetermined>. *)

    | MenhirState425 : ((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 425.
        Stack shape : IF expr.
        Start symbol: <undetermined>. *)

    | MenhirState426 : (((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 426.
        Stack shape : IF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState427 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 427.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState428 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 428.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState430 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_DOT _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 430.
        Stack shape : IDENTIFIER DOT LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState434 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_DOT _menhir_cell0_LPAR, 'r) _menhir_cell1_discard_or_field, 'r) _menhir_state
      (** State 434.
        Stack shape : IDENTIFIER DOT LPAR discard_or_field.
        Start symbol: <undetermined>. *)

    | MenhirState436 : ((('s, 'r) _menhir_cell1_discard_or_field, 'r) _menhir_cell1_discard_or_field, 'r) _menhir_state
      (** State 436.
        Stack shape : discard_or_field discard_or_field.
        Start symbol: <undetermined>. *)

    | MenhirState441 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_state
      (** State 441.
        Stack shape : IDENTIFIER DOT LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState443 : ((('s, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 443.
        Stack shape : DOT LBRACKET IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState449 : (('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 449.
        Stack shape : FOR IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState450 : ((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 450.
        Stack shape : FOR IDENTIFIER expr.
        Start symbol: <undetermined>. *)

    | MenhirState453 : (((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_direction, 'r) _menhir_state
      (** State 453.
        Stack shape : FOR IDENTIFIER expr direction.
        Start symbol: <undetermined>. *)

    | MenhirState454 : ((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_direction, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 454.
        Stack shape : FOR IDENTIFIER expr direction expr.
        Start symbol: <undetermined>. *)

    | MenhirState456 : (((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_direction, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_loop_limit, 'r) _menhir_state
      (** State 456.
        Stack shape : FOR IDENTIFIER expr direction expr loop_limit.
        Start symbol: <undetermined>. *)

    | MenhirState458 : (('s, 'r) _menhir_cell1_DEBUG _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 458.
        Stack shape : DEBUG LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState462 : (('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_state
      (** State 462.
        Stack shape : CONSTANT.
        Start symbol: <undetermined>. *)

    | MenhirState463 : ((('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_cell1_decl_item, 'r) _menhir_state
      (** State 463.
        Stack shape : CONSTANT decl_item.
        Start symbol: <undetermined>. *)

    | MenhirState464 : (((('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_EQ, 'r) _menhir_state
      (** State 464.
        Stack shape : CONSTANT decl_item EQ.
        Start symbol: <undetermined>. *)

    | MenhirState465 : ((((('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_EQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 465.
        Stack shape : CONSTANT decl_item EQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState468 : (((('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_as_ty, 'r) _menhir_state
      (** State 468.
        Stack shape : CONSTANT decl_item as_ty.
        Start symbol: <undetermined>. *)

    | MenhirState469 : ((((('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_as_ty, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 469.
        Stack shape : CONSTANT decl_item as_ty expr.
        Start symbol: <undetermined>. *)

    | MenhirState473 : (('s, 'r) _menhir_cell1_CASE, 'r) _menhir_state
      (** State 473.
        Stack shape : CASE.
        Start symbol: <undetermined>. *)

    | MenhirState474 : ((('s, 'r) _menhir_cell1_CASE, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 474.
        Stack shape : CASE expr.
        Start symbol: <undetermined>. *)

    | MenhirState475 : (((('s, 'r) _menhir_cell1_CASE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OF, 'r) _menhir_state
      (** State 475.
        Stack shape : CASE expr OF.
        Start symbol: <undetermined>. *)

    | MenhirState476 : (('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_state
      (** State 476.
        Stack shape : WHEN.
        Start symbol: <undetermined>. *)

    | MenhirState478 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_pattern_list, 'r) _menhir_state
      (** State 478.
        Stack shape : WHEN pattern_list.
        Start symbol: <undetermined>. *)

    | MenhirState479 : (((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_pattern_list, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 479.
        Stack shape : WHEN pattern_list expr.
        Start symbol: <undetermined>. *)

    | MenhirState480 : ((((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_pattern_list, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ARROW, 'r) _menhir_state
      (** State 480.
        Stack shape : WHEN pattern_list expr ARROW.
        Start symbol: <undetermined>. *)

    | MenhirState481 : (('s, 'r) _menhir_cell1_ASSERT, 'r) _menhir_state
      (** State 481.
        Stack shape : ASSERT.
        Start symbol: <undetermined>. *)

    | MenhirState482 : ((('s, 'r) _menhir_cell1_ASSERT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 482.
        Stack shape : ASSERT expr.
        Start symbol: <undetermined>. *)

    | MenhirState485 : (('s, 'r) _menhir_cell1_stmt, 'r) _menhir_state
      (** State 485.
        Stack shape : stmt.
        Start symbol: <undetermined>. *)

    | MenhirState488 : (('s, 'r) _menhir_cell1_lexpr, 'r) _menhir_state
      (** State 488.
        Stack shape : lexpr.
        Start symbol: <undetermined>. *)

    | MenhirState489 : ((('s, 'r) _menhir_cell1_lexpr, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 489.
        Stack shape : lexpr expr.
        Start symbol: <undetermined>. *)

    | MenhirState491 : (('s, 'r) _menhir_cell1_call, 'r) _menhir_state
      (** State 491.
        Stack shape : call.
        Start symbol: <undetermined>. *)

    | MenhirState494 : ((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_state
      (** State 494.
        Stack shape : call DOT LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState497 : (((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_cell1_clist2_IDENTIFIER_ _menhir_cell0_RBRACKET, 'r) _menhir_state
      (** State 497.
        Stack shape : call DOT LBRACKET clist2(IDENTIFIER) RBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState498 : ((((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_DOT _menhir_cell0_LBRACKET, 'r) _menhir_cell1_clist2_IDENTIFIER_ _menhir_cell0_RBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 498.
        Stack shape : call DOT LBRACKET clist2(IDENTIFIER) RBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState500 : (('s, 'r) _menhir_cell1_DOT _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 500.
        Stack shape : DOT IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState503 : ((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_setter_access, 'r) _menhir_state
      (** State 503.
        Stack shape : call setter_access.
        Start symbol: <undetermined>. *)

    | MenhirState504 : (((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_setter_access, 'r) _menhir_cell1_EQ, 'r) _menhir_state
      (** State 504.
        Stack shape : call setter_access EQ.
        Start symbol: <undetermined>. *)

    | MenhirState505 : ((((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_setter_access, 'r) _menhir_cell1_EQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 505.
        Stack shape : call setter_access EQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState508 : (((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_setter_access, 'r) _menhir_cell1_slices, 'r) _menhir_state
      (** State 508.
        Stack shape : call setter_access slices.
        Start symbol: <undetermined>. *)

    | MenhirState509 : ((((('s, 'r) _menhir_cell1_call, 'r) _menhir_cell1_setter_access, 'r) _menhir_cell1_slices, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 509.
        Stack shape : call setter_access slices expr.
        Start symbol: <undetermined>. *)

    | MenhirState513 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_pattern_list, 'r) _menhir_state
      (** State 513.
        Stack shape : WHEN pattern_list.
        Start symbol: <undetermined>. *)

    | MenhirState517 : ((((('s, 'r) _menhir_cell1_CASE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OF, 'r) _menhir_cell1_list1_case_alt_, 'r) _menhir_state
      (** State 517.
        Stack shape : CASE expr OF list1(case_alt).
        Start symbol: <undetermined>. *)

    | MenhirState523 : (('s, 'r) _menhir_cell1_case_alt, 'r) _menhir_state
      (** State 523.
        Stack shape : case_alt.
        Start symbol: <undetermined>. *)

    | MenhirState528 : ((((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_state
      (** State 528.
        Stack shape : IF expr THEN stmt_list.
        Start symbol: <undetermined>. *)

    | MenhirState529 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_ELSIF, 'r) _menhir_state
      (** State 529.
        Stack shape : expr THEN stmt_list ELSIF.
        Start symbol: <undetermined>. *)

    | MenhirState530 : (((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 530.
        Stack shape : expr THEN stmt_list ELSIF expr.
        Start symbol: <undetermined>. *)

    | MenhirState531 : ((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 531.
        Stack shape : expr THEN stmt_list ELSIF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState532 : (((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_state
      (** State 532.
        Stack shape : expr THEN stmt_list ELSIF expr THEN stmt_list.
        Start symbol: <undetermined>. *)

    | MenhirState533 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_ELSE, 'r) _menhir_state
      (** State 533.
        Stack shape : expr THEN stmt_list ELSE.
        Start symbol: <undetermined>. *)

    | MenhirState540 : ((('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_cell1_stmt_list, 'r) _menhir_state
      (** State 540.
        Stack shape : REPEAT stmt_list.
        Start symbol: <undetermined>. *)

    | MenhirState541 : (((('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 541.
        Stack shape : REPEAT stmt_list expr.
        Start symbol: <undetermined>. *)

    | MenhirState545 : ((('s, 'r) _menhir_cell1_TRY, 'r) _menhir_cell1_stmt_list, 'r) _menhir_state
      (** State 545.
        Stack shape : TRY stmt_list.
        Start symbol: <undetermined>. *)

    | MenhirState546 : (('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_state
      (** State 546.
        Stack shape : WHEN.
        Start symbol: <undetermined>. *)

    | MenhirState548 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_COLON, 'r) _menhir_state
      (** State 548.
        Stack shape : WHEN IDENTIFIER COLON.
        Start symbol: <undetermined>. *)

    | MenhirState550 : (((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_COLON, 'r) _menhir_cell1_ty, 'r) _menhir_state
      (** State 550.
        Stack shape : WHEN IDENTIFIER COLON ty.
        Start symbol: <undetermined>. *)

    | MenhirState553 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_ty, 'r) _menhir_state
      (** State 553.
        Stack shape : WHEN ty.
        Start symbol: <undetermined>. *)

    | MenhirState557 : (((('s, 'r) _menhir_cell1_TRY, 'r) _menhir_cell1_stmt_list, 'r) _menhir_cell1_list1_catcher_, 'r) _menhir_state
      (** State 557.
        Stack shape : TRY stmt_list list1(catcher).
        Start symbol: <undetermined>. *)

    | MenhirState562 : (('s, 'r) _menhir_cell1_catcher, 'r) _menhir_state
      (** State 562.
        Stack shape : catcher.
        Start symbol: <undetermined>. *)

    | MenhirState570 : ('s, _menhir_box_spec) _menhir_state
      (** State 570.
        Stack shape : .
        Start symbol: spec. *)

    | MenhirState571 : (('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_state
      (** State 571.
        Stack shape : VAR.
        Start symbol: spec. *)

    | MenhirState574 : ((('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_state
      (** State 574.
        Stack shape : VAR ignored_or_identifier.
        Start symbol: spec. *)

    | MenhirState575 : (((('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_EQ, _menhir_box_spec) _menhir_state
      (** State 575.
        Stack shape : VAR ignored_or_identifier EQ.
        Start symbol: spec. *)

    | MenhirState576 : ((((('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_EQ, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 576.
        Stack shape : VAR ignored_or_identifier EQ expr.
        Start symbol: spec. *)

    | MenhirState578 : (((('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_COLON, _menhir_box_spec) _menhir_state
      (** State 578.
        Stack shape : VAR ignored_or_identifier COLON.
        Start symbol: spec. *)

    | MenhirState579 : ((((('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_COLON, _menhir_box_spec) _menhir_cell1_COLLECTION, _menhir_box_spec) _menhir_state
      (** State 579.
        Stack shape : VAR ignored_or_identifier COLON COLLECTION.
        Start symbol: spec. *)

    | MenhirState580 : (('s, _menhir_box_spec) _menhir_cell1_LBRACE, _menhir_box_spec) _menhir_state
      (** State 580.
        Stack shape : LBRACE.
        Start symbol: spec. *)

    | MenhirState583 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 583.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState586 : (('s, _menhir_box_spec) _menhir_cell1_typed_identifier, _menhir_box_spec) _menhir_state
      (** State 586.
        Stack shape : typed_identifier.
        Start symbol: spec. *)

    | MenhirState596 : (((('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_state
      (** State 596.
        Stack shape : VAR ignored_or_identifier as_ty.
        Start symbol: spec. *)

    | MenhirState597 : ((((('s, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 597.
        Stack shape : VAR ignored_or_identifier as_ty expr.
        Start symbol: spec. *)

    | MenhirState602 : (('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 602.
        Stack shape : TYPE IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState605 : (('s, _menhir_box_spec) _menhir_cell1_SUBTYPES _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 605.
        Stack shape : SUBTYPES IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState607 : ((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_state
      (** State 607.
        Stack shape : TYPE IDENTIFIER OF.
        Start symbol: spec. *)

    | MenhirState608 : (((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_RECORD, _menhir_box_spec) _menhir_state
      (** State 608.
        Stack shape : TYPE IDENTIFIER OF RECORD.
        Start symbol: spec. *)

    | MenhirState610 : (((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_EXCEPTION, _menhir_box_spec) _menhir_state
      (** State 610.
        Stack shape : TYPE IDENTIFIER OF EXCEPTION.
        Start symbol: spec. *)

    | MenhirState613 : (((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_ENUMERATION _menhir_cell0_LBRACE, _menhir_box_spec) _menhir_state
      (** State 613.
        Stack shape : TYPE IDENTIFIER OF ENUMERATION LBRACE.
        Start symbol: spec. *)

    | MenhirState615 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 615.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState619 : (((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_ty_decl, _menhir_box_spec) _menhir_state
      (** State 619.
        Stack shape : TYPE IDENTIFIER OF ty_decl.
        Start symbol: spec. *)

    | MenhirState629 : (('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 629.
        Stack shape : READONLY IMPLEMENTATION FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState630 : (('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_LBRACE, _menhir_box_spec) _menhir_state
      (** State 630.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: spec. *)

    | MenhirState631 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 631.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState634 : (('s, _menhir_box_spec) _menhir_cell1_opt_typed_identifier, _menhir_box_spec) _menhir_state
      (** State 634.
        Stack shape : opt_typed_identifier.
        Start symbol: spec. *)

    | MenhirState638 : ((('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 638.
        Stack shape : READONLY IMPLEMENTATION FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState639 : ((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_LPAR, _menhir_box_spec) _menhir_state
      (** State 639.
        Stack shape : IDENTIFIER params_opt LPAR.
        Start symbol: spec. *)

    | MenhirState641 : (('s, _menhir_box_spec) _menhir_cell1_typed_identifier, _menhir_box_spec) _menhir_state
      (** State 641.
        Stack shape : typed_identifier.
        Start symbol: spec. *)

    | MenhirState646 : (((('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 646.
        Stack shape : READONLY IMPLEMENTATION FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState647 : ((((('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 647.
        Stack shape : READONLY IMPLEMENTATION FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState652 : (((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_ARROW, _menhir_box_spec) _menhir_state
      (** State 652.
        Stack shape : IDENTIFIER params_opt func_args ARROW.
        Start symbol: spec. *)

    | MenhirState654 : ((((('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 654.
        Stack shape : READONLY IMPLEMENTATION FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState655 : ((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_RECURSELIMIT, _menhir_box_spec) _menhir_state
      (** State 655.
        Stack shape : IDENTIFIER params_opt func_args return_type RECURSELIMIT.
        Start symbol: spec. *)

    | MenhirState656 : (((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_RECURSELIMIT, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 656.
        Stack shape : IDENTIFIER params_opt func_args return_type RECURSELIMIT expr.
        Start symbol: spec. *)

    | MenhirState658 : (((((('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 658.
        Stack shape : READONLY IMPLEMENTATION FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState664 : (('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 664.
        Stack shape : READONLY IMPDEF FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState665 : ((('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 665.
        Stack shape : READONLY IMPDEF FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState666 : (((('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 666.
        Stack shape : READONLY IMPDEF FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState667 : ((((('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 667.
        Stack shape : READONLY IMPDEF FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState671 : ((((('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 671.
        Stack shape : READONLY IMPDEF FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState673 : (((((('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 673.
        Stack shape : READONLY IMPDEF FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState678 : (('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 678.
        Stack shape : READONLY FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState679 : ((('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 679.
        Stack shape : READONLY FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState680 : (((('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 680.
        Stack shape : READONLY FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState681 : ((((('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 681.
        Stack shape : READONLY FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState685 : ((((('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 685.
        Stack shape : READONLY FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState687 : (((((('s, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 687.
        Stack shape : READONLY FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState694 : (('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 694.
        Stack shape : PURE IMPLEMENTATION FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState695 : ((('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 695.
        Stack shape : PURE IMPLEMENTATION FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState696 : (((('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 696.
        Stack shape : PURE IMPLEMENTATION FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState697 : ((((('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 697.
        Stack shape : PURE IMPLEMENTATION FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState701 : ((((('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 701.
        Stack shape : PURE IMPLEMENTATION FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState703 : (((((('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 703.
        Stack shape : PURE IMPLEMENTATION FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState709 : (('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 709.
        Stack shape : PURE IMPDEF FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState710 : ((('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 710.
        Stack shape : PURE IMPDEF FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState711 : (((('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 711.
        Stack shape : PURE IMPDEF FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState712 : ((((('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 712.
        Stack shape : PURE IMPDEF FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState716 : ((((('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 716.
        Stack shape : PURE IMPDEF FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState718 : (((((('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 718.
        Stack shape : PURE IMPDEF FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState723 : (('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 723.
        Stack shape : PURE FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState724 : ((('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 724.
        Stack shape : PURE FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState725 : (((('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 725.
        Stack shape : PURE FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState726 : ((((('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 726.
        Stack shape : PURE FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState730 : ((((('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 730.
        Stack shape : PURE FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState732 : (((((('s, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 732.
        Stack shape : PURE FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState737 : (('s, _menhir_box_spec) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 737.
        Stack shape : PRAGMA IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState743 : (('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 743.
        Stack shape : NORETURN IMPLEMENTATION FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState744 : ((('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 744.
        Stack shape : NORETURN IMPLEMENTATION FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState745 : (((('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 745.
        Stack shape : NORETURN IMPLEMENTATION FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState746 : ((((('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 746.
        Stack shape : NORETURN IMPLEMENTATION FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState750 : ((((('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 750.
        Stack shape : NORETURN IMPLEMENTATION FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState752 : (((((('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 752.
        Stack shape : NORETURN IMPLEMENTATION FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState758 : (('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 758.
        Stack shape : NORETURN IMPDEF FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState759 : ((('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 759.
        Stack shape : NORETURN IMPDEF FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState760 : (((('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 760.
        Stack shape : NORETURN IMPDEF FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState761 : ((((('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 761.
        Stack shape : NORETURN IMPDEF FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState765 : ((((('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 765.
        Stack shape : NORETURN IMPDEF FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState767 : (((((('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 767.
        Stack shape : NORETURN IMPDEF FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState772 : (('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 772.
        Stack shape : NORETURN FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState773 : ((('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 773.
        Stack shape : NORETURN FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState774 : (((('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 774.
        Stack shape : NORETURN FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState775 : ((((('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 775.
        Stack shape : NORETURN FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState779 : ((((('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 779.
        Stack shape : NORETURN FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState781 : (((((('s, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 781.
        Stack shape : NORETURN FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState785 : (('s, _menhir_box_spec) _menhir_cell1_LET, _menhir_box_spec) _menhir_state
      (** State 785.
        Stack shape : LET.
        Start symbol: spec. *)

    | MenhirState786 : ((('s, _menhir_box_spec) _menhir_cell1_LET, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_state
      (** State 786.
        Stack shape : LET ignored_or_identifier.
        Start symbol: spec. *)

    | MenhirState787 : (((('s, _menhir_box_spec) _menhir_cell1_LET, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_EQ, _menhir_box_spec) _menhir_state
      (** State 787.
        Stack shape : LET ignored_or_identifier EQ.
        Start symbol: spec. *)

    | MenhirState788 : ((((('s, _menhir_box_spec) _menhir_cell1_LET, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_EQ, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 788.
        Stack shape : LET ignored_or_identifier EQ expr.
        Start symbol: spec. *)

    | MenhirState791 : (((('s, _menhir_box_spec) _menhir_cell1_LET, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_state
      (** State 791.
        Stack shape : LET ignored_or_identifier as_ty.
        Start symbol: spec. *)

    | MenhirState792 : ((((('s, _menhir_box_spec) _menhir_cell1_LET, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 792.
        Stack shape : LET ignored_or_identifier as_ty expr.
        Start symbol: spec. *)

    | MenhirState798 : (('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 798.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState799 : ((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 799.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState800 : (((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 800.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState801 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 801.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState805 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 805.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState807 : (((((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 807.
        Stack shape : IMPLEMENTATION FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState812 : (('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 812.
        Stack shape : IMPLEMENTATION IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState813 : ((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 813.
        Stack shape : IMPLEMENTATION IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState816 : (((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 816.
        Stack shape : IMPLEMENTATION IDENTIFIER params_opt func_args IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState818 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_state
      (** State 818.
        Stack shape : IMPLEMENTATION IDENTIFIER params_opt func_args IDENTIFIER as_ty.
        Start symbol: spec. *)

    | MenhirState819 : ((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_state
      (** State 819.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty SETTER.
        Start symbol: spec. *)

    | MenhirState821 : (((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END, _menhir_box_spec) _menhir_state
      (** State 821.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty SETTER maybe_empty_stmt_list END.
        Start symbol: spec. *)

    | MenhirState822 : ((((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 822.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty SETTER maybe_empty_stmt_list END SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState825 : (((((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_cell1_is_readonly, _menhir_box_spec) _menhir_state
      (** State 825.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty SETTER maybe_empty_stmt_list END SEMI_COLON is_readonly.
        Start symbol: spec. *)

    | MenhirState830 : ((((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END, _menhir_box_spec) _menhir_cell1_is_readonly, _menhir_box_spec) _menhir_state
      (** State 830.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty SETTER maybe_empty_stmt_list END is_readonly.
        Start symbol: spec. *)

    | MenhirState835 : ((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_is_readonly, _menhir_box_spec) _menhir_state
      (** State 835.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty is_readonly.
        Start symbol: spec. *)

    | MenhirState838 : (((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_is_readonly, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END, _menhir_box_spec) _menhir_state
      (** State 838.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty is_readonly maybe_empty_stmt_list END.
        Start symbol: spec. *)

    | MenhirState843 : (((((('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_is_readonly, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END _menhir_cell0_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 843.
        Stack shape : IDENTIFIER params_opt func_args IDENTIFIER as_ty is_readonly maybe_empty_stmt_list END SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState852 : (('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 852.
        Stack shape : IMPDEF FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState853 : ((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 853.
        Stack shape : IMPDEF FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState854 : (((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 854.
        Stack shape : IMPDEF FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState855 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 855.
        Stack shape : IMPDEF FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState859 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 859.
        Stack shape : IMPDEF FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState861 : (((((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 861.
        Stack shape : IMPDEF FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState866 : (('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 866.
        Stack shape : IMPDEF IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState867 : ((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 867.
        Stack shape : IMPDEF IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState870 : (((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 870.
        Stack shape : IMPDEF IDENTIFIER params_opt func_args IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState872 : ((((('s, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_state
      (** State 872.
        Stack shape : IMPDEF IDENTIFIER params_opt func_args IDENTIFIER as_ty.
        Start symbol: spec. *)

    | MenhirState877 : (('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 877.
        Stack shape : FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState878 : ((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 878.
        Stack shape : FUNC IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState879 : (((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_state
      (** State 879.
        Stack shape : FUNC IDENTIFIER params_opt func_args.
        Start symbol: spec. *)

    | MenhirState880 : ((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 880.
        Stack shape : FUNC IDENTIFIER params_opt func_args BEGIN.
        Start symbol: spec. *)

    | MenhirState884 : ((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_state
      (** State 884.
        Stack shape : FUNC IDENTIFIER params_opt func_args return_type.
        Start symbol: spec. *)

    | MenhirState886 : (((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit, _menhir_box_spec) _menhir_state
      (** State 886.
        Stack shape : FUNC IDENTIFIER params_opt func_args return_type recurse_limit.
        Start symbol: spec. *)

    | MenhirState890 : (('s, _menhir_box_spec) _menhir_cell1_CONSTANT, _menhir_box_spec) _menhir_state
      (** State 890.
        Stack shape : CONSTANT.
        Start symbol: spec. *)

    | MenhirState891 : ((('s, _menhir_box_spec) _menhir_cell1_CONSTANT, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_state
      (** State 891.
        Stack shape : CONSTANT ignored_or_identifier.
        Start symbol: spec. *)

    | MenhirState892 : (((('s, _menhir_box_spec) _menhir_cell1_CONSTANT, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_EQ, _menhir_box_spec) _menhir_state
      (** State 892.
        Stack shape : CONSTANT ignored_or_identifier EQ.
        Start symbol: spec. *)

    | MenhirState893 : ((((('s, _menhir_box_spec) _menhir_cell1_CONSTANT, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_EQ, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 893.
        Stack shape : CONSTANT ignored_or_identifier EQ expr.
        Start symbol: spec. *)

    | MenhirState896 : (((('s, _menhir_box_spec) _menhir_cell1_CONSTANT, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_state
      (** State 896.
        Stack shape : CONSTANT ignored_or_identifier as_ty.
        Start symbol: spec. *)

    | MenhirState897 : ((((('s, _menhir_box_spec) _menhir_cell1_CONSTANT, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 897.
        Stack shape : CONSTANT ignored_or_identifier as_ty expr.
        Start symbol: spec. *)

    | MenhirState901 : (('s, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_state
      (** State 901.
        Stack shape : CONFIG.
        Start symbol: spec. *)

    | MenhirState902 : ((('s, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_state
      (** State 902.
        Stack shape : CONFIG ignored_or_identifier.
        Start symbol: spec. *)

    | MenhirState904 : (((('s, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_state
      (** State 904.
        Stack shape : CONFIG ignored_or_identifier as_ty.
        Start symbol: spec. *)

    | MenhirState905 : ((((('s, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 905.
        Stack shape : CONFIG ignored_or_identifier as_ty expr.
        Start symbol: spec. *)

    | MenhirState910 : (('s, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 910.
        Stack shape : ACCESSOR IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState911 : ((('s, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_state
      (** State 911.
        Stack shape : ACCESSOR IDENTIFIER params_opt.
        Start symbol: spec. *)

    | MenhirState914 : (((('s, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 914.
        Stack shape : ACCESSOR IDENTIFIER params_opt func_args IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState916 : ((((('s, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_state
      (** State 916.
        Stack shape : ACCESSOR IDENTIFIER params_opt func_args IDENTIFIER as_ty.
        Start symbol: spec. *)

    | MenhirState923 : (('s, _menhir_box_spec) _menhir_cell1_decl, _menhir_box_spec) _menhir_state
      (** State 923.
        Stack shape : decl.
        Start symbol: spec. *)

    | MenhirState925 : ('s, _menhir_box_stmts) _menhir_state
      (** State 925.
        Stack shape : .
        Start symbol: stmts. *)

  
  and ('s, 'r) _menhir_cell1_access = 
    | MenhirCell1_access of 's * ('s, 'r) _menhir_state * (Desugar.field_or_array_access list)
  
  and ('s, 'r) _menhir_cell1_as_ty = 
    | MenhirCell1_as_ty of 's * ('s, 'r) _menhir_state * (AST.ty)
  
  and ('s, 'r) _menhir_cell1_bitfield = 
    | MenhirCell1_bitfield of 's * ('s, 'r) _menhir_state * (AST.bitfield)
  
  and ('s, 'r) _menhir_cell1_call = 
    | MenhirCell1_call of 's * ('s, 'r) _menhir_state * (AST.call) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_case_alt = 
    | MenhirCell1_case_alt of 's * ('s, 'r) _menhir_state * (AST.case_alt_desc AST.annotated)
  
  and ('s, 'r) _menhir_cell1_catcher = 
    | MenhirCell1_catcher of 's * ('s, 'r) _menhir_state * (AST.catcher)
  
  and ('s, 'r) _menhir_cell1_clist1_expr_ = 
    | MenhirCell1_clist1_expr_ of 's * ('s, 'r) _menhir_state * (AST.expr list)
  
  and ('s, 'r) _menhir_cell1_clist2_IDENTIFIER_ = 
    | MenhirCell1_clist2_IDENTIFIER_ of 's * ('s, 'r) _menhir_state * (string list)
  
  and ('s, 'r) _menhir_cell1_clist2_annotated_IDENTIFIER__ = 
    | MenhirCell1_clist2_annotated_IDENTIFIER__ of 's * ('s, 'r) _menhir_state * (string AST.annotated list)
  
  and ('s, 'r) _menhir_cell1_decl = 
    | MenhirCell1_decl of 's * ('s, 'r) _menhir_state * (AST.decl list)
  
  and ('s, 'r) _menhir_cell1_decl_item = 
    | MenhirCell1_decl_item of 's * ('s, 'r) _menhir_state * (AST.local_decl_item)
  
  and ('s, 'r) _menhir_cell1_direction = 
    | MenhirCell1_direction of 's * ('s, 'r) _menhir_state * (AST.for_direction)
  
  and ('s, 'r) _menhir_cell1_discard_or_basic_lexpr = 
    | MenhirCell1_discard_or_basic_lexpr of 's * ('s, 'r) _menhir_state * ((string AST.annotated * Desugar.lhs_access) option)
  
  and ('s, 'r) _menhir_cell1_discard_or_field = 
    | MenhirCell1_discard_or_field of 's * ('s, 'r) _menhir_state * (Desugar.lhs_field option)
  
  and ('s, 'r) _menhir_cell1_discard_or_identifier = 
    | MenhirCell1_discard_or_identifier of 's * ('s, 'r) _menhir_state * (string)
  
  and ('s, 'r) _menhir_cell1_expr = 
    | MenhirCell1_expr of 's * ('s, 'r) _menhir_state * (AST.expr) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_expr_pattern = 
    | MenhirCell1_expr_pattern of 's * ('s, 'r) _menhir_state * (AST.expr) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_field_assign = 
    | MenhirCell1_field_assign of 's * ('s, 'r) _menhir_state * (string * AST.expr)
  
  and ('s, 'r) _menhir_cell1_func_args = 
    | MenhirCell1_func_args of 's * ('s, 'r) _menhir_state * (AST.typed_identifier list)
  
  and ('s, 'r) _menhir_cell1_ignored_or_identifier = 
    | MenhirCell1_ignored_or_identifier of 's * ('s, 'r) _menhir_state * (string)
  
  and ('s, 'r) _menhir_cell1_int_constraint = 
    | MenhirCell1_int_constraint of 's * ('s, 'r) _menhir_state * (AST.int_constraint)
  
  and ('s, 'r) _menhir_cell1_is_readonly = 
    | MenhirCell1_is_readonly of 's * ('s, 'r) _menhir_state * (bool)
  
  and ('s, 'r) _menhir_cell1_lexpr = 
    | MenhirCell1_lexpr of 's * ('s, 'r) _menhir_state * (AST.lexpr) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_list1_case_alt_ = 
    | MenhirCell1_list1_case_alt_ of 's * ('s, 'r) _menhir_state * (AST.case_alt_desc AST.annotated list)
  
  and ('s, 'r) _menhir_cell1_list1_catcher_ = 
    | MenhirCell1_list1_catcher_ of 's * ('s, 'r) _menhir_state * (AST.catcher list)
  
  and ('s, 'r) _menhir_cell1_loop_limit = 
    | MenhirCell1_loop_limit of 's * ('s, 'r) _menhir_state * (AST.expr option)
  
  and ('s, 'r) _menhir_cell1_maybe_empty_stmt_list = 
    | MenhirCell1_maybe_empty_stmt_list of 's * ('s, 'r) _menhir_state * (AST.stmt)
  
  and ('s, 'r) _menhir_cell1_opt_typed_identifier = 
    | MenhirCell1_opt_typed_identifier of 's * ('s, 'r) _menhir_state * (string * AST.ty option)
  
  and ('s, 'r) _menhir_cell1_params_opt = 
    | MenhirCell1_params_opt of 's * ('s, 'r) _menhir_state * ((string * AST.ty option) list)
  
  and ('s, 'r) _menhir_cell1_pattern = 
    | MenhirCell1_pattern of 's * ('s, 'r) _menhir_state * (AST.pattern) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_pattern_list = 
    | MenhirCell1_pattern_list of 's * ('s, 'r) _menhir_state * (AST.pattern)
  
  and ('s, 'r) _menhir_cell1_recurse_limit = 
    | MenhirCell1_recurse_limit of 's * ('s, 'r) _menhir_state * (AST.expr option)
  
  and ('s, 'r) _menhir_cell1_return_type = 
    | MenhirCell1_return_type of 's * ('s, 'r) _menhir_state * (AST.ty)
  
  and ('s, 'r) _menhir_cell1_setter_access = 
    | MenhirCell1_setter_access of 's * ('s, 'r) _menhir_state * (Desugar.field_or_array_access list)
  
  and ('s, 'r) _menhir_cell1_slice = 
    | MenhirCell1_slice of 's * ('s, 'r) _menhir_state * (AST.slice)
  
  and ('s, 'r) _menhir_cell1_slices = 
    | MenhirCell1_slices of 's * ('s, 'r) _menhir_state * (AST.slice list) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_stmt = 
    | MenhirCell1_stmt of 's * ('s, 'r) _menhir_state * (AST.stmt_desc AST.annotated) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_stmt_list = 
    | MenhirCell1_stmt_list of 's * ('s, 'r) _menhir_state * (AST.stmt) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ty = 
    | MenhirCell1_ty of 's * ('s, 'r) _menhir_state * (AST.ty) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ty_decl = 
    | MenhirCell1_ty_decl of 's * ('s, 'r) _menhir_state * (AST.ty)
  
  and ('s, 'r) _menhir_cell1_typed_identifier = 
    | MenhirCell1_typed_identifier of 's * ('s, 'r) _menhir_state * (AST.field)
  
  and ('s, 'r) _menhir_cell1_ACCESSOR = 
    | MenhirCell1_ACCESSOR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_AND = 
    | MenhirCell1_AND of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ARBITRARY = 
    | MenhirCell1_ARBITRARY of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ARRAY = 
    | MenhirCell1_ARRAY of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ARROW = 
    | MenhirCell1_ARROW of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_AS = 
    | MenhirCell1_AS of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ASSERT = 
    | MenhirCell1_ASSERT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BAND = 
    | MenhirCell1_BAND of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_BEGIN = 
    | MenhirCell1_BEGIN of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_BEQ = 
    | MenhirCell1_BEQ of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_BITS = 
    | MenhirCell1_BITS of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BNOT = 
    | MenhirCell1_BNOT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BOR = 
    | MenhirCell1_BOR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_CASE = 
    | MenhirCell1_CASE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_COLLECTION = 
    | MenhirCell1_COLLECTION of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_COLON = 
    | MenhirCell1_COLON of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_COLON = 
    | MenhirCell0_COLON of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_COLON_COLON = 
    | MenhirCell1_COLON_COLON of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_COMMA = 
    | MenhirCell1_COMMA of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_CONFIG = 
    | MenhirCell1_CONFIG of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_CONSTANT = 
    | MenhirCell1_CONSTANT of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_DEBUG = 
    | MenhirCell1_DEBUG of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_DIV = 
    | MenhirCell1_DIV of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_DIVRM = 
    | MenhirCell1_DIVRM of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_DOT = 
    | MenhirCell1_DOT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ELSE = 
    | MenhirCell1_ELSE of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ELSIF = 
    | MenhirCell1_ELSIF of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_END = 
    | MenhirCell0_END of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ENUMERATION = 
    | MenhirCell1_ENUMERATION of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_EQ = 
    | MenhirCell1_EQ of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_EQ_OP = 
    | MenhirCell1_EQ_OP of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_EXCEPTION = 
    | MenhirCell1_EXCEPTION of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_FOR = 
    | MenhirCell1_FOR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_FUNC = 
    | MenhirCell1_FUNC of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_FUNC = 
    | MenhirCell0_FUNC of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_GEQ = 
    | MenhirCell1_GEQ of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_GT = 
    | MenhirCell1_GT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_IDENTIFIER = 
    | MenhirCell1_IDENTIFIER of 's * ('s, 'r) _menhir_state * (
# 136 "asllib/Tokens.mly"
       (string)
# 2544 "asllib/Parser.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_IDENTIFIER = 
    | MenhirCell0_IDENTIFIER of 's * (
# 136 "asllib/Tokens.mly"
       (string)
# 2551 "asllib/Parser.ml"
  ) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IF = 
    | MenhirCell1_IF of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IMPDEF = 
    | MenhirCell1_IMPDEF of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_IMPDEF = 
    | MenhirCell0_IMPDEF of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IMPL = 
    | MenhirCell1_IMPL of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_IMPLEMENTATION = 
    | MenhirCell1_IMPLEMENTATION of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_IMPLEMENTATION = 
    | MenhirCell0_IMPLEMENTATION of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IN = 
    | MenhirCell1_IN of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_INTEGER = 
    | MenhirCell1_INTEGER of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LBRACE = 
    | MenhirCell1_LBRACE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_LBRACE = 
    | MenhirCell0_LBRACE of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LBRACKET = 
    | MenhirCell1_LBRACKET of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_LBRACKET = 
    | MenhirCell0_LBRACKET of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LEQ = 
    | MenhirCell1_LEQ of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LET = 
    | MenhirCell1_LET of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LLBRACKET = 
    | MenhirCell1_LLBRACKET of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_LOOPLIMIT = 
    | MenhirCell1_LOOPLIMIT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_LPAR = 
    | MenhirCell1_LPAR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_LPAR = 
    | MenhirCell0_LPAR of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LT = 
    | MenhirCell1_LT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_MINUS = 
    | MenhirCell1_MINUS of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_MOD = 
    | MenhirCell1_MOD of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_MUL = 
    | MenhirCell1_MUL of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_NEQ = 
    | MenhirCell1_NEQ of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_NORETURN = 
    | MenhirCell1_NORETURN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_NOT = 
    | MenhirCell1_NOT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_OF = 
    | MenhirCell1_OF of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_OR = 
    | MenhirCell1_OR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_PLUS = 
    | MenhirCell1_PLUS of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_PLUS_COLON = 
    | MenhirCell1_PLUS_COLON of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_POW = 
    | MenhirCell1_POW of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_PRAGMA = 
    | MenhirCell1_PRAGMA of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_PRINT = 
    | MenhirCell1_PRINT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_PRINTLN = 
    | MenhirCell1_PRINTLN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_PURE = 
    | MenhirCell1_PURE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RBRACE = 
    | MenhirCell1_RBRACE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_RBRACE = 
    | MenhirCell0_RBRACE of 's * Lexing.position
  
  and 's _menhir_cell0_RBRACKET = 
    | MenhirCell0_RBRACKET of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RDIV = 
    | MenhirCell1_RDIV of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_READONLY = 
    | MenhirCell1_READONLY of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RECORD = 
    | MenhirCell1_RECORD of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RECURSELIMIT = 
    | MenhirCell1_RECURSELIMIT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_REPEAT = 
    | MenhirCell1_REPEAT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RETURN = 
    | MenhirCell1_RETURN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RPAR = 
    | MenhirCell1_RPAR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RRBRACKET = 
    | MenhirCell1_RRBRACKET of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_SEMI_COLON = 
    | MenhirCell1_SEMI_COLON of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_SEMI_COLON = 
    | MenhirCell0_SEMI_COLON of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_SETTER = 
    | MenhirCell1_SETTER of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_SHL = 
    | MenhirCell1_SHL of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_SHR = 
    | MenhirCell1_SHR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_SLICING = 
    | MenhirCell1_SLICING of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_STAR_COLON = 
    | MenhirCell1_STAR_COLON of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_SUBTYPES = 
    | MenhirCell1_SUBTYPES of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_THEN = 
    | MenhirCell1_THEN of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_THROW = 
    | MenhirCell1_THROW of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_TRY = 
    | MenhirCell1_TRY of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_TYPE = 
    | MenhirCell1_TYPE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_VAR = 
    | MenhirCell1_VAR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_WHEN = 
    | MenhirCell1_WHEN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_WHILE = 
    | MenhirCell1_WHILE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_XOR = 
    | MenhirCell1_XOR of 's * ('s, 'r) _menhir_state
  
  and _menhir_box_stmts = 
    | MenhirBox_stmts of (AST.stmt) [@@unboxed]
  
  and _menhir_box_spec = 
    | MenhirBox_spec of (AST.t) [@@unboxed]
  
  and _menhir_box_opn = 
    | MenhirBox_opn of (AST.t) [@@unboxed]
  
  let _menhir_action_003 =
    fun () ->
      (
# 430 "asllib/Parser.mly"
    ( [] )
# 2751 "asllib/Parser.ml"
       : (Desugar.field_or_array_access list))
  
  let _menhir_action_004 =
    fun _1 _endpos_desc_ _startpos_desc_ desc t ->
      let h =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 2762 "asllib/Parser.ml"
        
      in
      (
# 431 "asllib/Parser.mly"
                                            ( FieldAccess h :: t )
# 2768 "asllib/Parser.ml"
       : (Desugar.field_or_array_access list))
  
  let _menhir_action_005 =
    fun _1 _3 idx t ->
      (
# 432 "asllib/Parser.mly"
                                              ( ArrayAccess idx :: t )
# 2776 "asllib/Parser.ml"
       : (Desugar.field_or_array_access list))
  
  let _menhir_action_006 =
    fun _1 _1_inlined1 _2 _2_inlined1 _2_inlined2 _5 getter is_readonly setter ->
      let _7 =
        let (_2, _1) = (_2_inlined2, _1_inlined1) in
        ()
      in
      let _4 =
        let _2 = _2_inlined1 in
        ()
      in
      (
# 631 "asllib/Parser.mly"
    ( { is_readonly; getter; setter } )
# 2792 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_007 =
    fun _1 _1_inlined1 _2 _2_inlined1 _5 _endpos__1_inlined1_ _startpos__1_inlined1_ getter is_readonly setter ->
      let _7 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2807 "asllib/Parser.ml"
        
      in
      let _4 =
        let _2 = _2_inlined1 in
        ()
      in
      (
# 631 "asllib/Parser.mly"
    ( { is_readonly; getter; setter } )
# 2817 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_008 =
    fun _1 _1_inlined1 _2 _2_inlined1 _5 _endpos__1_ _startpos__1_ getter is_readonly setter ->
      let _7 =
        let (_2, _1) = (_2_inlined1, _1_inlined1) in
        ()
      in
      let _4 =
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2835 "asllib/Parser.ml"
        
      in
      (
# 631 "asllib/Parser.mly"
    ( { is_readonly; getter; setter } )
# 2841 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_009 =
    fun _1 _1_inlined1 _2 _5 _endpos__1_ _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ getter is_readonly setter ->
      let _7 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2856 "asllib/Parser.ml"
        
      in
      let _4 =
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2868 "asllib/Parser.ml"
        
      in
      (
# 631 "asllib/Parser.mly"
    ( { is_readonly; getter; setter } )
# 2874 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_010 =
    fun _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _5 getter is_readonly setter ->
      let _7 =
        let (_2, _1) = (_2_inlined1, _1_inlined2) in
        ()
      in
      let _3 =
        let _1 = _1_inlined1 in
        ()
      in
      (
# 634 "asllib/Parser.mly"
    ( { is_readonly; getter; setter } )
# 2890 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_011 =
    fun _1 _1_inlined1 _1_inlined2 _2 _5 _endpos__1_inlined2_ _startpos__1_inlined2_ getter is_readonly setter ->
      let _7 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2905 "asllib/Parser.ml"
        
      in
      let _3 =
        let _1 = _1_inlined1 in
        ()
      in
      (
# 634 "asllib/Parser.mly"
    ( { is_readonly; getter; setter } )
# 2915 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_012 =
    fun _1 _1_inlined1 _1_inlined2 _2 _5 _endpos__1_inlined1_ _startpos__1_inlined1_ getter is_readonly setter ->
      let _7 =
        let _1 = _1_inlined2 in
        ()
      in
      let _3 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2934 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    ( { is_readonly; getter; setter } )
# 2940 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_013 =
    fun _1 _1_inlined1 _1_inlined2 _5 _endpos__1_inlined1_ _endpos__1_inlined2_ _startpos__1_inlined1_ _startpos__1_inlined2_ getter is_readonly setter ->
      let _7 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2955 "asllib/Parser.ml"
        
      in
      let _3 =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
        let _endpos = _endpos__1_ in
        let _startpos = _startpos__1_ in
        
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 2968 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    ( { is_readonly; getter; setter } )
# 2974 "asllib/Parser.ml"
       : (Desugar.accessor_pair))
  
  let _menhir_action_014 =
    fun _1 _2 ->
      (_2 : (AST.ty))
  
  let _menhir_action_015 =
    fun _endpos_desc_ _startpos_desc_ access desc ->
      let base =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 2989 "asllib/Parser.ml"
        
      in
      (
# 436 "asllib/Parser.mly"
    ( ( base, {access; slices=add_dummy_annotation ~version []} ) )
# 2995 "asllib/Parser.ml"
       : (string AST.annotated * Desugar.lhs_access))
  
  let _menhir_action_016 =
    fun _endpos_desc_ _endpos_desc_inlined1_ _startpos_desc_ _startpos_desc_inlined1_ access desc desc_inlined1 ->
      let slices =
        let (_endpos_desc_, _startpos_desc_, desc) = (_endpos_desc_inlined1_, _startpos_desc_inlined1_, desc_inlined1) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3007 "asllib/Parser.ml"
        
      in
      let base =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3016 "asllib/Parser.ml"
        
      in
      (
# 438 "asllib/Parser.mly"
    ( ( base, {access; slices} ) )
# 3022 "asllib/Parser.ml"
       : (string AST.annotated * Desugar.lhs_access))
  
  let _menhir_action_017 =
    fun s x ->
      (
# 375 "asllib/Parser.mly"
                                              ( BitField_Simple (x, s)     )
# 3030 "asllib/Parser.ml"
       : (AST.bitfield))
  
  let _menhir_action_018 =
    fun bf s x ->
      (
# 376 "asllib/Parser.mly"
                                              ( BitField_Nested (x, s, bf) )
# 3038 "asllib/Parser.ml"
       : (AST.bitfield))
  
  let _menhir_action_019 =
    fun s ty x ->
      (
# 377 "asllib/Parser.mly"
                                              ( BitField_Type   (x, s, ty) )
# 3046 "asllib/Parser.ml"
       : (AST.bitfield))
  
  let _menhir_action_020 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 3054 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_021 =
    fun () ->
      (
# 372 "asllib/Parser.mly"
                     ( [] )
# 3062 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_022 =
    fun _1 ->
      (_1 : (AST.bitfield list))
  
  let _menhir_action_023 =
    fun name x ->
      let args = 
# 205 "<standard.mly>"
    ( x )
# 3074 "asllib/Parser.ml"
       in
      (
# 594 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 3079 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_024 =
    fun name x ->
      let args = 
# 591 "asllib/Parser.mly"
                     ( [] )
# 3087 "asllib/Parser.ml"
       in
      let params = 
# 205 "<standard.mly>"
    ( x )
# 3092 "asllib/Parser.ml"
       in
      (
# 596 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 3097 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_025 =
    fun name x x_inlined1 ->
      let args =
        let x = x_inlined1 in
        
# 205 "<standard.mly>"
    ( x )
# 3107 "asllib/Parser.ml"
        
      in
      let params = 
# 205 "<standard.mly>"
    ( x )
# 3113 "asllib/Parser.ml"
       in
      (
# 596 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 3118 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_026 =
    fun _1 _4 _endpos_stmt_ _startpos__1_ pattern stmt ->
      let desc =
        let where = 
# 123 "<standard.mly>"
    ( None )
# 3127 "asllib/Parser.ml"
         in
        
# 507 "asllib/Parser.mly"
      ( { pattern; where; stmt } )
# 3132 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_stmt_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3141 "asllib/Parser.ml"
       : (AST.case_alt_desc AST.annotated))
  
  let _menhir_action_027 =
    fun _1 _1_inlined1 _2 _4 _endpos_stmt_ _startpos__1_ pattern stmt ->
      let desc =
        let where =
          let _1 = _1_inlined1 in
          let x = _2 in
          
# 126 "<standard.mly>"
    ( Some x )
# 3153 "asllib/Parser.ml"
          
        in
        
# 507 "asllib/Parser.mly"
      ( { pattern; where; stmt } )
# 3159 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_stmt_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3168 "asllib/Parser.ml"
       : (AST.case_alt_desc AST.annotated))
  
  let _menhir_action_028 =
    fun _1 _4 stmt_list ty ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 3176 "asllib/Parser.ml"
       in
      let _2_1 = _2 in
      ((_2_1, ty, stmt_list) : (AST.catcher))
  
  let _menhir_action_029 =
    fun _1 _4 stmt_list ty x ->
      let _2 =
        let x = 
# 196 "<standard.mly>"
    ( x )
# 3187 "asllib/Parser.ml"
         in
        
# 126 "<standard.mly>"
    ( Some x )
# 3192 "asllib/Parser.ml"
        
      in
      let _2_1 = _2 in
      ((_2_1, ty, stmt_list) : (AST.catcher))
  
  let _menhir_action_030 =
    fun () ->
      (
# 162 "asllib/Parser.mly"
                 ( [] )
# 3203 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_031 =
    fun _1 ->
      (_1 : (AST.expr list))
  
  let _menhir_action_032 =
    fun () ->
      (
# 162 "asllib/Parser.mly"
                 ( [] )
# 3215 "asllib/Parser.ml"
       : (AST.ty list))
  
  let _menhir_action_033 =
    fun _1 ->
      (_1 : (AST.ty list))
  
  let _menhir_action_034 =
    fun () ->
      (
# 162 "asllib/Parser.mly"
                 ( [] )
# 3227 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_035 =
    fun _1 ->
      (_1 : (AST.typed_identifier list))
  
  let _menhir_action_036 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3239 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_037 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3247 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_038 =
    fun _endpos_desc_ _startpos_desc_ desc ->
      let x =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3258 "asllib/Parser.ml"
        
      in
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3264 "asllib/Parser.ml"
       : (string AST.annotated list))
  
  let _menhir_action_039 =
    fun _2 _endpos_desc_ _startpos_desc_ desc t ->
      let h =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3275 "asllib/Parser.ml"
        
      in
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3281 "asllib/Parser.ml"
       : (string AST.annotated list))
  
  let _menhir_action_040 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3289 "asllib/Parser.ml"
       : ((string AST.annotated * Desugar.lhs_access) option list))
  
  let _menhir_action_041 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3297 "asllib/Parser.ml"
       : ((string AST.annotated * Desugar.lhs_access) option list))
  
  let _menhir_action_042 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3305 "asllib/Parser.ml"
       : (Desugar.lhs_field option list))
  
  let _menhir_action_043 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3313 "asllib/Parser.ml"
       : (Desugar.lhs_field option list))
  
  let _menhir_action_044 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3321 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_045 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3329 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_046 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3337 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_047 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3345 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_048 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3353 "asllib/Parser.ml"
       : ((string * AST.expr) list))
  
  let _menhir_action_049 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3361 "asllib/Parser.ml"
       : ((string * AST.expr) list))
  
  let _menhir_action_050 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3369 "asllib/Parser.ml"
       : (AST.int_constraint list))
  
  let _menhir_action_051 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3377 "asllib/Parser.ml"
       : (AST.int_constraint list))
  
  let _menhir_action_052 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3385 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_053 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3393 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_054 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3401 "asllib/Parser.ml"
       : (AST.pattern list))
  
  let _menhir_action_055 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3409 "asllib/Parser.ml"
       : (AST.pattern list))
  
  let _menhir_action_056 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3417 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_057 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3425 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_058 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3433 "asllib/Parser.ml"
       : (AST.ty list))
  
  let _menhir_action_059 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3441 "asllib/Parser.ml"
       : (AST.ty list))
  
  let _menhir_action_060 =
    fun x ->
      (
# 158 "asllib/Parser.mly"
         ( [ x ] )
# 3449 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_061 =
    fun _2 h t ->
      (
# 159 "asllib/Parser.mly"
                             ( h :: t )
# 3457 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_062 =
    fun _2 li x ->
      (
# 165 "asllib/Parser.mly"
                                           ( x :: li )
# 3465 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_063 =
    fun _2 _endpos_desc_ _startpos_desc_ desc li ->
      let x =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3476 "asllib/Parser.ml"
        
      in
      (
# 165 "asllib/Parser.mly"
                                           ( x :: li )
# 3482 "asllib/Parser.ml"
       : (string AST.annotated list))
  
  let _menhir_action_064 =
    fun _2 li x ->
      (
# 165 "asllib/Parser.mly"
                                           ( x :: li )
# 3490 "asllib/Parser.ml"
       : ((string AST.annotated * Desugar.lhs_access) option list))
  
  let _menhir_action_065 =
    fun _2 li x ->
      (
# 165 "asllib/Parser.mly"
                                           ( x :: li )
# 3498 "asllib/Parser.ml"
       : (Desugar.lhs_field option list))
  
  let _menhir_action_066 =
    fun _2 li x ->
      (
# 165 "asllib/Parser.mly"
                                           ( x :: li )
# 3506 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_067 =
    fun _2 li x ->
      (
# 165 "asllib/Parser.mly"
                                           ( x :: li )
# 3514 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_068 =
    fun _2 li x ->
      (
# 165 "asllib/Parser.mly"
                                           ( x :: li )
# 3522 "asllib/Parser.ml"
       : (AST.pattern list))
  
  let _menhir_action_069 =
    fun x ->
      let cs = 
# 205 "<standard.mly>"
    ( x )
# 3530 "asllib/Parser.ml"
       in
      (
# 294 "asllib/Parser.mly"
                                       ( WellConstrained (cs, Precision_Full) )
# 3535 "asllib/Parser.ml"
       : (AST.constraint_kind))
  
  let _menhir_action_070 =
    fun _endpos__3_ _startpos__1_ x ->
      let _1 = 
# 205 "<standard.mly>"
    ( x )
# 3543 "asllib/Parser.ml"
       in
      let _endpos__1_ = _endpos__3_ in
      let _endpos = _endpos__1_ in
      let _startpos = _startpos__1_ in
      (
# 295 "asllib/Parser.mly"
                   (
    if Config.allow_hyphenated_pending_constraint then PendingConstrained
      else Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Hyphenated pending constraint."
  )
# 3554 "asllib/Parser.ml"
       : (AST.constraint_kind))
  
  let _menhir_action_071 =
    fun _1 _2 ->
      (
# 299 "asllib/Parser.mly"
                    ( PendingConstrained )
# 3562 "asllib/Parser.ml"
       : (AST.constraint_kind))
  
  let _menhir_action_072 =
    fun _1 ->
      (_1 : (AST.constraint_kind))
  
  let _menhir_action_073 =
    fun () ->
      (
# 292 "asllib/Parser.mly"
                                             ( UnConstrained )
# 3574 "asllib/Parser.ml"
       : (AST.constraint_kind))
  
  let _menhir_action_074 =
    fun _1_inlined1 _2 _3 _endpos__2_ _startpos__3_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 3589 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 3595 "asllib/Parser.ml"
           in
          let qualifier = 
# 123 "<standard.mly>"
    ( None )
# 3600 "asllib/Parser.ml"
           in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 3618 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__3_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3627 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 3633 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_075 =
    fun _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_inlined1_ _startpos__3_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 3651 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 3657 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 3663 "asllib/Parser.ml"
           in
          let qualifier = 
# 123 "<standard.mly>"
    ( None )
# 3668 "asllib/Parser.ml"
           in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 3686 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__3_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3695 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 3701 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_076 =
    fun _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined2 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 3717 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 3724 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3729 "asllib/Parser.ml"
            
          in
          let qualifier = 
# 123 "<standard.mly>"
    ( None )
# 3735 "asllib/Parser.ml"
           in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 3753 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3762 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 3768 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_077 =
    fun _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 3787 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 3793 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 3800 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3805 "asllib/Parser.ml"
            
          in
          let qualifier = 
# 123 "<standard.mly>"
    ( None )
# 3811 "asllib/Parser.ml"
           in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 3829 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3838 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 3844 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_078 =
    fun _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined2 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 3860 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 3867 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3872 "asllib/Parser.ml"
            
          in
          let qualifier = 
# 123 "<standard.mly>"
    ( None )
# 3878 "asllib/Parser.ml"
           in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 3896 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3905 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 3911 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_079 =
    fun _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 3930 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 3936 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 3943 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 3948 "asllib/Parser.ml"
            
          in
          let qualifier = 
# 123 "<standard.mly>"
    ( None )
# 3954 "asllib/Parser.ml"
           in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 3972 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 3981 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 3987 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_080 =
    fun _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined2 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 4003 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 4009 "asllib/Parser.ml"
           in
          let qualifier =
            let x = 
# 615 "asllib/Parser.mly"
                ( Pure )
# 4015 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4020 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 4039 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4048 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 4054 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_081 =
    fun _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 4073 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 4079 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 4085 "asllib/Parser.ml"
           in
          let qualifier =
            let x = 
# 615 "asllib/Parser.mly"
                ( Pure )
# 4091 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4096 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 4115 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4124 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 4130 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_082 =
    fun _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined3 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 4146 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 4154 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4159 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 615 "asllib/Parser.mly"
                ( Pure )
# 4166 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4171 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 4190 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4199 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 4205 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_083 =
    fun _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 4224 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 4230 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 4238 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4243 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 615 "asllib/Parser.mly"
                ( Pure )
# 4250 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4255 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 4274 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4283 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 4289 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_084 =
    fun _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined3 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 4305 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 4313 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4318 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 615 "asllib/Parser.mly"
                ( Pure )
# 4325 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4330 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 4349 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4358 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 4364 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_085 =
    fun _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 4383 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 4389 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 4397 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4402 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 615 "asllib/Parser.mly"
                ( Pure )
# 4409 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4414 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 4433 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4442 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 4448 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_086 =
    fun _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined2 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 4464 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 4470 "asllib/Parser.ml"
           in
          let qualifier =
            let x = 
# 616 "asllib/Parser.mly"
                ( Readonly )
# 4476 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4481 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 4500 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4509 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 4515 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_087 =
    fun _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 4534 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 4540 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 4546 "asllib/Parser.ml"
           in
          let qualifier =
            let x = 
# 616 "asllib/Parser.mly"
                ( Readonly )
# 4552 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4557 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 4576 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4585 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 4591 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_088 =
    fun _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined3 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 4607 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 4615 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4620 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 616 "asllib/Parser.mly"
                ( Readonly )
# 4627 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4632 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 4651 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4660 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 4666 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_089 =
    fun _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 4685 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 4691 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 4699 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4704 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 616 "asllib/Parser.mly"
                ( Readonly )
# 4711 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4716 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 4735 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4744 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 4750 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_090 =
    fun _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined3 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 4766 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 4774 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4779 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 616 "asllib/Parser.mly"
                ( Readonly )
# 4786 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4791 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 4810 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4819 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 4825 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_091 =
    fun _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 4844 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 4850 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 4858 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4863 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 616 "asllib/Parser.mly"
                ( Readonly )
# 4870 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4875 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 4894 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4903 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 4909 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_092 =
    fun _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined2 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 4925 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 4931 "asllib/Parser.ml"
           in
          let qualifier =
            let x = 
# 617 "asllib/Parser.mly"
                ( Noreturn )
# 4937 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 4942 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 4961 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4970 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 4976 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_093 =
    fun _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 4995 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 5001 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 5007 "asllib/Parser.ml"
           in
          let qualifier =
            let x = 
# 617 "asllib/Parser.mly"
                ( Noreturn )
# 5013 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5018 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 5037 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5046 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 5052 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_094 =
    fun _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined3 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 5068 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 5076 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5081 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 617 "asllib/Parser.mly"
                ( Noreturn )
# 5088 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5093 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 5112 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5121 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 5127 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_095 =
    fun _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 5146 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 5152 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 5160 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5165 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 617 "asllib/Parser.mly"
                ( Noreturn )
# 5172 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5177 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 5196 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5205 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 5211 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_096 =
    fun _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined3 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 5227 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 5235 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5240 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 617 "asllib/Parser.mly"
                ( Noreturn )
# 5247 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5252 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 5271 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5280 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 5286 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_097 =
    fun _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt recurse_limit return_type x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 5305 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 5311 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 5319 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5324 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 617 "asllib/Parser.mly"
                ( Noreturn )
# 5331 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5336 "asllib/Parser.ml"
            
          in
          
# 640 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            qualifier;
            override;
            builtin = false;
          }
        )
# 5355 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5364 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 5370 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_098 =
    fun _1_inlined1 _2 _3 _endpos__2_ _startpos__3_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 5385 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 5391 "asllib/Parser.ml"
           in
          let qualifier = 
# 123 "<standard.mly>"
    ( None )
# 5396 "asllib/Parser.ml"
           in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 5414 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__3_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5423 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 5429 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_099 =
    fun _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_inlined1_ _startpos__3_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 5447 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 5453 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 5459 "asllib/Parser.ml"
           in
          let qualifier = 
# 123 "<standard.mly>"
    ( None )
# 5464 "asllib/Parser.ml"
           in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 5482 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__3_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5491 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 5497 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_100 =
    fun _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined2 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 5513 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 5520 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5525 "asllib/Parser.ml"
            
          in
          let qualifier = 
# 123 "<standard.mly>"
    ( None )
# 5531 "asllib/Parser.ml"
           in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 5549 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5558 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 5564 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_101 =
    fun _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 5583 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 5589 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 5596 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5601 "asllib/Parser.ml"
            
          in
          let qualifier = 
# 123 "<standard.mly>"
    ( None )
# 5607 "asllib/Parser.ml"
           in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 5625 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5634 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 5640 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_102 =
    fun _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined2 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 5656 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 5663 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5668 "asllib/Parser.ml"
            
          in
          let qualifier = 
# 123 "<standard.mly>"
    ( None )
# 5674 "asllib/Parser.ml"
           in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 5692 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5701 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 5707 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_103 =
    fun _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 5726 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 5732 "asllib/Parser.ml"
            
          in
          let override =
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 5739 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5744 "asllib/Parser.ml"
            
          in
          let qualifier = 
# 123 "<standard.mly>"
    ( None )
# 5750 "asllib/Parser.ml"
           in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 5768 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5777 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 5783 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_104 =
    fun _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined2 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 5799 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 5805 "asllib/Parser.ml"
           in
          let qualifier =
            let x = 
# 615 "asllib/Parser.mly"
                ( Pure )
# 5811 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5816 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 5835 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5844 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 5850 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_105 =
    fun _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 5869 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 5875 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 5881 "asllib/Parser.ml"
           in
          let qualifier =
            let x = 
# 615 "asllib/Parser.mly"
                ( Pure )
# 5887 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5892 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 5911 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5920 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 5926 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_106 =
    fun _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined3 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 5942 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 5950 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5955 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 615 "asllib/Parser.mly"
                ( Pure )
# 5962 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 5967 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 5986 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5995 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 6001 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_107 =
    fun _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 6020 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 6026 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 6034 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6039 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 615 "asllib/Parser.mly"
                ( Pure )
# 6046 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6051 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 6070 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6079 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 6085 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_108 =
    fun _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined3 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 6101 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 6109 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6114 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 615 "asllib/Parser.mly"
                ( Pure )
# 6121 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6126 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 6145 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6154 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 6160 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_109 =
    fun _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 6179 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 6185 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 6193 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6198 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 615 "asllib/Parser.mly"
                ( Pure )
# 6205 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6210 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 6229 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6238 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 6244 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_110 =
    fun _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined2 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 6260 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 6266 "asllib/Parser.ml"
           in
          let qualifier =
            let x = 
# 616 "asllib/Parser.mly"
                ( Readonly )
# 6272 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6277 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 6296 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6305 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 6311 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_111 =
    fun _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 6330 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 6336 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 6342 "asllib/Parser.ml"
           in
          let qualifier =
            let x = 
# 616 "asllib/Parser.mly"
                ( Readonly )
# 6348 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6353 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 6372 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6381 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 6387 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_112 =
    fun _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined3 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 6403 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 6411 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6416 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 616 "asllib/Parser.mly"
                ( Readonly )
# 6423 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6428 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 6447 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6456 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 6462 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_113 =
    fun _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 6481 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 6487 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 6495 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6500 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 616 "asllib/Parser.mly"
                ( Readonly )
# 6507 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6512 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 6531 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6540 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 6546 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_114 =
    fun _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined3 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 6562 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 6570 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6575 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 616 "asllib/Parser.mly"
                ( Readonly )
# 6582 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6587 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 6606 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6615 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 6621 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_115 =
    fun _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 6640 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 6646 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 6654 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6659 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 616 "asllib/Parser.mly"
                ( Readonly )
# 6666 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6671 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 6690 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6699 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 6705 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_116 =
    fun _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined2 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 6721 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 6727 "asllib/Parser.ml"
           in
          let qualifier =
            let x = 
# 617 "asllib/Parser.mly"
                ( Noreturn )
# 6733 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6738 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 6757 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6766 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 6772 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_117 =
    fun _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 6791 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 6797 "asllib/Parser.ml"
            
          in
          let override = 
# 123 "<standard.mly>"
    ( None )
# 6803 "asllib/Parser.ml"
           in
          let qualifier =
            let x = 
# 617 "asllib/Parser.mly"
                ( Noreturn )
# 6809 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6814 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 6833 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6842 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 6848 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_118 =
    fun _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined3 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 6864 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 6872 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6877 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 617 "asllib/Parser.mly"
                ( Noreturn )
# 6884 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6889 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 6908 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6917 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 6923 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_119 =
    fun _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 6942 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 6948 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 6956 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6961 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 617 "asllib/Parser.mly"
                ( Noreturn )
# 6968 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 6973 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 6992 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7001 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7007 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_120 =
    fun _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined3 in
            let _3 =
              let _1 = _1_inlined1 in
              ()
            in
            
# 205 "<standard.mly>"
    ( x )
# 7023 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 7031 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 7036 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 617 "asllib/Parser.mly"
                ( Noreturn )
# 7043 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 7048 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 7067 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7076 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7082 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_121 =
    fun _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt x ->
      let d =
        let desc =
          let body =
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) in
            let _3 =
              let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
              let _endpos = _endpos__1_ in
              let _startpos = _startpos__1_ in
              
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7101 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 7107 "asllib/Parser.ml"
            
          in
          let override =
            let _1 = _1_inlined1 in
            let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 7115 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 7120 "asllib/Parser.ml"
            
          in
          let qualifier =
            let x = 
# 617 "asllib/Parser.mly"
                ( Noreturn )
# 7127 "asllib/Parser.ml"
             in
            
# 126 "<standard.mly>"
    ( Some x )
# 7132 "asllib/Parser.ml"
            
          in
          
# 657 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier;
            override;
            builtin = false;
          }
        )
# 7151 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7160 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7166 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_122 =
    fun _1 _3 _endpos__2_ _startpos__1_ subtype_opt t x ->
      let d =
        let desc =
          let x = 
# 674 "asllib/Parser.mly"
                                                            D_TypeDecl            
# 7176 "asllib/Parser.ml"
           (x, t, subtype_opt) in
          
# 196 "<standard.mly>"
    ( x )
# 7181 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7190 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7196 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_123 =
    fun _1 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc x ->
      let d =
        let desc =
          let x =
            let s =
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7210 "asllib/Parser.ml"
              
            in
            
# 677 "asllib/Parser.mly"
                                                            make_ty_decl_subtype  
# 7216 "asllib/Parser.ml"
             (x, s)
          in
          
# 196 "<standard.mly>"
    ( x )
# 7222 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7231 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7237 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_124 =
    fun _1 _4 _endpos__2_ _startpos__1_ name x ->
      let d =
        let desc =
          let x =
            let initial_value = 
# 144 "asllib/Parser.mly"
                        Some 
# 7248 "asllib/Parser.ml"
             x in
            let ty = 
# 123 "<standard.mly>"
    ( None )
# 7253 "asllib/Parser.ml"
             in
            let keyword = 
# 492 "asllib/Parser.mly"
                ( GDK_Let      )
# 7258 "asllib/Parser.ml"
             in
            
# 682 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 7263 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 7269 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7278 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7284 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_125 =
    fun _1 _4 _endpos__2_ _startpos__1_ name x x_inlined1 ->
      let d =
        let desc =
          let x =
            let initial_value =
              let x = x_inlined1 in
              
# 144 "asllib/Parser.mly"
                        Some 
# 7297 "asllib/Parser.ml"
               x
            in
            let ty = 
# 126 "<standard.mly>"
    ( Some x )
# 7303 "asllib/Parser.ml"
             in
            let keyword = 
# 492 "asllib/Parser.mly"
                ( GDK_Let      )
# 7308 "asllib/Parser.ml"
             in
            
# 682 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 7313 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 7319 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7328 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7334 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_126 =
    fun _1 _4 _endpos__2_ _startpos__1_ name x ->
      let d =
        let desc =
          let x =
            let initial_value = 
# 144 "asllib/Parser.mly"
                        Some 
# 7345 "asllib/Parser.ml"
             x in
            let ty = 
# 123 "<standard.mly>"
    ( None )
# 7350 "asllib/Parser.ml"
             in
            let keyword = 
# 493 "asllib/Parser.mly"
                ( GDK_Constant )
# 7355 "asllib/Parser.ml"
             in
            
# 682 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 7360 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 7366 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7375 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7381 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_127 =
    fun _1 _4 _endpos__2_ _startpos__1_ name x x_inlined1 ->
      let d =
        let desc =
          let x =
            let initial_value =
              let x = x_inlined1 in
              
# 144 "asllib/Parser.mly"
                        Some 
# 7394 "asllib/Parser.ml"
               x
            in
            let ty = 
# 126 "<standard.mly>"
    ( Some x )
# 7400 "asllib/Parser.ml"
             in
            let keyword = 
# 493 "asllib/Parser.mly"
                ( GDK_Constant )
# 7405 "asllib/Parser.ml"
             in
            
# 682 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 7410 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 7416 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7425 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7431 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_128 =
    fun _1 _4 _endpos__2_ _startpos__1_ name x ->
      let d =
        let desc =
          let x =
            let initial_value = 
# 144 "asllib/Parser.mly"
                        Some 
# 7442 "asllib/Parser.ml"
             x in
            let ty = 
# 123 "<standard.mly>"
    ( None )
# 7447 "asllib/Parser.ml"
             in
            let keyword = 
# 494 "asllib/Parser.mly"
                ( GDK_Var )
# 7452 "asllib/Parser.ml"
             in
            
# 682 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 7457 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 7463 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7472 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7478 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_129 =
    fun _1 _4 _endpos__2_ _startpos__1_ name x x_inlined1 ->
      let d =
        let desc =
          let x =
            let initial_value =
              let x = x_inlined1 in
              
# 144 "asllib/Parser.mly"
                        Some 
# 7491 "asllib/Parser.ml"
               x
            in
            let ty = 
# 126 "<standard.mly>"
    ( Some x )
# 7497 "asllib/Parser.ml"
             in
            let keyword = 
# 494 "asllib/Parser.mly"
                ( GDK_Var )
# 7502 "asllib/Parser.ml"
             in
            
# 682 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 7507 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 7513 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7522 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7528 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_130 =
    fun _1 _4 _endpos__2_ _startpos__1_ name ty x ->
      let d =
        let desc =
          let x =
            let initial_value = 
# 144 "asllib/Parser.mly"
                        Some 
# 7539 "asllib/Parser.ml"
             x in
            
# 685 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword=GDK_Config; name; ty=Some ty; initial_value } )
# 7544 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 7550 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7559 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7565 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_131 =
    fun _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc name ty ->
      let d =
        let desc =
          let x =
            let call =
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7579 "asllib/Parser.ml"
              
            in
            let keyword = 
# 492 "asllib/Parser.mly"
                ( GDK_Let      )
# 7585 "asllib/Parser.ml"
             in
            
# 688 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty=Some ty; initial_value=desugar_elided_parameter ty call } )
# 7590 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 7596 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7605 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7611 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_132 =
    fun _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc name ty ->
      let d =
        let desc =
          let x =
            let call =
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7625 "asllib/Parser.ml"
              
            in
            let keyword = 
# 493 "asllib/Parser.mly"
                ( GDK_Constant )
# 7631 "asllib/Parser.ml"
             in
            
# 688 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty=Some ty; initial_value=desugar_elided_parameter ty call } )
# 7636 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 7642 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7651 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7657 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_133 =
    fun _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc name ty ->
      let d =
        let desc =
          let x =
            let call =
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7671 "asllib/Parser.ml"
              
            in
            let keyword = 
# 494 "asllib/Parser.mly"
                ( GDK_Var )
# 7677 "asllib/Parser.ml"
             in
            
# 688 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty=Some ty; initial_value=desugar_elided_parameter ty call } )
# 7682 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 7688 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7697 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7703 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_134 =
    fun _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc name ty ->
      let d =
        let desc =
          let x =
            let call =
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7717 "asllib/Parser.ml"
              
            in
            let keyword = 
# 498 "asllib/Parser.mly"
            ( GDK_Config )
# 7723 "asllib/Parser.ml"
             in
            
# 688 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty=Some ty; initial_value=desugar_elided_parameter ty call } )
# 7728 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 7734 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7743 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7749 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_135 =
    fun _1 _3 _endpos__2_ _startpos__1_ name x ->
      let d =
        let desc =
          let x =
            let ty = 
# 144 "asllib/Parser.mly"
                        Some 
# 7760 "asllib/Parser.ml"
             x in
            
# 692 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword=GDK_Var; name; ty; initial_value=None})
# 7765 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 7771 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7780 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7786 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_136 =
    fun _1 _endpos__2_ _startpos__1_ e x ->
      let d =
        let desc =
          let x = 
# 695 "asllib/Parser.mly"
                                                D_Pragma  
# 7796 "asllib/Parser.ml"
           (x, e) in
          
# 196 "<standard.mly>"
    ( x )
# 7801 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7810 "asllib/Parser.ml"
        
      in
      (
# 698 "asllib/Parser.mly"
     ( [d] )
# 7816 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_137 =
    fun _1 _1_inlined1 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let _2 = _2_inlined1 in
        let _3 =
          let _1 = _1_inlined1 in
          ()
        in
        
# 704 "asllib/Parser.mly"
  ( accessors )
# 7830 "asllib/Parser.ml"
        
      in
      let override = 
# 123 "<standard.mly>"
    ( None )
# 7836 "asllib/Parser.ml"
       in
      (
# 701 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 7841 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_138 =
    fun _1 _1_inlined1 _2 _6 _endpos__1_inlined1_ _startpos__1_inlined1_ accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let _3 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7857 "asllib/Parser.ml"
          
        in
        
# 704 "asllib/Parser.mly"
  ( accessors )
# 7863 "asllib/Parser.ml"
        
      in
      let override = 
# 123 "<standard.mly>"
    ( None )
# 7869 "asllib/Parser.ml"
       in
      (
# 701 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 7874 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_139 =
    fun _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let (_2, _1_inlined1, _1) = (_2_inlined1, _1_inlined2, _1_inlined1) in
        let _3 =
          let _1 = _1_inlined1 in
          ()
        in
        
# 704 "asllib/Parser.mly"
  ( accessors )
# 7888 "asllib/Parser.ml"
        
      in
      let override =
        let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 7895 "asllib/Parser.ml"
         in
        
# 126 "<standard.mly>"
    ( Some x )
# 7900 "asllib/Parser.ml"
        
      in
      (
# 701 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 7906 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_140 =
    fun _1 _1_inlined1 _1_inlined2 _2 _6 _endpos__1_inlined2_ _startpos__1_inlined2_ accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2, _1_inlined1) in
        let _3 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7923 "asllib/Parser.ml"
          
        in
        
# 704 "asllib/Parser.mly"
  ( accessors )
# 7929 "asllib/Parser.ml"
        
      in
      let override =
        let x = 
# 625 "asllib/Parser.mly"
              ( Impdef )
# 7936 "asllib/Parser.ml"
         in
        
# 126 "<standard.mly>"
    ( Some x )
# 7941 "asllib/Parser.ml"
        
      in
      (
# 701 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 7947 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_141 =
    fun _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let (_2, _1_inlined1, _1) = (_2_inlined1, _1_inlined2, _1_inlined1) in
        let _3 =
          let _1 = _1_inlined1 in
          ()
        in
        
# 704 "asllib/Parser.mly"
  ( accessors )
# 7961 "asllib/Parser.ml"
        
      in
      let override =
        let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 7968 "asllib/Parser.ml"
         in
        
# 126 "<standard.mly>"
    ( Some x )
# 7973 "asllib/Parser.ml"
        
      in
      (
# 701 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 7979 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_142 =
    fun _1 _1_inlined1 _1_inlined2 _2 _6 _endpos__1_inlined2_ _startpos__1_inlined2_ accessors as_ty func_args name params_opt setter_arg ->
      let accessor_body =
        let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2, _1_inlined1) in
        let _3 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 7996 "asllib/Parser.ml"
          
        in
        
# 704 "asllib/Parser.mly"
  ( accessors )
# 8002 "asllib/Parser.ml"
        
      in
      let override =
        let x = 
# 626 "asllib/Parser.mly"
                      ( Implementation )
# 8009 "asllib/Parser.ml"
         in
        
# 126 "<standard.mly>"
    ( Some x )
# 8014 "asllib/Parser.ml"
        
      in
      (
# 701 "asllib/Parser.mly"
    ( desugar_accessor_pair override name params_opt func_args setter_arg as_ty accessor_body )
# 8020 "asllib/Parser.ml"
       : (AST.decl list))
  
  let _menhir_action_143 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let _endpos = _endpos__1_ in
      let _startpos = _startpos__1_ in
      (
# 468 "asllib/Parser.mly"
                                       (
      if Config.allow_storage_discards then LDI_Var (local_ignored ())
      else Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Discarded storage declaration."
    )
# 8033 "asllib/Parser.ml"
       : (AST.local_decl_item))
  
  let _menhir_action_144 =
    fun _1 ->
      let _1_1 = _1 in
      (
# 472 "asllib/Parser.mly"
                                         LDI_Var  
# 8042 "asllib/Parser.ml"
       _1_1 : (AST.local_decl_item))
  
  let _menhir_action_145 =
    fun _endpos__3_ _startpos__1_ x ->
      let vs = 
# 205 "<standard.mly>"
    ( x )
# 8050 "asllib/Parser.ml"
       in
      let (_endpos_vs_, _startpos_vs_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_vs_ in
      let _startpos = _startpos_vs_ in
      (
# 473 "asllib/Parser.mly"
                                       (
      if List.for_all is_local_ignored vs && not Config.allow_storage_discards then
        Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Discarded storage declaration."
      else LDI_Tuple vs
    )
# 8062 "asllib/Parser.ml"
       : (AST.local_decl_item))
  
  let _menhir_action_146 =
    fun _1 ->
      (
# 502 "asllib/Parser.mly"
                       ( AST.Up )
# 8070 "asllib/Parser.ml"
       : (AST.for_direction))
  
  let _menhir_action_147 =
    fun _1 ->
      (
# 502 "asllib/Parser.mly"
                                            ( AST.Down )
# 8078 "asllib/Parser.ml"
       : (AST.for_direction))
  
  let _menhir_action_148 =
    fun _1 ->
      (
# 441 "asllib/Parser.mly"
                          ( None )
# 8086 "asllib/Parser.ml"
       : ((string AST.annotated * Desugar.lhs_access) option))
  
  let _menhir_action_149 =
    fun basic_lexpr ->
      (
# 442 "asllib/Parser.mly"
                            Some  
# 8094 "asllib/Parser.ml"
       basic_lexpr : ((string AST.annotated * Desugar.lhs_access) option))
  
  let _menhir_action_150 =
    fun _1 ->
      (
# 445 "asllib/Parser.mly"
                             ( None )
# 8102 "asllib/Parser.ml"
       : (Desugar.lhs_field option))
  
  let _menhir_action_151 =
    fun _endpos_desc_ _startpos_desc_ desc ->
      let _1 =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8113 "asllib/Parser.ml"
        
      in
      let _1_1 = _1 in
      (
# 446 "asllib/Parser.mly"
                               Some  
# 8120 "asllib/Parser.ml"
       _1_1 : (Desugar.lhs_field option))
  
  let _menhir_action_152 =
    fun _1 ->
      (
# 464 "asllib/Parser.mly"
                   ( local_ignored () )
# 8128 "asllib/Parser.ml"
       : (string))
  
  let _menhir_action_153 =
    fun _1 ->
      (_1 : (string))
  
  let _menhir_action_154 =
    fun _1 _2 ->
      (_2 : (AST.expr))
  
  let _menhir_action_155 =
    fun _1 _3 _endpos_e2_ _startpos__1_ c e1 e2 ->
      let desc =
        let _endpos = _endpos_e2_ in
        let _startpos = _startpos__1_ in
        
# 248 "asllib/Parser.mly"
                                                                          (
      if Config.allow_expression_elsif then E_Cond (c, e1, e2)
      else Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Expression-level 'elsif'."
    )
# 8150 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8159 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_156 =
    fun _2 _3 name ->
      let args = 
# 591 "asllib/Parser.mly"
                     ( [] )
# 8167 "asllib/Parser.ml"
       in
      (
# 599 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 8172 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_157 =
    fun _2 _3 name x ->
      let args = 
# 205 "<standard.mly>"
    ( x )
# 8180 "asllib/Parser.ml"
       in
      (
# 599 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 8185 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_158 =
    fun _2 _3 _5 name params ->
      let args = 
# 591 "asllib/Parser.mly"
                     ( [] )
# 8193 "asllib/Parser.ml"
       in
      (
# 601 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 8198 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_159 =
    fun _2 _3 _5 name params x ->
      let args = 
# 205 "<standard.mly>"
    ( x )
# 8206 "asllib/Parser.ml"
       in
      (
# 601 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 8211 "asllib/Parser.ml"
       : (AST.call))
  
  let _menhir_action_160 =
    fun _endpos_value_ _startpos_value_ value ->
      let desc = 
# 257 "asllib/Parser.mly"
                                                                    E_Literal             
# 8219 "asllib/Parser.ml"
       value in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_value_, _startpos_value_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8227 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_161 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let _1_1 = _1 in
        
# 258 "asllib/Parser.mly"
                                                                    E_Var                 
# 8237 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8246 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_162 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 213 "asllib/Parser.mly"
                  ( `AND    )
# 8255 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8260 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8269 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_163 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 214 "asllib/Parser.mly"
                  ( `BAND   )
# 8278 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8283 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8292 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_164 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 215 "asllib/Parser.mly"
                  ( `BOR    )
# 8301 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8306 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8315 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_165 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 216 "asllib/Parser.mly"
                  ( `BEQ    )
# 8324 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8329 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8338 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_166 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 217 "asllib/Parser.mly"
                  ( `DIV    )
# 8347 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8352 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8361 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_167 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 218 "asllib/Parser.mly"
                  ( `DIVRM  )
# 8370 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8375 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8384 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_168 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 219 "asllib/Parser.mly"
                  ( `XOR    )
# 8393 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8398 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8407 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_169 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 220 "asllib/Parser.mly"
                  ( `EQ_OP  )
# 8416 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8421 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8430 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_170 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 221 "asllib/Parser.mly"
                  ( `NEQ    )
# 8439 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8444 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8453 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_171 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 222 "asllib/Parser.mly"
                  ( `GT     )
# 8462 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8467 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8476 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_172 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 223 "asllib/Parser.mly"
                  ( `GEQ    )
# 8485 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8490 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8499 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_173 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 224 "asllib/Parser.mly"
                  ( `IMPL   )
# 8508 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8513 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8522 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_174 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 225 "asllib/Parser.mly"
                  ( `LT     )
# 8531 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8536 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8545 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_175 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 226 "asllib/Parser.mly"
                  ( `LEQ    )
# 8554 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8559 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8568 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_176 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 227 "asllib/Parser.mly"
                  ( `PLUS   )
# 8577 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8582 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8591 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_177 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 228 "asllib/Parser.mly"
                  ( `MINUS  )
# 8600 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8605 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8614 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_178 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 229 "asllib/Parser.mly"
                  ( `MOD    )
# 8623 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8628 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8637 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_179 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 230 "asllib/Parser.mly"
                  ( `MUL    )
# 8646 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8651 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8660 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_180 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 231 "asllib/Parser.mly"
                  ( `OR     )
# 8669 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8674 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8683 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_181 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 232 "asllib/Parser.mly"
                  ( `RDIV   )
# 8692 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8697 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8706 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_182 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 233 "asllib/Parser.mly"
                  ( `SHL    )
# 8715 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8720 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8729 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_183 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 234 "asllib/Parser.mly"
                  ( `SHR    )
# 8738 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8743 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8752 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_184 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 235 "asllib/Parser.mly"
                  ( `POW    )
# 8761 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8766 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8775 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_185 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 236 "asllib/Parser.mly"
                  ( `CONCAT )
# 8784 "asllib/Parser.ml"
         in
        
# 259 "asllib/Parser.mly"
                                                                e_binop               
# 8789 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8798 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_186 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 208 "asllib/Parser.mly"
            ( BNOT )
# 8807 "asllib/Parser.ml"
         in
        
# 260 "asllib/Parser.mly"
                                                                    E_Unop                
# 8812 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8821 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_187 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 209 "asllib/Parser.mly"
            ( NEG )
# 8830 "asllib/Parser.ml"
         in
        
# 260 "asllib/Parser.mly"
                                                                    E_Unop                
# 8835 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8844 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_188 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 210 "asllib/Parser.mly"
            ( NOT )
# 8853 "asllib/Parser.ml"
         in
        
# 260 "asllib/Parser.mly"
                                                                    E_Unop                
# 8858 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8867 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_189 =
    fun _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else ->
      let desc = 
# 261 "asllib/Parser.mly"
                                                                    E_Cond                
# 8875 "asllib/Parser.ml"
       (e1, e2, e_else) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_else_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8883 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_190 =
    fun _endpos_call_ _startpos_call_ call ->
      let desc = 
# 262 "asllib/Parser.mly"
                                                                    e_call                
# 8891 "asllib/Parser.ml"
       call in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_call_, _startpos_call_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8899 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_191 =
    fun _endpos_slices_ _startpos_e_ e slices ->
      let desc = 
# 263 "asllib/Parser.mly"
                                                                E_Slice               
# 8907 "asllib/Parser.ml"
       (e, slices) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_slices_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8915 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_192 =
    fun _2 _4 _endpos__4_ _startpos_e1_ e1 e2 ->
      let desc = 
# 264 "asllib/Parser.mly"
                                                                E_GetArray            
# 8923 "asllib/Parser.ml"
       (e1, e2) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__4_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8931 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_193 =
    fun _2 _endpos_x_ _startpos_e_ e x ->
      let desc = 
# 265 "asllib/Parser.mly"
                                                                E_GetField            
# 8939 "asllib/Parser.ml"
       (e, x) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_x_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8947 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_194 =
    fun _2 _endpos__3_ _startpos_e_ e x ->
      let desc =
        let fs = 
# 205 "<standard.mly>"
    ( x )
# 8956 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                E_GetFields           
# 8961 "asllib/Parser.ml"
         (e, fs)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8970 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_195 =
    fun _2 _endpos_ty_ _startpos_expr_ expr ty ->
      let desc = 
# 268 "asllib/Parser.mly"
                                                                E_ATC                 
# 8978 "asllib/Parser.ml"
       (expr, ty) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8986 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_196 =
    fun _2 _endpos_constraint_kind_ _startpos_constraint_kind_ _startpos_expr_ constraint_kind expr ->
      let desc =
        let implicit_t_int =
          let desc = 
# 419 "asllib/Parser.mly"
                                                       T_Int 
# 8996 "asllib/Parser.ml"
           constraint_kind in
          let (_endpos_desc_, _startpos_desc_) = (_endpos_constraint_kind_, _startpos_constraint_kind_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9004 "asllib/Parser.ml"
          
        in
        
# 269 "asllib/Parser.mly"
                                                                E_ATC                 
# 9010 "asllib/Parser.ml"
         (expr, implicit_t_int)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_constraint_kind_, _startpos_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9019 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_197 =
    fun _2 _endpos_pattern_set_ _startpos_expr_ expr pattern_set ->
      let desc = 
# 271 "asllib/Parser.mly"
                                                                E_Pattern             
# 9027 "asllib/Parser.ml"
       (expr, pattern_set) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_pattern_set_, _startpos_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9035 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_198 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_expr_ expr ->
      let desc =
        let pattern_mask =
          let desc =
            let _1_1 = _1 in
            
# 336 "asllib/Parser.mly"
                                            Pattern_Mask  
# 9047 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9056 "asllib/Parser.ml"
          
        in
        
# 272 "asllib/Parser.mly"
                                                                E_Pattern             
# 9062 "asllib/Parser.ml"
         (expr, pattern_mask)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9071 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_199 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e ->
      let desc =
        let p =
          let desc =
            let _1_1 = _1 in
            
# 336 "asllib/Parser.mly"
                                            Pattern_Mask  
# 9083 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9092 "asllib/Parser.ml"
          
        in
        
# 273 "asllib/Parser.mly"
                                                              ( E_Pattern (e, Pattern_Not (p) |> add_pos_from p) )
# 9098 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9107 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_200 =
    fun _1 _2 _endpos_ty_ _startpos__1_ ty ->
      let desc = 
# 274 "asllib/Parser.mly"
                                                                E_Arbitrary         
# 9115 "asllib/Parser.ml"
       ty in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9123 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_201 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let e = 
# 205 "<standard.mly>"
    ( x )
# 9132 "asllib/Parser.ml"
         in
        
# 275 "asllib/Parser.mly"
                                                              ( E_Tuple [ e ]        )
# 9137 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9146 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_202 =
    fun _2 _3 _4 _endpos__4_ _endpos_desc_ _startpos_desc_ desc ->
      let desc =
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9158 "asllib/Parser.ml"
          
        in
        
# 277 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), []) )
# 9164 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__4_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9173 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_203 =
    fun _endpos__3_ _endpos_desc_ _startpos_desc_ desc x ->
      let desc =
        let fields = 
# 205 "<standard.mly>"
    ( x )
# 9182 "asllib/Parser.ml"
         in
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9190 "asllib/Parser.ml"
          
        in
        
# 279 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), fields) )
# 9196 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9205 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_204 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let _1 = 
# 205 "<standard.mly>"
    ( x )
# 9214 "asllib/Parser.ml"
         in
        let _1_1 = _1 in
        
# 281 "asllib/Parser.mly"
                                                                    E_Tuple               
# 9220 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9229 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_205 =
    fun _endpos_value_ _startpos_value_ value ->
      let desc = 
# 310 "asllib/Parser.mly"
                                                                    E_Literal             
# 9237 "asllib/Parser.ml"
       value in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_value_, _startpos_value_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9245 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_206 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let _1_1 = _1 in
        
# 311 "asllib/Parser.mly"
                                                                    E_Var                 
# 9255 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9264 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_207 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 213 "asllib/Parser.mly"
                  ( `AND    )
# 9273 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9278 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9287 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_208 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 214 "asllib/Parser.mly"
                  ( `BAND   )
# 9296 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9301 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9310 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_209 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 215 "asllib/Parser.mly"
                  ( `BOR    )
# 9319 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9324 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9333 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_210 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 216 "asllib/Parser.mly"
                  ( `BEQ    )
# 9342 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9347 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9356 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_211 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 217 "asllib/Parser.mly"
                  ( `DIV    )
# 9365 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9370 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9379 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_212 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 218 "asllib/Parser.mly"
                  ( `DIVRM  )
# 9388 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9393 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9402 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_213 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 219 "asllib/Parser.mly"
                  ( `XOR    )
# 9411 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9416 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9425 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_214 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 220 "asllib/Parser.mly"
                  ( `EQ_OP  )
# 9434 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9439 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9448 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_215 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 221 "asllib/Parser.mly"
                  ( `NEQ    )
# 9457 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9462 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9471 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_216 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 222 "asllib/Parser.mly"
                  ( `GT     )
# 9480 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9485 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9494 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_217 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 223 "asllib/Parser.mly"
                  ( `GEQ    )
# 9503 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9508 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9517 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_218 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 224 "asllib/Parser.mly"
                  ( `IMPL   )
# 9526 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9531 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9540 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_219 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 225 "asllib/Parser.mly"
                  ( `LT     )
# 9549 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9554 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9563 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_220 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 226 "asllib/Parser.mly"
                  ( `LEQ    )
# 9572 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9577 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9586 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_221 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 227 "asllib/Parser.mly"
                  ( `PLUS   )
# 9595 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9600 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9609 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_222 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 228 "asllib/Parser.mly"
                  ( `MINUS  )
# 9618 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9623 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9632 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_223 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 229 "asllib/Parser.mly"
                  ( `MOD    )
# 9641 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9646 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9655 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_224 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 230 "asllib/Parser.mly"
                  ( `MUL    )
# 9664 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9669 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9678 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_225 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 231 "asllib/Parser.mly"
                  ( `OR     )
# 9687 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9692 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9701 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_226 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 232 "asllib/Parser.mly"
                  ( `RDIV   )
# 9710 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9715 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9724 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_227 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 233 "asllib/Parser.mly"
                  ( `SHL    )
# 9733 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9738 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9747 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_228 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 234 "asllib/Parser.mly"
                  ( `SHR    )
# 9756 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9761 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9770 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_229 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 235 "asllib/Parser.mly"
                  ( `POW    )
# 9779 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9784 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9793 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_230 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 236 "asllib/Parser.mly"
                  ( `CONCAT )
# 9802 "asllib/Parser.ml"
         in
        
# 312 "asllib/Parser.mly"
                                                                        e_binop               
# 9807 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9816 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_231 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 208 "asllib/Parser.mly"
            ( BNOT )
# 9825 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                    E_Unop                
# 9830 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9839 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_232 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 209 "asllib/Parser.mly"
            ( NEG )
# 9848 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                    E_Unop                
# 9853 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9862 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_233 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 210 "asllib/Parser.mly"
            ( NOT )
# 9871 "asllib/Parser.ml"
         in
        
# 313 "asllib/Parser.mly"
                                                                    E_Unop                
# 9876 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9885 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_234 =
    fun _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else ->
      let desc = 
# 314 "asllib/Parser.mly"
                                                                    E_Cond                
# 9893 "asllib/Parser.ml"
       (e1, e2, e_else) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_else_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9901 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_235 =
    fun _endpos_call_ _startpos_call_ call ->
      let desc = 
# 315 "asllib/Parser.mly"
                                                                    e_call                
# 9909 "asllib/Parser.ml"
       call in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_call_, _startpos_call_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9917 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_236 =
    fun _endpos_slices_ _startpos_e_ e slices ->
      let desc = 
# 316 "asllib/Parser.mly"
                                                                        E_Slice               
# 9925 "asllib/Parser.ml"
       (e, slices) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_slices_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9933 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_237 =
    fun _2 _4 _endpos__4_ _startpos_e1_ e1 e2 ->
      let desc = 
# 317 "asllib/Parser.mly"
                                                                        E_GetArray            
# 9941 "asllib/Parser.ml"
       (e1, e2) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__4_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9949 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_238 =
    fun _2 _endpos_x_ _startpos_e_ e x ->
      let desc = 
# 318 "asllib/Parser.mly"
                                                                        E_GetField            
# 9957 "asllib/Parser.ml"
       (e, x) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_x_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9965 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_239 =
    fun _2 _endpos__3_ _startpos_e_ e x ->
      let desc =
        let fs = 
# 205 "<standard.mly>"
    ( x )
# 9974 "asllib/Parser.ml"
         in
        
# 319 "asllib/Parser.mly"
                                                                        E_GetFields           
# 9979 "asllib/Parser.ml"
         (e, fs)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9988 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_240 =
    fun _2 _endpos_ty_ _startpos_expr_pattern_ expr_pattern ty ->
      let desc = 
# 321 "asllib/Parser.mly"
                                                                        E_ATC                 
# 9996 "asllib/Parser.ml"
       (expr_pattern, ty) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10004 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_241 =
    fun _2 _endpos_constraint_kind_ _startpos_constraint_kind_ _startpos_expr_pattern_ constraint_kind expr_pattern ->
      let desc =
        let implicit_t_int =
          let desc = 
# 419 "asllib/Parser.mly"
                                                       T_Int 
# 10014 "asllib/Parser.ml"
           constraint_kind in
          let (_endpos_desc_, _startpos_desc_) = (_endpos_constraint_kind_, _startpos_constraint_kind_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10022 "asllib/Parser.ml"
          
        in
        
# 322 "asllib/Parser.mly"
                                                                        E_ATC                 
# 10028 "asllib/Parser.ml"
         (expr_pattern, implicit_t_int)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_constraint_kind_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10037 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_242 =
    fun _2 _endpos_pattern_set_ _startpos_expr_pattern_ expr_pattern pattern_set ->
      let desc = 
# 324 "asllib/Parser.mly"
                                                                        E_Pattern             
# 10045 "asllib/Parser.ml"
       (expr_pattern, pattern_set) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_pattern_set_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10053 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_243 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_expr_pattern_ expr_pattern ->
      let desc =
        let pattern_mask =
          let desc =
            let _1_1 = _1 in
            
# 336 "asllib/Parser.mly"
                                            Pattern_Mask  
# 10065 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10074 "asllib/Parser.ml"
          
        in
        
# 325 "asllib/Parser.mly"
                                                                        E_Pattern             
# 10080 "asllib/Parser.ml"
         (expr_pattern, pattern_mask)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10089 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_244 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e ->
      let desc =
        let p =
          let desc =
            let _1_1 = _1 in
            
# 336 "asllib/Parser.mly"
                                            Pattern_Mask  
# 10101 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10110 "asllib/Parser.ml"
          
        in
        
# 326 "asllib/Parser.mly"
                                                                      ( E_Pattern (e, Pattern_Not (p) |> add_pos_from p) )
# 10116 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10125 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_245 =
    fun _1 _2 _endpos_ty_ _startpos__1_ ty ->
      let desc = 
# 328 "asllib/Parser.mly"
                                                                        E_Arbitrary         
# 10133 "asllib/Parser.ml"
       ty in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10141 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_246 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let e = 
# 205 "<standard.mly>"
    ( x )
# 10150 "asllib/Parser.ml"
         in
        
# 329 "asllib/Parser.mly"
                                                                      ( E_Tuple [ e ]        )
# 10155 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10164 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_247 =
    fun _2 _3 _4 _endpos__4_ _endpos_desc_ _startpos_desc_ desc ->
      let desc =
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10176 "asllib/Parser.ml"
          
        in
        
# 331 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), []) )
# 10182 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__4_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10191 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_248 =
    fun _endpos__3_ _endpos_desc_ _startpos_desc_ desc x ->
      let desc =
        let fields = 
# 205 "<standard.mly>"
    ( x )
# 10200 "asllib/Parser.ml"
         in
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10208 "asllib/Parser.ml"
          
        in
        
# 333 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), fields) )
# 10214 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10223 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_249 =
    fun x y ->
      (
# 180 "<standard.mly>"
    ( (x, y) )
# 10231 "asllib/Parser.ml"
       : (string * AST.expr))
  
  let _menhir_action_250 =
    fun x ->
      let _1 = 
# 205 "<standard.mly>"
    ( x )
# 10239 "asllib/Parser.ml"
       in
      (
# 358 "asllib/Parser.mly"
                   ( [] )
# 10244 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_251 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 10252 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_252 =
    fun () ->
      (
# 360 "asllib/Parser.mly"
                  ( [] )
# 10260 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_253 =
    fun _1 ->
      (_1 : (AST.field list))
  
  let _menhir_action_254 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 10272 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_255 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let _endpos = _endpos__1_ in
      let _startpos = _startpos__1_ in
      (
# 607 "asllib/Parser.mly"
                            (
      if Config.allow_storage_discards then global_ignored ()
      else Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Discarded storage declaration."
    )
# 10285 "asllib/Parser.ml"
       : (string))
  
  let _menhir_action_256 =
    fun _1 ->
      (_1 : (string))
  
  let _menhir_action_257 =
    fun expr ->
      (
# 302 "asllib/Parser.mly"
                                  Constraint_Exact  
# 10297 "asllib/Parser.ml"
       expr : (AST.int_constraint))
  
  let _menhir_action_258 =
    fun _2 e1 e2 ->
      (
# 303 "asllib/Parser.mly"
                                  Constraint_Range  
# 10305 "asllib/Parser.ml"
       (e1, e2) : (AST.int_constraint))
  
  let _menhir_action_259 =
    fun () ->
      (
# 620 "asllib/Parser.mly"
              ( false )
# 10313 "asllib/Parser.ml"
       : (bool))
  
  let _menhir_action_260 =
    fun _1 ->
      (
# 621 "asllib/Parser.mly"
              ( true )
# 10321 "asllib/Parser.ml"
       : (bool))
  
  let _menhir_action_261 =
    fun basic_lexpr ->
      (
# 449 "asllib/Parser.mly"
                     desugar_lhs_access  
# 10329 "asllib/Parser.ml"
       basic_lexpr : (AST.lexpr))
  
  let _menhir_action_262 =
    fun _endpos__3_ _startpos__1_ x ->
      let _1 =
        let desc = 
# 205 "<standard.mly>"
    ( x )
# 10338 "asllib/Parser.ml"
         in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10346 "asllib/Parser.ml"
        
      in
      let _1_1 = _1 in
      (
# 450 "asllib/Parser.mly"
                                                   desugar_lhs_tuple  
# 10353 "asllib/Parser.ml"
       _1_1 : (AST.lexpr))
  
  let _menhir_action_263 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 452 "asllib/Parser.mly"
             ( LE_Discard )
# 10361 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10369 "asllib/Parser.ml"
       : (AST.lexpr))
  
  let _menhir_action_264 =
    fun _2 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x ->
      let desc =
        let flds = 
# 205 "<standard.mly>"
    ( x )
# 10378 "asllib/Parser.ml"
         in
        let x =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10386 "asllib/Parser.ml"
          
        in
        
# 454 "asllib/Parser.mly"
      ( LE_SetFields (le_var x, flds, []) )
# 10392 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10401 "asllib/Parser.ml"
       : (AST.lexpr))
  
  let _menhir_action_265 =
    fun _2 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x ->
      let desc =
        let flds = 
# 205 "<standard.mly>"
    ( x )
# 10410 "asllib/Parser.ml"
         in
        let x =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10418 "asllib/Parser.ml"
          
        in
        
# 456 "asllib/Parser.mly"
      ( desugar_lhs_fields_tuple x flds )
# 10424 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10433 "asllib/Parser.ml"
       : (AST.lexpr))
  
  let _menhir_action_266 =
    fun () ->
      (
# 216 "<standard.mly>"
    ( [] )
# 10441 "asllib/Parser.ml"
       : (AST.decl list list))
  
  let _menhir_action_267 =
    fun x xs ->
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10449 "asllib/Parser.ml"
       : (AST.decl list list))
  
  let _menhir_action_268 =
    fun x ->
      (
# 183 "asllib/Parser.mly"
         ( [ x ] )
# 10457 "asllib/Parser.ml"
       : (AST.case_alt_desc AST.annotated list))
  
  let _menhir_action_269 =
    fun l x ->
      (
# 184 "asllib/Parser.mly"
                     ( x :: l )
# 10465 "asllib/Parser.ml"
       : (AST.case_alt_desc AST.annotated list))
  
  let _menhir_action_270 =
    fun x ->
      (
# 183 "asllib/Parser.mly"
         ( [ x ] )
# 10473 "asllib/Parser.ml"
       : (AST.catcher list))
  
  let _menhir_action_271 =
    fun l x ->
      (
# 184 "asllib/Parser.mly"
                     ( x :: l )
# 10481 "asllib/Parser.ml"
       : (AST.catcher list))
  
  let _menhir_action_272 =
    fun x ->
      (
# 183 "asllib/Parser.mly"
         ( [ x ] )
# 10489 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_273 =
    fun l x ->
      (
# 184 "asllib/Parser.mly"
                     ( x :: l )
# 10497 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_274 =
    fun () ->
      (
# 123 "<standard.mly>"
    ( None )
# 10505 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_275 =
    fun _1 _2 ->
      let x = _2 in
      (
# 126 "<standard.mly>"
    ( Some x )
# 10514 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_276 =
    fun _1 ->
      (_1 : (AST.stmt))
  
  let _menhir_action_277 =
    fun _endpos__0_ ->
      let desc = 
# 603 "asllib/Parser.mly"
                                                   ( S_Pass )
# 10526 "asllib/Parser.ml"
       in
      let _endpos_desc_ = _endpos__0_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _endpos in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10534 "asllib/Parser.ml"
       : (AST.stmt))
  
  let _menhir_action_278 =
    fun _2 body ->
      (
# 711 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            qualifier = None;
            override = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 10559 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_279 =
    fun x ->
      let y = 
# 123 "<standard.mly>"
    ( None )
# 10567 "asllib/Parser.ml"
       in
      (
# 172 "<standard.mly>"
    ( (x, y) )
# 10572 "asllib/Parser.ml"
       : (string * AST.ty option))
  
  let _menhir_action_280 =
    fun x x_inlined1 ->
      let y =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 10582 "asllib/Parser.ml"
        
      in
      (
# 172 "<standard.mly>"
    ( (x, y) )
# 10588 "asllib/Parser.ml"
       : (string * AST.ty option))
  
  let _menhir_action_281 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 10596 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_282 =
    fun x ->
      (
# 114 "<standard.mly>"
    ( Some x )
# 10604 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_283 =
    fun () ->
      (
# 123 "<standard.mly>"
    ( None )
# 10612 "asllib/Parser.ml"
       : (AST.stmt option))
  
  let _menhir_action_284 =
    fun _1 _2 _3 ->
      let x = _3 in
      (
# 126 "<standard.mly>"
    ( Some x )
# 10621 "asllib/Parser.ml"
       : (AST.stmt option))
  
  let _menhir_action_285 =
    fun () ->
      (
# 589 "asllib/Parser.mly"
                  ( [] )
# 10629 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_286 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 10637 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_287 =
    fun _endpos_expr_pattern_ _startpos_expr_pattern_ expr_pattern ->
      let desc = 
# 341 "asllib/Parser.mly"
                        Pattern_Single  
# 10645 "asllib/Parser.ml"
       expr_pattern in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_expr_pattern_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10653 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_288 =
    fun _2 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc = 
# 342 "asllib/Parser.mly"
                                           Pattern_Range  
# 10661 "asllib/Parser.ml"
       (e1, e2) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10669 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_289 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 343 "asllib/Parser.mly"
             ( Pattern_All )
# 10677 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10685 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_290 =
    fun _1 _endpos_expr_ _startpos__1_ expr ->
      let desc = 
# 344 "asllib/Parser.mly"
                     Pattern_Leq  
# 10693 "asllib/Parser.ml"
       expr in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_expr_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10701 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_291 =
    fun _1 _endpos_expr_ _startpos__1_ expr ->
      let desc = 
# 345 "asllib/Parser.mly"
                     Pattern_Geq  
# 10709 "asllib/Parser.ml"
       expr in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_expr_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10717 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_292 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let _1 = 
# 205 "<standard.mly>"
    ( x )
# 10726 "asllib/Parser.ml"
         in
        let _1_1 = _1 in
        
# 346 "asllib/Parser.mly"
                           Pattern_Tuple  
# 10732 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10741 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_293 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let _1_1 = _1 in
        
# 336 "asllib/Parser.mly"
                                            Pattern_Mask  
# 10751 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10760 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_294 =
    fun _1 ->
      (_1 : (AST.pattern))
  
  let _menhir_action_295 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let _1_1 = _1 in
        
# 337 "asllib/Parser.mly"
                                                   Pattern_Any  
# 10774 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10783 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_296 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 10791 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_297 =
    fun _1 _endpos__3_ _startpos__1_ x ->
      let desc =
        let _2 = 
# 205 "<standard.mly>"
    ( x )
# 10800 "asllib/Parser.ml"
         in
        let _2_1 = _2 in
        
# 354 "asllib/Parser.mly"
                                      Pattern_Not  
# 10806 "asllib/Parser.ml"
         _2_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10815 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_298 =
    fun () ->
      (
# 123 "<standard.mly>"
    ( None )
# 10823 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_299 =
    fun _1 _2 ->
      let x = _2 in
      (
# 126 "<standard.mly>"
    ( Some x )
# 10832 "asllib/Parser.ml"
       : (AST.expr option))
  
  let _menhir_action_300 =
    fun _1 _2 ->
      (_2 : (AST.ty))
  
  let _menhir_action_301 =
    fun _1 _3 _endpos_s2_ _startpos__1_ e s1 s2 ->
      let desc = 
# 571 "asllib/Parser.mly"
                                                     S_Cond 
# 10844 "asllib/Parser.ml"
       (e, s1, s2) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_s2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = if _startpos_desc_ != _endpos_desc_ then
        _startpos_desc_
      else
        _endpos in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10855 "asllib/Parser.ml"
       : (AST.stmt))
  
  let _menhir_action_302 =
    fun _endpos__0_ ->
      let desc = 
# 500 "asllib/Parser.mly"
            ( S_Pass )
# 10863 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__0_, _endpos__0_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = if _startpos_desc_ != _endpos_desc_ then
        _startpos_desc_
      else
        _endpos in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10874 "asllib/Parser.ml"
       : (AST.stmt))
  
  let _menhir_action_303 =
    fun _1 _2 ->
      (_2 : (AST.stmt))
  
  let _menhir_action_304 =
    fun () ->
      (
# 522 "asllib/Parser.mly"
    ( [] )
# 10886 "asllib/Parser.ml"
       : (Desugar.field_or_array_access list))
  
  let _menhir_action_305 =
    fun _1 _endpos_desc_ _startpos_desc_ desc t ->
      let h =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10897 "asllib/Parser.ml"
        
      in
      (
# 523 "asllib/Parser.mly"
                                                   ( FieldAccess h :: t )
# 10903 "asllib/Parser.ml"
       : (Desugar.field_or_array_access list))
  
  let _menhir_action_306 =
    fun expr ->
      (
# 365 "asllib/Parser.mly"
                                    Slice_Single   
# 10911 "asllib/Parser.ml"
       expr : (AST.slice))
  
  let _menhir_action_307 =
    fun _2 e1 e2 ->
      (
# 366 "asllib/Parser.mly"
                                    Slice_Range    
# 10919 "asllib/Parser.ml"
       (e1, e2) : (AST.slice))
  
  let _menhir_action_308 =
    fun _2 e1 e2 ->
      (
# 367 "asllib/Parser.mly"
                                    Slice_Length   
# 10927 "asllib/Parser.ml"
       (e1, e2) : (AST.slice))
  
  let _menhir_action_309 =
    fun _endpos_desc_ _startpos_desc_ desc e ->
      let loc =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10938 "asllib/Parser.ml"
        
      in
      (
# 368 "asllib/Parser.mly"
                                  ( Slice_Length(zero ~loc, e) )
# 10944 "asllib/Parser.ml"
       : (AST.slice))
  
  let _menhir_action_310 =
    fun _2 e1 e2 ->
      (
# 369 "asllib/Parser.mly"
                                    Slice_Star     
# 10952 "asllib/Parser.ml"
       (e1, e2) : (AST.slice))
  
  let _menhir_action_311 =
    fun x ->
      (
# 205 "<standard.mly>"
    ( x )
# 10960 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_312 =
    fun x ->
      let _1 = 
# 196 "<standard.mly>"
    ( x )
# 10968 "asllib/Parser.ml"
       in
      let _1_1 = _1 in
      (
# 707 "asllib/Parser.mly"
                                             List.concat  
# 10974 "asllib/Parser.ml"
       _1_1 : (AST.t))
  
  let _menhir_action_313 =
    fun _1 _1_inlined1 _2 _3 _endpos__2_ _startpos__1_ e s1 s2 ->
      let desc =
        let _2 =
          let _1 = _1_inlined1 in
          ()
        in
        let x = 
# 528 "asllib/Parser.mly"
                                                       S_Cond 
# 10987 "asllib/Parser.ml"
         (e, s1, s2) in
        
# 196 "<standard.mly>"
    ( x )
# 10992 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11001 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_314 =
    fun _1 _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ e s1 s2 ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 11017 "asllib/Parser.ml"
          
        in
        let x = 
# 528 "asllib/Parser.mly"
                                                       S_Cond 
# 11023 "asllib/Parser.ml"
         (e, s1, s2) in
        
# 196 "<standard.mly>"
    ( x )
# 11028 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11037 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_315 =
    fun _1 _1_inlined1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ expr ->
      let desc =
        let _2 =
          let _1 = _1_inlined2 in
          ()
        in
        let x =
          let alt = _1_inlined1 in
          
# 530 "asllib/Parser.mly"
          ( desugar_case_stmt expr alt (S_Unreachable |> ASTUtils.add_pos_from expr))
# 11052 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 11058 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11067 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_316 =
    fun _1 _1_inlined1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ expr ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 11083 "asllib/Parser.ml"
          
        in
        let x =
          let alt = _1_inlined1 in
          
# 530 "asllib/Parser.mly"
          ( desugar_case_stmt expr alt (S_Unreachable |> ASTUtils.add_pos_from expr))
# 11091 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 11097 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11106 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_317 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _2_inlined1 _3 _endpos__2_ _startpos__1_ expr otherwise_stmt ->
      let desc =
        let _2 =
          let _1 = _1_inlined3 in
          ()
        in
        let x =
          let _2 = _2_inlined1 in
          let case_otherwise =
            let _1 = _1_inlined2 in
            
# 512 "asllib/Parser.mly"
      ( otherwise_stmt )
# 11123 "asllib/Parser.ml"
            
          in
          let alt = _1_inlined1 in
          
# 532 "asllib/Parser.mly"
          ( desugar_case_stmt expr alt case_otherwise )
# 11130 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 11136 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11145 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_318 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ expr otherwise_stmt ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 11161 "asllib/Parser.ml"
          
        in
        let x =
          let _2 = _2_inlined1 in
          let case_otherwise =
            let _1 = _1_inlined2 in
            
# 512 "asllib/Parser.mly"
      ( otherwise_stmt )
# 11171 "asllib/Parser.ml"
            
          in
          let alt = _1_inlined1 in
          
# 532 "asllib/Parser.mly"
          ( desugar_case_stmt expr alt case_otherwise )
# 11178 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 11184 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11193 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_319 =
    fun _1 _1_inlined1 _2 _4 _endpos__2_ _startpos__1_ expr loop_limit stmt_list ->
      let desc =
        let _2 =
          let _1 = _1_inlined1 in
          ()
        in
        let x = 
# 533 "asllib/Parser.mly"
                                                       S_While 
# 11206 "asllib/Parser.ml"
         (expr, loop_limit, stmt_list) in
        
# 196 "<standard.mly>"
    ( x )
# 11211 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11220 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_320 =
    fun _1 _1_inlined1 _4 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ expr loop_limit stmt_list ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 11236 "asllib/Parser.ml"
          
        in
        let x = 
# 533 "asllib/Parser.mly"
                                                       S_While 
# 11242 "asllib/Parser.ml"
         (expr, loop_limit, stmt_list) in
        
# 196 "<standard.mly>"
    ( x )
# 11247 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11256 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_321 =
    fun _1 _1_inlined1 _2 _3 _8 _endpos__2_ _startpos__1_ body dir end_e index_name limit start_e ->
      let desc =
        let _2 =
          let _1 = _1_inlined1 in
          ()
        in
        let x = 
# 536 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 11269 "asllib/Parser.ml"
         in
        
# 196 "<standard.mly>"
    ( x )
# 11274 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11283 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_322 =
    fun _1 _1_inlined1 _3 _8 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ body dir end_e index_name limit start_e ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 11299 "asllib/Parser.ml"
          
        in
        let x = 
# 536 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 11305 "asllib/Parser.ml"
         in
        
# 196 "<standard.mly>"
    ( x )
# 11310 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11319 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_323 =
    fun _1 _1_inlined1 _2 _3 _endpos__2_ _startpos__1_ c o s ->
      let desc =
        let _2 =
          let _1 = _1_inlined1 in
          ()
        in
        let x = 
# 537 "asllib/Parser.mly"
                                                                      S_Try  
# 11332 "asllib/Parser.ml"
         (s, c, o) in
        
# 196 "<standard.mly>"
    ( x )
# 11337 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11346 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_324 =
    fun _1 _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ c o s ->
      let desc =
        let _2 =
          let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
          let _endpos = _endpos__1_ in
          let _startpos = _startpos__1_ in
          
# 188 "asllib/Parser.mly"
                          (
      if not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 11362 "asllib/Parser.ml"
          
        in
        let x = 
# 537 "asllib/Parser.mly"
                                                                      S_Try  
# 11368 "asllib/Parser.ml"
         (s, c, o) in
        
# 196 "<standard.mly>"
    ( x )
# 11373 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11382 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_325 =
    fun _1 _endpos__2_ _startpos__1_ ->
      let desc =
        let x = 
# 500 "asllib/Parser.mly"
            ( S_Pass )
# 11391 "asllib/Parser.ml"
         in
        
# 196 "<standard.mly>"
    ( x )
# 11396 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11405 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_326 =
    fun _1 _2_inlined1 _endpos__2_ _startpos__1_ ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          let _2_1 = _2 in
          
# 541 "asllib/Parser.mly"
                                                              S_Return  
# 11417 "asllib/Parser.ml"
           _2_1
        in
        
# 196 "<standard.mly>"
    ( x )
# 11423 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11432 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_327 =
    fun _endpos__2_ _startpos_call_ call ->
      let desc =
        let x = 
# 542 "asllib/Parser.mly"
                                                               s_call  
# 11441 "asllib/Parser.ml"
         call in
        
# 196 "<standard.mly>"
    ( x )
# 11446 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_call_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11455 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_328 =
    fun _1 _endpos__2_ _startpos__1_ e ->
      let desc =
        let x = 
# 543 "asllib/Parser.mly"
                                                               S_Assert  
# 11464 "asllib/Parser.ml"
         e in
        
# 196 "<standard.mly>"
    ( x )
# 11469 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11478 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_329 =
    fun _1 _4 _endpos__2_ _startpos__1_ decl_item x ->
      let desc =
        let x =
          let _5 = 
# 144 "asllib/Parser.mly"
                        Some 
# 11488 "asllib/Parser.ml"
           x in
          let ty_opt = 
# 123 "<standard.mly>"
    ( None )
# 11493 "asllib/Parser.ml"
           in
          let local_decl_keyword = 
# 483 "asllib/Parser.mly"
                ( LDK_Let       )
# 11498 "asllib/Parser.ml"
           in
          let _5_1 = _5 in
          
# 544 "asllib/Parser.mly"
                                                                         S_Decl    
# 11504 "asllib/Parser.ml"
           (local_decl_keyword, decl_item, ty_opt, _5_1)
        in
        
# 196 "<standard.mly>"
    ( x )
# 11510 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11519 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_330 =
    fun _1 _4 _endpos__2_ _startpos__1_ decl_item x x_inlined1 ->
      let desc =
        let x =
          let _5 =
            let x = x_inlined1 in
            
# 144 "asllib/Parser.mly"
                        Some 
# 11531 "asllib/Parser.ml"
             x
          in
          let ty_opt = 
# 126 "<standard.mly>"
    ( Some x )
# 11537 "asllib/Parser.ml"
           in
          let local_decl_keyword = 
# 483 "asllib/Parser.mly"
                ( LDK_Let       )
# 11542 "asllib/Parser.ml"
           in
          let _5_1 = _5 in
          
# 544 "asllib/Parser.mly"
                                                                         S_Decl    
# 11548 "asllib/Parser.ml"
           (local_decl_keyword, decl_item, ty_opt, _5_1)
        in
        
# 196 "<standard.mly>"
    ( x )
# 11554 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11563 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_331 =
    fun _1 _4 _endpos__1_ _endpos__2_ _startpos__1_ decl_item x ->
      let desc =
        let x =
          let _5 = 
# 144 "asllib/Parser.mly"
                        Some 
# 11573 "asllib/Parser.ml"
           x in
          let ty_opt = 
# 123 "<standard.mly>"
    ( None )
# 11578 "asllib/Parser.ml"
           in
          let local_decl_keyword =
            let _endpos = _endpos__1_ in
            let _startpos = _startpos__1_ in
            
# 484 "asllib/Parser.mly"
                              (
    if not Config.allow_local_constants then
        Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Local constant declaration."
    else LDK_Constant
  )
# 11590 "asllib/Parser.ml"
            
          in
          let _5_1 = _5 in
          
# 544 "asllib/Parser.mly"
                                                                         S_Decl    
# 11597 "asllib/Parser.ml"
           (local_decl_keyword, decl_item, ty_opt, _5_1)
        in
        
# 196 "<standard.mly>"
    ( x )
# 11603 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11612 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_332 =
    fun _1 _4 _endpos__1_ _endpos__2_ _startpos__1_ decl_item x x_inlined1 ->
      let desc =
        let x =
          let _5 =
            let x = x_inlined1 in
            
# 144 "asllib/Parser.mly"
                        Some 
# 11624 "asllib/Parser.ml"
             x
          in
          let ty_opt = 
# 126 "<standard.mly>"
    ( Some x )
# 11630 "asllib/Parser.ml"
           in
          let local_decl_keyword =
            let _endpos = _endpos__1_ in
            let _startpos = _startpos__1_ in
            
# 484 "asllib/Parser.mly"
                              (
    if not Config.allow_local_constants then
        Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Local constant declaration."
    else LDK_Constant
  )
# 11642 "asllib/Parser.ml"
            
          in
          let _5_1 = _5 in
          
# 544 "asllib/Parser.mly"
                                                                         S_Decl    
# 11649 "asllib/Parser.ml"
           (local_decl_keyword, decl_item, ty_opt, _5_1)
        in
        
# 196 "<standard.mly>"
    ( x )
# 11655 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11664 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_333 =
    fun _1 _4 _endpos__2_ _startpos__1_ decl_item x ->
      let desc =
        let x =
          let _5 = 
# 144 "asllib/Parser.mly"
                        Some 
# 11674 "asllib/Parser.ml"
           x in
          let ty_opt = 
# 123 "<standard.mly>"
    ( None )
# 11679 "asllib/Parser.ml"
           in
          let local_decl_keyword = 
# 489 "asllib/Parser.mly"
                ( LDK_Var       )
# 11684 "asllib/Parser.ml"
           in
          let _5_1 = _5 in
          
# 544 "asllib/Parser.mly"
                                                                         S_Decl    
# 11690 "asllib/Parser.ml"
           (local_decl_keyword, decl_item, ty_opt, _5_1)
        in
        
# 196 "<standard.mly>"
    ( x )
# 11696 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11705 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_334 =
    fun _1 _4 _endpos__2_ _startpos__1_ decl_item x x_inlined1 ->
      let desc =
        let x =
          let _5 =
            let x = x_inlined1 in
            
# 144 "asllib/Parser.mly"
                        Some 
# 11717 "asllib/Parser.ml"
             x
          in
          let ty_opt = 
# 126 "<standard.mly>"
    ( Some x )
# 11723 "asllib/Parser.ml"
           in
          let local_decl_keyword = 
# 489 "asllib/Parser.mly"
                ( LDK_Var       )
# 11728 "asllib/Parser.ml"
           in
          let _5_1 = _5 in
          
# 544 "asllib/Parser.mly"
                                                                         S_Decl    
# 11734 "asllib/Parser.ml"
           (local_decl_keyword, decl_item, ty_opt, _5_1)
        in
        
# 196 "<standard.mly>"
    ( x )
# 11740 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11749 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_335 =
    fun _2_inlined1 _endpos__2_ _startpos_le_ e le ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          
# 545 "asllib/Parser.mly"
                                                               S_Assign  
# 11760 "asllib/Parser.ml"
           (le, e)
        in
        
# 196 "<standard.mly>"
    ( x )
# 11766 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_le_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11775 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_336 =
    fun _3 _endpos__2_ _endpos_desc_ _startpos_desc_ desc rhs setter_access ->
      let desc =
        let x =
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11788 "asllib/Parser.ml"
            
          in
          
# 547 "asllib/Parser.mly"
        ( desugar_setter call { access=setter_access; slices=add_dummy_annotation ~version [] } rhs )
# 11794 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 11800 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__2_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11809 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_337 =
    fun _4 _endpos__2_ _endpos_desc_ _endpos_desc_inlined1_ _startpos_desc_ _startpos_desc_inlined1_ desc desc_inlined1 rhs setter_access ->
      let desc =
        let x =
          let slices =
            let (_endpos_desc_, _startpos_desc_, desc) = (_endpos_desc_inlined1_, _startpos_desc_inlined1_, desc_inlined1) in
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11823 "asllib/Parser.ml"
            
          in
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11832 "asllib/Parser.ml"
            
          in
          
# 549 "asllib/Parser.mly"
        ( desugar_setter call { access=setter_access; slices } rhs )
# 11838 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 11844 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__2_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11853 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_338 =
    fun _2_inlined1 _4 _endpos__2_ _endpos_desc_ _startpos_desc_ desc rhs x ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          let flds = 
# 205 "<standard.mly>"
    ( x )
# 11864 "asllib/Parser.ml"
           in
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11872 "asllib/Parser.ml"
            
          in
          
# 551 "asllib/Parser.mly"
        ( desugar_setter_setfields call flds rhs )
# 11878 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 11884 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__2_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11893 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_339 =
    fun _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc lhs ty ->
      let desc =
        let x =
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11906 "asllib/Parser.ml"
            
          in
          let ldk = 
# 483 "asllib/Parser.mly"
                ( LDK_Let       )
# 11912 "asllib/Parser.ml"
           in
          
# 553 "asllib/Parser.mly"
        ( S_Decl (ldk, lhs, Some ty, desugar_elided_parameter ty call) )
# 11917 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 11923 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11932 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_340 =
    fun _1 _4 _endpos__1_ _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc lhs ty ->
      let desc =
        let x =
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11945 "asllib/Parser.ml"
            
          in
          let ldk =
            let _endpos = _endpos__1_ in
            let _startpos = _startpos__1_ in
            
# 484 "asllib/Parser.mly"
                              (
    if not Config.allow_local_constants then
        Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Local constant declaration."
    else LDK_Constant
  )
# 11958 "asllib/Parser.ml"
            
          in
          
# 553 "asllib/Parser.mly"
        ( S_Decl (ldk, lhs, Some ty, desugar_elided_parameter ty call) )
# 11964 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 11970 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11979 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_341 =
    fun _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc lhs ty ->
      let desc =
        let x =
          let call =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11992 "asllib/Parser.ml"
            
          in
          let ldk = 
# 489 "asllib/Parser.mly"
                ( LDK_Var       )
# 11998 "asllib/Parser.ml"
           in
          
# 553 "asllib/Parser.mly"
        ( S_Decl (ldk, lhs, Some ty, desugar_elided_parameter ty call) )
# 12003 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 12009 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12018 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_342 =
    fun _1 _endpos__2_ _startpos__1_ ldi x ->
      let desc =
        let x =
          let ty = 
# 144 "asllib/Parser.mly"
                        Some 
# 12028 "asllib/Parser.ml"
           x in
          
# 554 "asllib/Parser.mly"
                                                              ( S_Decl (LDK_Var, ldi, ty, None) )
# 12033 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 12039 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12048 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_343 =
    fun _1 _2_inlined1 _endpos__2_ _startpos__1_ as_ty ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          let _2_1 = _2 in
          
# 555 "asllib/Parser.mly"
                                                                make_ldi_vars  
# 12060 "asllib/Parser.ml"
           (_2_1, as_ty)
        in
        
# 196 "<standard.mly>"
    ( x )
# 12066 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12075 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_344 =
    fun _1 _endpos__2_ _startpos__1_ x ->
      let desc =
        let x =
          let args = 
# 205 "<standard.mly>"
    ( x )
# 12085 "asllib/Parser.ml"
           in
          
# 556 "asllib/Parser.mly"
                                                              ( S_Print { args; newline = true; debug = false } )
# 12090 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 12096 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12105 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_345 =
    fun _1 _endpos__2_ _startpos__1_ x ->
      let desc =
        let x =
          let args = 
# 205 "<standard.mly>"
    ( x )
# 12115 "asllib/Parser.ml"
           in
          
# 557 "asllib/Parser.mly"
                                                              ( S_Print { args; newline = false; debug = false } )
# 12120 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 12126 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12135 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_346 =
    fun _1 _endpos__2_ _startpos__1_ x ->
      let desc =
        let x =
          let args = 
# 205 "<standard.mly>"
    ( x )
# 12145 "asllib/Parser.ml"
           in
          
# 558 "asllib/Parser.mly"
                                             ( S_Print { args; newline = true; debug = true } )
# 12150 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 12156 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12165 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_347 =
    fun _1 _2_inlined1 _3 _endpos__2_ _startpos__1_ ->
      let desc =
        let x =
          let _2 = _2_inlined1 in
          
# 559 "asllib/Parser.mly"
                                                             ( S_Unreachable )
# 12176 "asllib/Parser.ml"
          
        in
        
# 196 "<standard.mly>"
    ( x )
# 12182 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12191 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_348 =
    fun _1 _3 _endpos__2_ _startpos__1_ expr loop_limit stmt_list ->
      let desc =
        let x = 
# 560 "asllib/Parser.mly"
                                                               S_Repeat  
# 12200 "asllib/Parser.ml"
         (stmt_list, expr, loop_limit) in
        
# 196 "<standard.mly>"
    ( x )
# 12205 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12214 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_349 =
    fun _1 _endpos__2_ _startpos__1_ e ->
      let desc =
        let x = 
# 561 "asllib/Parser.mly"
                                                             ( S_Throw (Some (e, None)) )
# 12223 "asllib/Parser.ml"
         in
        
# 196 "<standard.mly>"
    ( x )
# 12228 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12237 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_350 =
    fun _1 _endpos__2_ _startpos__1_ ->
      let desc =
        let x = 
# 562 "asllib/Parser.mly"
                                                             ( S_Throw None             )
# 12246 "asllib/Parser.ml"
         in
        
# 196 "<standard.mly>"
    ( x )
# 12251 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12260 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_351 =
    fun _1 _endpos__2_ _startpos__1_ e x ->
      let desc =
        let x = 
# 563 "asllib/Parser.mly"
                                                                S_Pragma  
# 12269 "asllib/Parser.ml"
         (x, e) in
        
# 196 "<standard.mly>"
    ( x )
# 12274 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12283 "asllib/Parser.ml"
       : (AST.stmt_desc AST.annotated))
  
  let _menhir_action_352 =
    fun _1 ->
      let _1_1 = _1 in
      (
# 567 "asllib/Parser.mly"
                                    stmt_from_list 
# 12292 "asllib/Parser.ml"
       _1_1 : (AST.stmt))
  
  let _menhir_action_353 =
    fun x ->
      (
# 196 "<standard.mly>"
    ( x )
# 12300 "asllib/Parser.ml"
       : (AST.stmt))
  
  let _menhir_action_354 =
    fun _1 _2 ->
      let with_opt = 
# 582 "asllib/Parser.mly"
                ( [] )
# 12308 "asllib/Parser.ml"
       in
      let _2_1 = _2 in
      ((_2_1, with_opt) : (string * AST.field list))
  
  let _menhir_action_355 =
    fun _1 _1_inlined1 _2 fields ->
      let with_opt =
        let _1 = _1_inlined1 in
        fields
      in
      let _2_1 = _2 in
      ((_2_1, with_opt) : (string * AST.field list))
  
  let _menhir_action_356 =
    fun () ->
      (
# 123 "<standard.mly>"
    ( None )
# 12327 "asllib/Parser.ml"
       : ((string * AST.field list) option))
  
  let _menhir_action_357 =
    fun x ->
      (
# 126 "<standard.mly>"
    ( Some x )
# 12335 "asllib/Parser.ml"
       : ((string * AST.field list) option))
  
  let _menhir_action_358 =
    fun () ->
      (
# 168 "asllib/Parser.mly"
                  ( [] )
# 12343 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_359 =
    fun _1 ->
      (_1 : (AST.bitfield list))
  
  let _menhir_action_360 =
    fun x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 12355 "asllib/Parser.ml"
       in
      (
# 172 "asllib/Parser.mly"
                         ( [ x ] )
# 12360 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_361 =
    fun x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 12370 "asllib/Parser.ml"
        
      in
      (
# 172 "asllib/Parser.mly"
                         ( [ x ] )
# 12376 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_362 =
    fun _2 h t ->
      (
# 173 "asllib/Parser.mly"
                              ( h :: t )
# 12384 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_363 =
    fun x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 12392 "asllib/Parser.ml"
       in
      (
# 172 "asllib/Parser.mly"
                         ( [ x ] )
# 12397 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_364 =
    fun x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 12407 "asllib/Parser.ml"
        
      in
      (
# 172 "asllib/Parser.mly"
                         ( [ x ] )
# 12413 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_365 =
    fun _2 h t ->
      (
# 173 "asllib/Parser.mly"
                              ( h :: t )
# 12421 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_366 =
    fun x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 12429 "asllib/Parser.ml"
       in
      (
# 172 "asllib/Parser.mly"
                         ( [ x ] )
# 12434 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_367 =
    fun x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 12444 "asllib/Parser.ml"
        
      in
      (
# 172 "asllib/Parser.mly"
                         ( [ x ] )
# 12450 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_368 =
    fun _2 h t ->
      (
# 173 "asllib/Parser.mly"
                              ( h :: t )
# 12458 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_369 =
    fun _1 _endpos_c_ _startpos__1_ c ->
      let desc = 
# 382 "asllib/Parser.mly"
                                                          T_Int         
# 12466 "asllib/Parser.ml"
       c in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_c_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12474 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_370 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 383 "asllib/Parser.mly"
                                                        ( T_Real       )
# 12482 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12490 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_371 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 384 "asllib/Parser.mly"
                                                        ( T_Bool       )
# 12498 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12506 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_372 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 385 "asllib/Parser.mly"
                                                        ( T_String     )
# 12514 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12522 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_373 =
    fun _endpos_desc_ _startpos_desc_ desc ->
      let desc =
        let loc =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12534 "asllib/Parser.ml"
          
        in
        
# 386 "asllib/Parser.mly"
                                                        ( t_bit ~loc   )
# 12540 "asllib/Parser.ml"
        
      in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12548 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_374 =
    fun _1 _endpos_bitfields_opt_ _startpos__1_ bitfields_opt x ->
      let desc =
        let _2 = 
# 205 "<standard.mly>"
    ( x )
# 12557 "asllib/Parser.ml"
         in
        let _2_1 = _2 in
        
# 387 "asllib/Parser.mly"
                                                          T_Bits        
# 12563 "asllib/Parser.ml"
         (_2_1, bitfields_opt)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_bitfields_opt_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12572 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_375 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let l = 
# 205 "<standard.mly>"
    ( x )
# 12581 "asllib/Parser.ml"
         in
        
# 388 "asllib/Parser.mly"
                                                          T_Tuple       
# 12586 "asllib/Parser.ml"
         l
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12595 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_376 =
    fun _endpos_name_ _startpos_name_ name ->
      let desc = 
# 389 "asllib/Parser.mly"
                                                          T_Named       
# 12603 "asllib/Parser.ml"
       name in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_name_, _startpos_name_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12611 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_377 =
    fun _1 _2 _4 _5 _endpos_t_ _startpos__1_ e t ->
      let desc = 
# 390 "asllib/Parser.mly"
                                                        ( T_Array (ArrayLength_Expr e, t) )
# 12619 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_t_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12627 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_378 =
    fun _1 ->
      (_1 : (AST.ty))
  
  let _menhir_action_379 =
    fun _1 _endpos__3_ _startpos__1_ x ->
      let desc =
        let l = 
# 205 "<standard.mly>"
    ( x )
# 12640 "asllib/Parser.ml"
         in
        
# 395 "asllib/Parser.mly"
                                                          T_Enum        
# 12645 "asllib/Parser.ml"
         l
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12654 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_380 =
    fun _1 _endpos_l_ _startpos__1_ l ->
      let desc = 
# 396 "asllib/Parser.mly"
                                                          T_Record      
# 12662 "asllib/Parser.ml"
       l in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_l_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12670 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_381 =
    fun _1 _endpos_l_ _startpos__1_ l ->
      let desc = 
# 397 "asllib/Parser.mly"
                                                          T_Exception   
# 12678 "asllib/Parser.ml"
       l in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_l_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12686 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_382 =
    fun _1 ->
      (_1 : (AST.ty))
  
  let _menhir_action_383 =
    fun _1 _endpos_l_ _startpos__1_ l ->
      let desc = 
# 409 "asllib/Parser.mly"
                                                          T_Collection  
# 12698 "asllib/Parser.ml"
       l in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_l_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 151 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12706 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_384 =
    fun x y ->
      (
# 172 "<standard.mly>"
    ( (x, y) )
# 12714 "asllib/Parser.ml"
       : (AST.field))
  
  let _menhir_action_385 =
    fun i ->
      (
# 201 "asllib/Parser.mly"
                        L_Int          
# 12722 "asllib/Parser.ml"
       i : (AST.literal))
  
  let _menhir_action_386 =
    fun b ->
      (
# 202 "asllib/Parser.mly"
                        L_Bool         
# 12730 "asllib/Parser.ml"
       b : (AST.literal))
  
  let _menhir_action_387 =
    fun r ->
      (
# 203 "asllib/Parser.mly"
                        L_Real         
# 12738 "asllib/Parser.ml"
       r : (AST.literal))
  
  let _menhir_action_388 =
    fun b ->
      (
# 204 "asllib/Parser.mly"
                        L_BitVector    
# 12746 "asllib/Parser.ml"
       b : (AST.literal))
  
  let _menhir_action_389 =
    fun s ->
      (
# 205 "asllib/Parser.mly"
                        L_String       
# 12754 "asllib/Parser.ml"
       s : (AST.literal))
  
  let _menhir_print_token : token -> string =
    fun _tok ->
      match _tok with
      | Tokens.ACCESSOR ->
          "ACCESSOR"
      | Tokens.AND ->
          "AND"
      | Tokens.ARBITRARY ->
          "ARBITRARY"
      | Tokens.ARRAY ->
          "ARRAY"
      | Tokens.ARROW ->
          "ARROW"
      | Tokens.AS ->
          "AS"
      | Tokens.ASSERT ->
          "ASSERT"
      | Tokens.BAND ->
          "BAND"
      | Tokens.BEGIN ->
          "BEGIN"
      | Tokens.BEQ ->
          "BEQ"
      | Tokens.BIT ->
          "BIT"
      | Tokens.BITS ->
          "BITS"
      | Tokens.BITVECTOR_LIT _ ->
          "BITVECTOR_LIT"
      | Tokens.BNOT ->
          "BNOT"
      | Tokens.BOOLEAN ->
          "BOOLEAN"
      | Tokens.BOOL_LIT _ ->
          "BOOL_LIT"
      | Tokens.BOR ->
          "BOR"
      | Tokens.CASE ->
          "CASE"
      | Tokens.CATCH ->
          "CATCH"
      | Tokens.COLLECTION ->
          "COLLECTION"
      | Tokens.COLON ->
          "COLON"
      | Tokens.COLON_COLON ->
          "COLON_COLON"
      | Tokens.COMMA ->
          "COMMA"
      | Tokens.CONFIG ->
          "CONFIG"
      | Tokens.CONSTANT ->
          "CONSTANT"
      | Tokens.DEBUG ->
          "DEBUG"
      | Tokens.DIV ->
          "DIV"
      | Tokens.DIVRM ->
          "DIVRM"
      | Tokens.DO ->
          "DO"
      | Tokens.DOT ->
          "DOT"
      | Tokens.DOWNTO ->
          "DOWNTO"
      | Tokens.ELSE ->
          "ELSE"
      | Tokens.ELSIF ->
          "ELSIF"
      | Tokens.END ->
          "END"
      | Tokens.ENUMERATION ->
          "ENUMERATION"
      | Tokens.EOF ->
          "EOF"
      | Tokens.EQ ->
          "EQ"
      | Tokens.EQ_OP ->
          "EQ_OP"
      | Tokens.EXCEPTION ->
          "EXCEPTION"
      | Tokens.FOR ->
          "FOR"
      | Tokens.FUNC ->
          "FUNC"
      | Tokens.GEQ ->
          "GEQ"
      | Tokens.GETTER ->
          "GETTER"
      | Tokens.GT ->
          "GT"
      | Tokens.IDENTIFIER _ ->
          "IDENTIFIER"
      | Tokens.IF ->
          "IF"
      | Tokens.IMPDEF ->
          "IMPDEF"
      | Tokens.IMPL ->
          "IMPL"
      | Tokens.IMPLEMENTATION ->
          "IMPLEMENTATION"
      | Tokens.IN ->
          "IN"
      | Tokens.INTEGER ->
          "INTEGER"
      | Tokens.INT_LIT _ ->
          "INT_LIT"
      | Tokens.LBRACE ->
          "LBRACE"
      | Tokens.LBRACKET ->
          "LBRACKET"
      | Tokens.LEQ ->
          "LEQ"
      | Tokens.LET ->
          "LET"
      | Tokens.LLBRACKET ->
          "LLBRACKET"
      | Tokens.LOOPLIMIT ->
          "LOOPLIMIT"
      | Tokens.LPAR ->
          "LPAR"
      | Tokens.LT ->
          "LT"
      | Tokens.MASK_LIT _ ->
          "MASK_LIT"
      | Tokens.MINUS ->
          "MINUS"
      | Tokens.MOD ->
          "MOD"
      | Tokens.MUL ->
          "MUL"
      | Tokens.NEQ ->
          "NEQ"
      | Tokens.NORETURN ->
          "NORETURN"
      | Tokens.NOT ->
          "NOT"
      | Tokens.OF ->
          "OF"
      | Tokens.OR ->
          "OR"
      | Tokens.OTHERWISE ->
          "OTHERWISE"
      | Tokens.PASS ->
          "PASS"
      | Tokens.PLUS ->
          "PLUS"
      | Tokens.PLUS_COLON ->
          "PLUS_COLON"
      | Tokens.POW ->
          "POW"
      | Tokens.PRAGMA ->
          "PRAGMA"
      | Tokens.PRINT ->
          "PRINT"
      | Tokens.PRINTLN ->
          "PRINTLN"
      | Tokens.PURE ->
          "PURE"
      | Tokens.RBRACE ->
          "RBRACE"
      | Tokens.RBRACKET ->
          "RBRACKET"
      | Tokens.RDIV ->
          "RDIV"
      | Tokens.READONLY ->
          "READONLY"
      | Tokens.REAL ->
          "REAL"
      | Tokens.REAL_LIT _ ->
          "REAL_LIT"
      | Tokens.RECORD ->
          "RECORD"
      | Tokens.RECURSELIMIT ->
          "RECURSELIMIT"
      | Tokens.REPEAT ->
          "REPEAT"
      | Tokens.RETURN ->
          "RETURN"
      | Tokens.RPAR ->
          "RPAR"
      | Tokens.RRBRACKET ->
          "RRBRACKET"
      | Tokens.SEMI_COLON ->
          "SEMI_COLON"
      | Tokens.SETTER ->
          "SETTER"
      | Tokens.SHL ->
          "SHL"
      | Tokens.SHR ->
          "SHR"
      | Tokens.SLICING ->
          "SLICING"
      | Tokens.STAR_COLON ->
          "STAR_COLON"
      | Tokens.STRING ->
          "STRING"
      | Tokens.STRING_LIT _ ->
          "STRING_LIT"
      | Tokens.SUBTYPES ->
          "SUBTYPES"
      | Tokens.THEN ->
          "THEN"
      | Tokens.THROW ->
          "THROW"
      | Tokens.TO ->
          "TO"
      | Tokens.TRY ->
          "TRY"
      | Tokens.TYPE ->
          "TYPE"
      | Tokens.UNREACHABLE ->
          "UNREACHABLE"
      | Tokens.UNTIL ->
          "UNTIL"
      | Tokens.VAR ->
          "VAR"
      | Tokens.WHEN ->
          "WHEN"
      | Tokens.WHERE ->
          "WHERE"
      | Tokens.WHILE ->
          "WHILE"
      | Tokens.WITH ->
          "WITH"
      | Tokens.XOR ->
          "XOR"
  
  let _menhir_fail : unit -> 'a =
    fun () ->
      Printf.eprintf "Internal failure -- please contact the parser generator's developers.\n%!";
      assert false
  
  include struct
    
    [@@@ocaml.warning "-4-37"]
    
    let _menhir_run_567 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let (_2, body) = ((), _v) in
            let _v = _menhir_action_278 _2 body in
            MenhirBox_opn _v
        | _ ->
            _eRR ()
    
    let _menhir_run_927 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_stmts =
      fun _menhir_stack _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let x = _v in
            let _v = _menhir_action_353 x in
            MenhirBox_stmts _v
        | _ ->
            _eRR ()
    
    let _menhir_run_921 : type  ttv_stack. ttv_stack -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let x = _v in
        let _v = _menhir_action_312 x in
        MenhirBox_spec _v
    
    let rec _menhir_run_924 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_decl -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_decl (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_267 x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_goto_list_decl_ : type  ttv_stack. ttv_stack -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _v _menhir_s ->
        match _menhir_s with
        | MenhirState923 ->
            _menhir_run_924 _menhir_stack _v
        | MenhirState570 ->
            _menhir_run_921 _menhir_stack _v
        | _ ->
            _menhir_fail ()
    
    let rec _menhir_run_001 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_WHILE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState001 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_002 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_389 s in
        _menhir_goto_value _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_goto_value : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState476 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState040 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState257 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState183 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState174 ->
            _menhir_run_178 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState904 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState896 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState892 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState791 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState787 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState737 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState655 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState596 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState575 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState540 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState529 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState508 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState504 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState497 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState488 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState481 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState478 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState473 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState468 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState464 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState458 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState453 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState449 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState428 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState424 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState419 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState415 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState394 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState385 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState380 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState375 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState369 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState365 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState340 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState342 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState350 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState347 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState344 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState335 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState311 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState001 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState004 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState005 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState305 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState006 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState300 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState010 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState012 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState282 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState280 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState020 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState273 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState271 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState269 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState267 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState034 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState249 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState244 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState242 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState240 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState238 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState236 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState234 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState226 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState224 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState222 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState220 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState215 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState212 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState210 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState208 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState206 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState204 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState201 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState199 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState197 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState195 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState193 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState191 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState189 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState187 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState185 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState171 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState165 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState159 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState155 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState150 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState146 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState140 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState138 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState136 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState134 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState132 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState117 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState105 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState099 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState097 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState095 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState092 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState090 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState088 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState086 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState084 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState082 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState080 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState078 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState076 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState073 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState071 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState069 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState067 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState065 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState063 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState061 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState059 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState057 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState053 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState041 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState037 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState035 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState032 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState030 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState028 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState026 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState022 ->
            _menhir_run_024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_178 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_value_, _startpos_value_, value) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_205 _endpos_value_ _startpos_value_ value in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_value_ _startpos_value_ _v _menhir_s _tok
    
    and _menhir_goto_expr_pattern : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState056 ->
            _menhir_run_259 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState476 ->
            _menhir_run_184 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState040 ->
            _menhir_run_184 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState257 ->
            _menhir_run_184 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState174 ->
            _menhir_run_184 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState183 ->
            _menhir_run_184 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_259 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_185 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.SLICING ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_187 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_189 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_191 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_246 _endpos__3_ _startpos__1_ x in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_193 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_195 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_197 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_199 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_201 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_204 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_206 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_208 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_210 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_212 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_217 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_220 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_222 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_226 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_229 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_234 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_236 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_238 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_240 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_242 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_244 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_246 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_249 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState259
        | Tokens.COMMA ->
            let (_endpos_expr_pattern_, _startpos_expr_pattern_, expr_pattern) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_287 _endpos_expr_pattern_ _startpos_expr_pattern_ expr_pattern in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_pattern_ _startpos_expr_pattern_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_185 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_XOR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState185 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_003 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_r_, _startpos_r_, r) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_387 r in
        _menhir_goto_value _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_r_ _v _menhir_s _tok
    
    and _menhir_run_004 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState004 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_005 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState005 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_006 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState006 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_007 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_i_, _startpos_i_, i) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_385 i in
        _menhir_goto_value _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_i_ _startpos_i_ _v _menhir_s _tok
    
    and _menhir_run_008 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState008 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_009 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState009
        | Tokens.LBRACE ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState009
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_161 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_010 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState010
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState010
        | Tokens.RPAR ->
            let _v = _menhir_action_030 () in
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_011 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_b_, _startpos_b_, b) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_386 b in
        _menhir_goto_value _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_b_ _v _menhir_s _tok
    
    and _menhir_run_012 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState012 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_013 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_b_, _startpos_b_, b) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_388 b in
        _menhir_goto_value _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_b_ _v _menhir_s _tok
    
    and _menhir_run_014 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ARBITRARY (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_COLON (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState015 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_016 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_372 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_ty : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState652 ->
            _menhir_run_653 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState607 ->
            _menhir_run_623 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState578 ->
            _menhir_run_594 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState546 ->
            _menhir_run_552 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState548 ->
            _menhir_run_549 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState015 ->
            _menhir_run_295 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState290 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState018 ->
            _menhir_run_289 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState246 ->
            _menhir_run_247 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState176 ->
            _menhir_run_177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState101 ->
            _menhir_run_130 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState114 ->
            _menhir_run_122 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState120 ->
            _menhir_run_121 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_653 : type  ttv_stack. (((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_ARROW -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_ARROW (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, _2) = ((), _v) in
        let _v = _menhir_action_300 _1 _2 in
        _menhir_goto_return_type _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_return_type : type  ttv_stack. (((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState879 ->
            _menhir_run_884 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState854 ->
            _menhir_run_859 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState800 ->
            _menhir_run_805 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState774 ->
            _menhir_run_779 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState760 ->
            _menhir_run_765 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState745 ->
            _menhir_run_750 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState725 ->
            _menhir_run_730 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState711 ->
            _menhir_run_716 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState696 ->
            _menhir_run_701 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState680 ->
            _menhir_run_685 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState666 ->
            _menhir_run_671 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState646 ->
            _menhir_run_654 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_884 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_655 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState884
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_298 () in
            _menhir_run_885 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState884
        | _ ->
            _eRR ()
    
    and _menhir_run_655 : type  ttv_stack. ((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_RECURSELIMIT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState655 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_885 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState886
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState886
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_277 _endpos__0_
            in
            _menhir_run_887 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_315 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_316 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState315
        | Tokens.LPAR ->
            _menhir_run_317 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState315
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.COMMA ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState315, _v, _startpos_0, _endpos) in
                let _menhir_s = MenhirState329 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_330 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON | Tokens.EQ ->
                let _v =
                  let _1 = _v in
                  _menhir_action_144 _1
                in
                _menhir_run_334 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState315 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_316 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_143 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_decl_item : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState462 ->
            _menhir_run_463 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState412 ->
            _menhir_run_414 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState315 ->
            _menhir_run_334 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_463 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_CONSTANT as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_EQ (_menhir_stack, MenhirState463) in
            let _menhir_s = MenhirState464 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState463
        | _ ->
            _eRR ()
    
    and _menhir_run_114 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_COLON (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState114 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_017 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_370 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_run_018 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState018 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RPAR ->
            let _v = _menhir_action_032 () in
            _menhir_goto_clist0_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_run_019 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState019 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            _menhir_run_020 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RECURSELIMIT | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.SUBTYPES | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let _v = _menhir_action_073 () in
            _menhir_goto_constraint_kind_opt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_020 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.RBRACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_startpos__1_, _1, _endpos__2_, _2) = (_startpos, (), _endpos, ()) in
            let _v = _menhir_action_071 _1 _2 in
            _menhir_goto_constraint_kind _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _startpos__1_ _v _menhir_s _tok
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | Tokens.MINUS ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState022
            | Tokens.REAL_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState022
            | Tokens.RBRACE ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_startpos__1_, x, _endpos__3_) = (_startpos, (), _endpos_1) in
                let _v = _menhir_action_070 _endpos__3_ _startpos__1_ x in
                _menhir_goto_constraint_kind _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState022
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState022
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState022
            | Tokens.INT_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState022
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState022
            | Tokens.IDENTIFIER _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState022
            | Tokens.BOOL_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState022
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState022
            | Tokens.BITVECTOR_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState022
            | Tokens.ARBITRARY ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState020, _startpos_0, _endpos) in
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState022
            | _ ->
                _eRR ())
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState020
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState020
        | _ ->
            _eRR ()
    
    and _menhir_goto_constraint_kind : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState019 ->
            _menhir_run_288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState246 ->
            _menhir_run_248 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState101 ->
            _menhir_run_131 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_288 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_INTEGER -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos__1_, _1) = (_endpos, _v) in
        let _v = _menhir_action_072 _1 in
        _menhir_goto_constraint_kind_opt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
    
    and _menhir_goto_constraint_kind_opt : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_INTEGER -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_c_, c) = ((), _endpos, _v) in
        let _v = _menhir_action_369 _1 _endpos_c_ _startpos__1_ c in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_c_ _v _menhir_s _tok
    
    and _menhir_run_248 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_AS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let MenhirCell1_AS (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, expr_pattern, _startpos_expr_pattern_, _) = _menhir_stack in
        let (_2, _endpos_constraint_kind_, _startpos_constraint_kind_, constraint_kind) = ((), _endpos, _startpos, _v) in
        let _v = _menhir_action_241 _2 _endpos_constraint_kind_ _startpos_constraint_kind_ _startpos_expr_pattern_ constraint_kind expr_pattern in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_constraint_kind_ _startpos_expr_pattern_ _v _menhir_s _tok
    
    and _menhir_run_131 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_AS -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let MenhirCell1_AS (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, expr, _startpos_expr_, _) = _menhir_stack in
        let (_2, _endpos_constraint_kind_, _startpos_constraint_kind_, constraint_kind) = ((), _endpos, _startpos, _v) in
        let _v = _menhir_action_196 _2 _endpos_constraint_kind_ _startpos_constraint_kind_ _startpos_expr_ constraint_kind expr in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_constraint_kind_ _startpos_expr_ _v _menhir_s _tok
    
    and _menhir_goto_expr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState904 ->
            _menhir_run_905 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState896 ->
            _menhir_run_897 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState892 ->
            _menhir_run_893 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState791 ->
            _menhir_run_792 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState787 ->
            _menhir_run_788 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState655 ->
            _menhir_run_656 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState596 ->
            _menhir_run_597 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState575 ->
            _menhir_run_576 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState540 ->
            _menhir_run_541 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState529 ->
            _menhir_run_530 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState508 ->
            _menhir_run_509 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState504 ->
            _menhir_run_505 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState497 ->
            _menhir_run_498 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState488 ->
            _menhir_run_489 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState481 ->
            _menhir_run_482 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState478 ->
            _menhir_run_479 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState473 ->
            _menhir_run_474 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState468 ->
            _menhir_run_469 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState464 ->
            _menhir_run_465 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState453 ->
            _menhir_run_454 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState449 ->
            _menhir_run_450 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState424 ->
            _menhir_run_425 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState419 ->
            _menhir_run_420 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState415 ->
            _menhir_run_416 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState394 ->
            _menhir_run_395 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState369 ->
            _menhir_run_372 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState365 ->
            _menhir_run_367 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState340 ->
            _menhir_run_353 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState335 ->
            _menhir_run_336 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState311 ->
            _menhir_run_312 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState001 ->
            _menhir_run_310 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState004 ->
            _menhir_run_309 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState006 ->
            _menhir_run_303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState300 ->
            _menhir_run_301 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_299 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState012 ->
            _menhir_run_296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState282 ->
            _menhir_run_283 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState020 ->
            _menhir_run_281 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState280 ->
            _menhir_run_281 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState273 ->
            _menhir_run_274 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState271 ->
            _menhir_run_272 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState269 ->
            _menhir_run_270 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState034 ->
            _menhir_run_268 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState267 ->
            _menhir_run_268 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_255 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState249 ->
            _menhir_run_250 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState244 ->
            _menhir_run_245 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState242 ->
            _menhir_run_243 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState240 ->
            _menhir_run_241 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState238 ->
            _menhir_run_239 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState236 ->
            _menhir_run_237 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState234 ->
            _menhir_run_235 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState226 ->
            _menhir_run_228 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState224 ->
            _menhir_run_225 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState222 ->
            _menhir_run_223 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState220 ->
            _menhir_run_221 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState215 ->
            _menhir_run_216 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState212 ->
            _menhir_run_213 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState210 ->
            _menhir_run_211 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState208 ->
            _menhir_run_209 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState206 ->
            _menhir_run_207 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState204 ->
            _menhir_run_205 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState201 ->
            _menhir_run_203 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState199 ->
            _menhir_run_200 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState197 ->
            _menhir_run_198 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState195 ->
            _menhir_run_196 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState193 ->
            _menhir_run_194 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState191 ->
            _menhir_run_192 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState189 ->
            _menhir_run_190 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState187 ->
            _menhir_run_188 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState185 ->
            _menhir_run_186 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState171 ->
            _menhir_run_172 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState737 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState458 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState428 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState385 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState380 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState375 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState342 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState350 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState347 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState344 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState305 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState010 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState165 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState159 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState155 ->
            _menhir_run_156 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState140 ->
            _menhir_run_141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState138 ->
            _menhir_run_139 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState136 ->
            _menhir_run_137 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState134 ->
            _menhir_run_135 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState132 ->
            _menhir_run_133 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState117 ->
            _menhir_run_118 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState105 ->
            _menhir_run_106 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState099 ->
            _menhir_run_100 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState097 ->
            _menhir_run_098 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState095 ->
            _menhir_run_096 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState092 ->
            _menhir_run_094 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState090 ->
            _menhir_run_091 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState088 ->
            _menhir_run_089 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState086 ->
            _menhir_run_087 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState084 ->
            _menhir_run_085 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState082 ->
            _menhir_run_083 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState080 ->
            _menhir_run_081 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState078 ->
            _menhir_run_079 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState076 ->
            _menhir_run_077 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState073 ->
            _menhir_run_075 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState071 ->
            _menhir_run_072 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState069 ->
            _menhir_run_070 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState067 ->
            _menhir_run_068 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState065 ->
            _menhir_run_066 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState063 ->
            _menhir_run_064 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState061 ->
            _menhir_run_062 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState059 ->
            _menhir_run_060 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState057 ->
            _menhir_run_058 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState053 ->
            _menhir_run_054 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState041 ->
            _menhir_run_042 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState037 ->
            _menhir_run_038 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState035 ->
            _menhir_run_036 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState032 ->
            _menhir_run_033 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState030 ->
            _menhir_run_031 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState028 ->
            _menhir_run_029 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState026 ->
            _menhir_run_027 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState005 ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState150 ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState146 ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState022 ->
            _menhir_run_025 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_905 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_CONFIG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, x, _4) = ((), _endpos_0, _v, ()) in
            let _v = _menhir_action_130 _1 _4 _endpos__2_ _startpos__1_ name ty x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState905
        | _ ->
            _eRR ()
    
    and _menhir_run_028 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_XOR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState028 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_030 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SHR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState030 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_037 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SHL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState037 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_decl : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_decl (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_571 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState923
        | Tokens.TYPE ->
            _menhir_run_601 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState923
        | Tokens.READONLY ->
            _menhir_run_626 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState923
        | Tokens.PURE ->
            _menhir_run_691 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState923
        | Tokens.PRAGMA ->
            _menhir_run_736 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState923
        | Tokens.NORETURN ->
            _menhir_run_740 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState923
        | Tokens.LET ->
            _menhir_run_785 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState923
        | Tokens.IMPLEMENTATION ->
            _menhir_run_796 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState923
        | Tokens.IMPDEF ->
            _menhir_run_850 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState923
        | Tokens.FUNC ->
            _menhir_run_876 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState923
        | Tokens.CONSTANT ->
            _menhir_run_890 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState923
        | Tokens.CONFIG ->
            _menhir_run_901 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState923
        | Tokens.ACCESSOR ->
            _menhir_run_909 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState923
        | Tokens.EOF ->
            let _v_0 = _menhir_action_266 () in
            _menhir_run_924 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_571 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState571 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_572 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_573 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_572 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_255 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ignored_or_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_ignored_or_identifier : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState901 ->
            _menhir_run_902 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState890 ->
            _menhir_run_891 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState785 ->
            _menhir_run_786 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState571 ->
            _menhir_run_574 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_902 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ignored_or_identifier (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState902
        | _ ->
            _eRR ()
    
    and _menhir_run_891 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ignored_or_identifier (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_EQ (_menhir_stack, MenhirState891) in
            let _menhir_s = MenhirState892 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState891
        | _ ->
            _eRR ()
    
    and _menhir_run_786 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_LET as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ignored_or_identifier (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_EQ (_menhir_stack, MenhirState786) in
            let _menhir_s = MenhirState787 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState786
        | _ ->
            _eRR ()
    
    and _menhir_run_574 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ignored_or_identifier (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_EQ (_menhir_stack, MenhirState574) in
            let _menhir_s = MenhirState575 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_COLON (_menhir_stack, MenhirState574, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState578
            | Tokens.REAL ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState578
            | Tokens.LPAR ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState578
            | Tokens.INTEGER ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState578
            | Tokens.IDENTIFIER _v_6 ->
                _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState578
            | Tokens.COLLECTION ->
                let _startpos_7 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell1_COLLECTION (_menhir_stack, MenhirState578, _startpos_7) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_580 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState579
                | Tokens.SEMI_COLON ->
                    let _v_9 = _menhir_action_252 () in
                    _menhir_run_590 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_8 _v_9 _tok
                | _ ->
                    _eRR ())
            | Tokens.BOOLEAN ->
                _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState578
            | Tokens.BITS ->
                _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState578
            | Tokens.BIT ->
                _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState578
            | Tokens.ARRAY ->
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState578
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_102 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_name_, _startpos_name_, name) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_376 _endpos_name_ _startpos_name_ name in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_name_ _v _menhir_s _tok
    
    and _menhir_run_580 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.RBRACE ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (x, _endpos__3_) = ((), _endpos_1) in
                let _v = _menhir_action_250 x in
                _menhir_goto_fields _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_583 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState580
        | _ ->
            _eRR ()
    
    and _menhir_goto_fields : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState605 ->
            _menhir_run_606 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState610 ->
            _menhir_run_591 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState608 ->
            _menhir_run_591 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState579 ->
            _menhir_run_591 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_606 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_SUBTYPES _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, _2, _, _) = _menhir_stack in
        let MenhirCell1_SUBTYPES (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _1_inlined1, _endpos_fields_, fields) = ((), (), _endpos, _v) in
        let _v = _menhir_action_355 _1 _1_inlined1 _2 fields in
        _menhir_goto_subtype _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_fields_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_subtype : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState602 ->
            _menhir_run_624 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState619 ->
            _menhir_run_622 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_624 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
            let MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _endpos_desc_, _startpos_desc_, desc) = ((), _endpos_0, _endpos, _startpos, _v) in
            let _v = _menhir_action_123 _1 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_622 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_ty_decl -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let x = _v in
        let _v = _menhir_action_357 x in
        _menhir_goto_subtype_opt _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
    
    and _menhir_goto_subtype_opt : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_ty_decl -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_ty_decl (_menhir_stack, _, t) = _menhir_stack in
            let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
            let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
            let MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _3, subtype_opt) = ((), _endpos, (), _v) in
            let _v = _menhir_action_122 _1 _3 _endpos__2_ _startpos__1_ subtype_opt t x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_591 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let (_endpos__1_, _1) = (_endpos, _v) in
        let _v = _menhir_action_253 _1 in
        _menhir_goto_fields_opt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_fields_opt : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState610 ->
            _menhir_run_611 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState608 ->
            _menhir_run_609 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState579 ->
            _menhir_run_590 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_611 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_EXCEPTION -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_EXCEPTION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_l_, l) = ((), _endpos, _v) in
        let _v = _menhir_action_381 _1 _endpos_l_ _startpos__1_ l in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_ty_decl : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty_decl (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SUBTYPES ->
            _menhir_run_603 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState619
        | Tokens.SEMI_COLON ->
            let _v = _menhir_action_356 () in
            _menhir_goto_subtype_opt _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_603 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WITH ->
                let _menhir_stack = MenhirCell1_SUBTYPES (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                let _menhir_s = MenhirState605 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_580 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.SEMI_COLON ->
                let (_startpos__1_, _1, _endpos__2_, _2) = (_startpos, (), _endpos, _v) in
                let _v = _menhir_action_354 _1 _2 in
                _menhir_goto_subtype _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _startpos__1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_609 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_RECORD -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_RECORD (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_l_, l) = ((), _endpos, _v) in
        let _v = _menhir_action_380 _1 _endpos_l_ _startpos__1_ l in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_590 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_COLON, _menhir_box_spec) _menhir_cell1_COLLECTION -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_COLLECTION (_menhir_stack, _, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_l_, l) = ((), _endpos, _v) in
        let _v = _menhir_action_383 _1 _endpos_l_ _startpos__1_ l in
        _menhir_goto_ty_or_collection _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
    
    and _menhir_goto_ty_or_collection : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_COLON -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_COLON (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, x, _3) = ((), _endpos, _v, ()) in
            let _v = _menhir_action_135 _1 _3 _endpos__2_ _startpos__1_ name x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_583 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _menhir_s = MenhirState583 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_103 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_371 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_run_104 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_BITS (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState105 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_115 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_desc_, _startpos_desc_, desc) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_373 _endpos_desc_ _startpos_desc_ desc in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_116 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ARRAY (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_s = MenhirState117 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_573 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = _v in
        let _v = _menhir_action_256 _1 in
        _menhir_goto_ignored_or_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_601 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SUBTYPES ->
                _menhir_run_603 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState602
            | Tokens.OF ->
                let _menhir_stack = MenhirCell1_OF (_menhir_stack, MenhirState602) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState607
                | Tokens.RECORD ->
                    let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell1_RECORD (_menhir_stack, MenhirState607, _startpos_1) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        _menhir_run_580 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState608
                    | Tokens.SEMI_COLON | Tokens.SUBTYPES ->
                        let _v_3 = _menhir_action_252 () in
                        _menhir_run_609 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_2 _v_3 _tok
                    | _ ->
                        _eRR ())
                | Tokens.REAL ->
                    _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState607
                | Tokens.LPAR ->
                    _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState607
                | Tokens.INTEGER ->
                    _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState607
                | Tokens.IDENTIFIER _v_4 ->
                    _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState607
                | Tokens.EXCEPTION ->
                    let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_6 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell1_EXCEPTION (_menhir_stack, MenhirState607, _startpos_5) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        _menhir_run_580 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState610
                    | Tokens.SEMI_COLON | Tokens.SUBTYPES ->
                        let _v_7 = _menhir_action_252 () in
                        _menhir_run_611 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_6 _v_7 _tok
                    | _ ->
                        _eRR ())
                | Tokens.ENUMERATION ->
                    let _menhir_s = MenhirState607 in
                    let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                    let _menhir_stack = MenhirCell1_ENUMERATION (_menhir_stack, _menhir_s, _startpos) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
                        let _menhir_s = MenhirState613 in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.IDENTIFIER _v ->
                            _menhir_run_614 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | Tokens.BOOLEAN ->
                    _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState607
                | Tokens.BITS ->
                    _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState607
                | Tokens.BIT ->
                    _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState607
                | Tokens.ARRAY ->
                    _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState607
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_614 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v_0 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                _menhir_run_614 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState615
            | Tokens.RBRACE ->
                let (x, x_inlined1) = (_v, ()) in
                let _v = _menhir_action_361 x x_inlined1 in
                _menhir_goto_tclist1_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_360 x in
            _menhir_goto_tclist1_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_tclist1_IDENTIFIER_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState613 ->
            _menhir_run_617 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState615 ->
            _menhir_run_616 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_617 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF, _menhir_box_spec) _menhir_cell1_ENUMERATION _menhir_cell0_LBRACE -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_ENUMERATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, x, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_379 _1 _endpos__3_ _startpos__1_ x in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_616 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, h, _, _) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_362 _2 h t in
        _menhir_goto_tclist1_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_626 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_READONLY (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IMPLEMENTATION ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_IMPLEMENTATION (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.FUNC ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_FUNC (_menhir_stack, _startpos_1) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_2, _endpos) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState629
                    | Tokens.LPAR ->
                        let _v_3 = _menhir_action_285 () in
                        _menhir_run_638 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState629 _tok
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.IMPDEF ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_IMPDEF (_menhir_stack, _startpos_4) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.FUNC ->
                let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_FUNC (_menhir_stack, _startpos_5) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_6, _endpos) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState664
                    | Tokens.LPAR ->
                        let _v_7 = _menhir_action_285 () in
                        _menhir_run_665 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 MenhirState664 _tok
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.FUNC ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_FUNC (_menhir_stack, _startpos_8) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_9, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState678
                | Tokens.LPAR ->
                    let _v_10 = _menhir_action_285 () in
                    _menhir_run_679 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10 MenhirState678 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_630 : type  ttv_stack. (ttv_stack _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState630 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            _menhir_run_631 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_631 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState631
        | Tokens.COMMA | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_279 x in
            _menhir_goto_opt_typed_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_opt_typed_identifier : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_opt_typed_identifier (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState634 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_631 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_052 x in
            _menhir_goto_clist1_opt_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_opt_typed_identifier_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState630 ->
            _menhir_run_636 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState634 ->
            _menhir_run_635 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_636 : type  ttv_stack. (ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_LBRACE -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let x = _v in
        let _v = _menhir_action_286 x in
        _menhir_goto_params_opt _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_params_opt : type  ttv_stack. (ttv_stack _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState910 ->
            _menhir_run_911 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState877 ->
            _menhir_run_878 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState866 ->
            _menhir_run_867 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState852 ->
            _menhir_run_853 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState812 ->
            _menhir_run_813 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState798 ->
            _menhir_run_799 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState772 ->
            _menhir_run_773 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState758 ->
            _menhir_run_759 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState743 ->
            _menhir_run_744 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState723 ->
            _menhir_run_724 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState709 ->
            _menhir_run_710 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState694 ->
            _menhir_run_695 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState678 ->
            _menhir_run_679 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState664 ->
            _menhir_run_665 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState629 ->
            _menhir_run_638 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_911 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState911
        | _ ->
            _eRR ()
    
    and _menhir_run_639 : type  ttv_stack. ((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState639 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            _menhir_run_583 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.RPAR ->
            let _v = _menhir_action_034 () in
            _menhir_goto_clist0_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist0_typed_identifier_ : type  ttv_stack. ((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_LPAR -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let x = _v in
        let _v = _menhir_action_254 x in
        _menhir_goto_func_args _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_func_args : type  ttv_stack. ((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState911 ->
            _menhir_run_912 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState878 ->
            _menhir_run_879 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState867 ->
            _menhir_run_868 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState853 ->
            _menhir_run_854 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState813 ->
            _menhir_run_814 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState799 ->
            _menhir_run_800 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState773 ->
            _menhir_run_774 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState759 ->
            _menhir_run_760 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState744 ->
            _menhir_run_745 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState724 ->
            _menhir_run_725 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState710 ->
            _menhir_run_711 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState695 ->
            _menhir_run_696 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState679 ->
            _menhir_run_680 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState665 ->
            _menhir_run_666 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState638 ->
            _menhir_run_646 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_912 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                let _menhir_s = MenhirState914 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.COLON ->
                    _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_879 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState879) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState880
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState880
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_277 _endpos__0_
                in
                _menhir_run_881 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_652 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState879
        | _ ->
            _eRR ()
    
    and _menhir_run_360 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.RPAR ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.SEMI_COLON ->
                    let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_startpos__1_, _1, _endpos__2_, _3, _2_inlined1) = (_startpos, (), _endpos_1, (), ()) in
                    let _v = _menhir_action_347 _1 _2_inlined1 _3 _endpos__2_ _startpos__1_ in
                    _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_goto_stmt : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState000 ->
            _menhir_run_567 _menhir_stack _v _tok
        | MenhirState925 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState886 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState880 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState861 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState855 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState843 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState838 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState835 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState830 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState825 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState819 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState807 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState801 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState781 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState775 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState767 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState761 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState752 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState746 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState732 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState726 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState718 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState712 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState703 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState697 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState687 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState681 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState673 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState667 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState658 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState647 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState314 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState364 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState557 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState553 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState550 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState373 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState426 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState531 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState533 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState456 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState517 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState513 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState485 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState480 ->
            _menhir_run_485 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_485 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.VAR ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.UNREACHABLE ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.TRY ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.THROW ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.RETURN ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.REPEAT ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.PRINTLN ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.PRINT ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.PRAGMA ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.PASS ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.LET ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.IDENTIFIER _v_0 ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState485
        | Tokens.FOR ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.DEBUG ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.CONSTANT ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.CASE ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.ASSERT ->
            let _menhir_stack = MenhirCell1_stmt (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState485
        | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
            let (_endpos_x_, x) = (_endpos, _v) in
            let _v = _menhir_action_272 x in
            _menhir_goto_list1_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_364 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_TRY (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState364 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_365 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState365
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_startpos__1_, _1, _endpos__2_) = (_startpos, (), _endpos) in
            let _v = _menhir_action_350 _1 _endpos__2_ _startpos__1_ in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState365
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState365
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState365
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState365
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState365
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState365
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState365
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState365
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState365
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState365
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState365
        | _ ->
            _eRR ()
    
    and _menhir_run_369 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState369 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.SEMI_COLON ->
            let _v = _menhir_action_281 () in
            _menhir_goto_option_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_goto_option_expr_ : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_RETURN -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos__2_, _2_inlined1) = ((), _endpos, _v) in
        let _v = _menhir_action_326 _1 _2_inlined1 _endpos__2_ _startpos__1_ in
        _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
    
    and _menhir_run_373 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_REPEAT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState373 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_374 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_PRINTLN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState375
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState375
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState375
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState375
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState375
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState375
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState375
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState375
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState375
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState375
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState375
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState375
            | Tokens.RPAR ->
                let _v = _menhir_action_030 () in
                _menhir_run_376 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_376 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_PRINTLN _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PRINTLN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, x) = ((), _endpos_0, _v) in
                let _v = _menhir_action_344 _1 _endpos__2_ _startpos__1_ x in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_379 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState380
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState380
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState380
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState380
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState380
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState380
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState380
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState380
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState380
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState380
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState380
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState380
            | Tokens.RPAR ->
                let _v = _menhir_action_030 () in
                _menhir_run_381 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_381 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_PRINT _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, x) = ((), _endpos_0, _v) in
                let _v = _menhir_action_345 _1 _endpos__2_ _startpos__1_ x in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_384 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v_1 ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState385
            | Tokens.REAL_LIT _v_2 ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState385
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState385
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState385
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState385
            | Tokens.INT_LIT _v_3 ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState385
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState385
            | Tokens.IDENTIFIER _v_4 ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState385
            | Tokens.BOOL_LIT _v_5 ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState385
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState385
            | Tokens.BITVECTOR_LIT _v_6 ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState385
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState385
            | Tokens.SEMI_COLON ->
                let _v_7 = _menhir_action_030 () in
                _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_386 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
            let MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_351 _1 _endpos__2_ _startpos__1_ e x in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_388 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_startpos__1_, _1, _endpos__2_) = (_startpos, (), _endpos) in
            let _v = _menhir_action_325 _1 _endpos__2_ _startpos__1_ in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_390 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_263 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_lexpr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_lexpr (_menhir_stack, _menhir_s, _v, _startpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState488 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_391 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState391 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_392 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_393 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_392 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = () in
        let _v = _menhir_action_148 _1 in
        _menhir_goto_discard_or_basic_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_discard_or_basic_lexpr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState406 ->
            _menhir_run_405 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState404 ->
            _menhir_run_405 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState391 ->
            _menhir_run_403 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_405 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_basic_lexpr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_discard_or_basic_lexpr (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState406 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_392 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_393 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_040 x in
            _menhir_goto_clist1_discard_or_basic_lexpr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_393 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            _menhir_run_394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState393
        | Tokens.DOT ->
            _menhir_run_397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState393
        | Tokens.COMMA | Tokens.LBRACKET | Tokens.RPAR ->
            let _v_0 = _menhir_action_003 () in
            _menhir_run_401 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState393 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_394 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LLBRACKET (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState394 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_397 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DOT (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            _menhir_run_398 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_run_398 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_DOT -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            _menhir_run_394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState398
        | Tokens.DOT ->
            _menhir_run_397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState398
        | Tokens.COMMA | Tokens.EQ | Tokens.LBRACKET | Tokens.RPAR ->
            let _v_0 = _menhir_action_003 () in
            _menhir_run_399 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_399 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_DOT _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let MenhirCell1_DOT (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, t) = ((), _v) in
        let _v = _menhir_action_004 _1 _endpos_desc_ _startpos_desc_ desc t in
        _menhir_goto_access _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_access : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState427 ->
            _menhir_run_401 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState393 ->
            _menhir_run_401 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState396 ->
            _menhir_run_400 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState398 ->
            _menhir_run_399 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_401 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_access (_menhir_stack, _menhir_s, _v) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState401
        | Tokens.COMMA | Tokens.EQ | Tokens.RPAR ->
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let access = _v in
            let _v = _menhir_action_015 _endpos_desc_ _startpos_desc_ access desc in
            _menhir_goto_basic_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_desc_ _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_034 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACKET (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState034 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.COLON ->
            _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_035 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_COLON (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState035 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_basic_lexpr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState925 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState886 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState880 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState861 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState855 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState835 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState843 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState838 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState819 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState830 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState825 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState807 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState801 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState781 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState775 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState767 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState761 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState752 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState746 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState732 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState726 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState718 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState712 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState703 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState697 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState687 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState681 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState673 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState667 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState658 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState647 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState314 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState364 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState557 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState553 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState550 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState373 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState426 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState531 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState533 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState456 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState517 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState513 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState480 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState485 ->
            _menhir_run_511 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState391 ->
            _menhir_run_408 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState404 ->
            _menhir_run_408 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState406 ->
            _menhir_run_408 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_511 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let (_startpos_basic_lexpr_, basic_lexpr) = (_startpos, _v) in
        let _v = _menhir_action_261 basic_lexpr in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_basic_lexpr_ _v _menhir_s _tok
    
    and _menhir_run_408 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let basic_lexpr = _v in
        let _v = _menhir_action_149 basic_lexpr in
        _menhir_goto_discard_or_basic_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_400 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LLBRACKET, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RRBRACKET -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_RRBRACKET (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, idx, _, _) = _menhir_stack in
        let MenhirCell1_LLBRACKET (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, _3, t) = ((), (), _v) in
        let _v = _menhir_action_005 _1 _3 idx t in
        _menhir_goto_access _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_clist1_discard_or_basic_lexpr_ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_basic_lexpr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState404 ->
            _menhir_run_409 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState406 ->
            _menhir_run_407 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_409 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_discard_or_basic_lexpr -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_basic_lexpr (_menhir_stack, _, x) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_064 _2 li x in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_262 _endpos__3_ _startpos__1_ x in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_407 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_basic_lexpr, ttv_result) _menhir_cell1_discard_or_basic_lexpr -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_basic_lexpr (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_041 _2 h t in
        _menhir_goto_clist1_discard_or_basic_lexpr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_403 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_discard_or_basic_lexpr (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState404 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_392 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_393 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_412 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState412 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_316 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_317 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_317 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState317 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_318 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_319 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_318 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = () in
        let _v = _menhir_action_152 _1 in
        _menhir_goto_discard_or_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_discard_or_identifier : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState323 ->
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState321 ->
            _menhir_run_322 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState317 ->
            _menhir_run_320 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_322 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_discard_or_identifier (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState323 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_318 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_319 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_044 x in
            _menhir_goto_clist1_discard_or_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_319 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = _v in
        let _v = _menhir_action_153 _1 in
        _menhir_goto_discard_or_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_clist1_discard_or_identifier_ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState321 ->
            _menhir_run_325 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState323 ->
            _menhir_run_324 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_325 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_discard_or_identifier -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_identifier (_menhir_stack, _, x) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_066 _2 li x in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_145 _endpos__3_ _startpos__1_ x in
        _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_324 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_identifier, ttv_result) _menhir_cell1_discard_or_identifier -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_identifier (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_045 _2 h t in
        _menhir_goto_clist1_discard_or_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_320 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_discard_or_identifier (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState321 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_318 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_319 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_413 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = _v in
        let _v = _menhir_action_144 _1 in
        _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_424 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState424 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_427 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Tokens.LLBRACKET ->
            _menhir_run_394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState427
        | Tokens.LBRACE ->
            let _menhir_s = MenhirState427 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            let _menhir_s = MenhirState428 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_DOT (_menhir_stack, MenhirState427) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState430 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.MINUS ->
                    _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_432 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.LBRACKET ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LBRACKET (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState441 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_442 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.IDENTIFIER _v ->
                _menhir_run_398 _menhir_stack _menhir_lexbuf _menhir_lexer _v
            | _ ->
                _eRR ())
        | Tokens.EQ | Tokens.LBRACKET ->
            let _v_12 = _menhir_action_003 () in
            _menhir_run_401 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState427 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_431 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = () in
        let _v = _menhir_action_150 _1 in
        _menhir_goto_discard_or_field _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_discard_or_field : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState436 ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState434 ->
            _menhir_run_435 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState430 ->
            _menhir_run_433 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_435 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_field as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_discard_or_field (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState436 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_432 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_042 x in
            _menhir_goto_clist1_discard_or_field_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_432 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_desc_, _startpos_desc_, desc) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_151 _endpos_desc_ _startpos_desc_ desc in
        _menhir_goto_discard_or_field _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_clist1_discard_or_field_ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_field as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState434 ->
            _menhir_run_438 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState436 ->
            _menhir_run_437 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_438 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_DOT _menhir_cell0_LPAR, ttv_result) _menhir_cell1_discard_or_field -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_field (_menhir_stack, _, x) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_065 _2 li x in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_DOT (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (_2, x, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_265 _2 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_437 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_discard_or_field, ttv_result) _menhir_cell1_discard_or_field -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_discard_or_field (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_043 _2 h t in
        _menhir_goto_clist1_discard_or_field_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_433 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_DOT _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_discard_or_field (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState434 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_431 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_432 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_442 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState443 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_045 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_045 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState046 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_045 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACKET ->
            let x = _v in
            let _v = _menhir_action_036 x in
            _menhir_goto_clist1_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_IDENTIFIER_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState443 ->
            _menhir_run_444 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState230 ->
            _menhir_run_231 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState044 ->
            _menhir_run_048 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState046 ->
            _menhir_run_047 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_444 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_062 _2 li x in
        _menhir_goto_clist2_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_goto_clist2_IDENTIFIER_ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState494 ->
            _menhir_run_495 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState441 ->
            _menhir_run_445 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_495 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_call, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_clist2_IDENTIFIER_ (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_RBRACKET (_menhir_stack, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState497 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_445 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACKET (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_DOT (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (_2, x, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_264 _2 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_231 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACKET (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_DOT (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
        let (_2, x, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_239 _2 _endpos__3_ _startpos_e_ e x in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_e_ _v _menhir_s _tok
    
    and _menhir_run_048 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACKET (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_DOT (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
        let (_2, x, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_194 _2 _endpos__3_ _startpos_e_ e x in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_e_ _v _menhir_s _tok
    
    and _menhir_run_047 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, h, _, _) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_037 _2 h t in
        _menhir_goto_clist1_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_447 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState449 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v ->
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.ARBITRARY ->
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_457 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState458
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState458
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState458
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState458
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState458
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState458
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState458
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState458
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState458
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState458
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState458
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState458
            | Tokens.RPAR ->
                let _v = _menhir_action_030 () in
                _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_459 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_DEBUG _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, x) = ((), _endpos_0, _v) in
                let _v = _menhir_action_346 _1 _endpos__2_ _startpos__1_ x in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_462 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState462 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_316 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_317 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_413 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_473 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState473 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_481 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ASSERT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState481 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_list1_stmt_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState925 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState886 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState880 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState861 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState855 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState835 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState843 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState838 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState819 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState830 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState825 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState807 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState801 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState781 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState775 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState767 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState761 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState752 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState746 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState732 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState726 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState718 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState712 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState703 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState697 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState687 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState681 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState673 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState667 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState658 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState647 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState314 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState364 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState557 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState553 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState550 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState373 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState426 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState531 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState533 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState456 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState517 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState513 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState480 ->
            _menhir_run_512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState485 ->
            _menhir_run_486 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_512 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let (_endpos__1_, _1) = (_endpos, _v) in
        let _v = _menhir_action_352 _1 in
        _menhir_goto_stmt_list _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_stmt_list : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState925 ->
            _menhir_run_927 _menhir_stack _v _tok
        | MenhirState886 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState880 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState861 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState855 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState843 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState838 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState835 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState830 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState825 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState819 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState807 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState801 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState781 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState775 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState767 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState761 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState752 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState746 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState732 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState726 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState718 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState712 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState703 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState697 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState687 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState681 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState673 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState667 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState658 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState647 ->
            _menhir_run_648 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState314 ->
            _menhir_run_564 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState557 ->
            _menhir_run_558 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState553 ->
            _menhir_run_554 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState550 ->
            _menhir_run_551 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState364 ->
            _menhir_run_544 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState373 ->
            _menhir_run_539 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState533 ->
            _menhir_run_534 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState531 ->
            _menhir_run_532 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState426 ->
            _menhir_run_528 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState456 ->
            _menhir_run_525 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState517 ->
            _menhir_run_518 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState513 ->
            _menhir_run_514 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState480 ->
            _menhir_run_484 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_648 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _1 = _v in
        let _v = _menhir_action_276 _1 in
        _menhir_goto_maybe_empty_stmt_list _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_maybe_empty_stmt_list : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState886 ->
            _menhir_run_887 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState880 ->
            _menhir_run_881 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState861 ->
            _menhir_run_862 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState855 ->
            _menhir_run_856 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState843 ->
            _menhir_run_844 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState838 ->
            _menhir_run_839 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState835 ->
            _menhir_run_836 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState830 ->
            _menhir_run_831 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState825 ->
            _menhir_run_826 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState819 ->
            _menhir_run_820 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState807 ->
            _menhir_run_808 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState801 ->
            _menhir_run_802 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState781 ->
            _menhir_run_782 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState775 ->
            _menhir_run_776 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState767 ->
            _menhir_run_768 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState761 ->
            _menhir_run_762 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState752 ->
            _menhir_run_753 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState746 ->
            _menhir_run_747 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState732 ->
            _menhir_run_733 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState726 ->
            _menhir_run_727 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState718 ->
            _menhir_run_719 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState712 ->
            _menhir_run_713 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState703 ->
            _menhir_run_704 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState697 ->
            _menhir_run_698 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState687 ->
            _menhir_run_688 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState681 ->
            _menhir_run_682 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState673 ->
            _menhir_run_674 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState667 ->
            _menhir_run_668 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState658 ->
            _menhir_run_659 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState647 ->
            _menhir_run_649 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_887 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__3_) = _menhir_stack in
                let (_endpos__2_, _2, x, _3, _1_inlined1) = (_endpos_0, (), _v, (), ()) in
                let _v = _menhir_action_074 _1_inlined1 _2 _3 _endpos__2_ _startpos__3_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__3_) = _menhir_stack in
                let (x, _3, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_v, (), _endpos, _startpos, ()) in
                let _v = _menhir_action_075 _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_inlined1_ _startpos__3_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_881 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__3_) = _menhir_stack in
                let (_endpos__2_, _2, x, _3, _1_inlined1) = (_endpos_0, (), _v, (), ()) in
                let _v = _menhir_action_098 _1_inlined1 _2 _3 _endpos__2_ _startpos__3_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__3_) = _menhir_stack in
                let (x, _3, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_v, (), _endpos, _startpos, ()) in
                let _v = _menhir_action_099 _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_inlined1_ _startpos__3_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_862 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined2) = ((), _endpos_0, (), _v, (), ()) in
                let _v = _menhir_action_076 _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), _v, (), (), _endpos, _startpos) in
                let _v = _menhir_action_077 _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_856 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined2) = ((), _endpos_0, (), _v, (), ()) in
                let _v = _menhir_action_100 _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), _v, (), (), _endpos, _startpos) in
                let _v = _menhir_action_101 _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_844 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_is_readonly, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_SEMI_COLON (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_END (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, getter) = _menhir_stack in
                let MenhirCell1_is_readonly (_menhir_stack, _menhir_s, is_readonly) = _menhir_stack in
                let (_1, _2, _2_inlined1, _5, _1_inlined1, setter, _2_inlined2) = ((), (), (), (), (), _v, ()) in
                let _v = _menhir_action_006 _1 _1_inlined1 _2 _2_inlined1 _2_inlined2 _5 getter is_readonly setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.END ->
                let MenhirCell0_SEMI_COLON (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_END (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, getter) = _menhir_stack in
                let MenhirCell1_is_readonly (_menhir_stack, _menhir_s, is_readonly) = _menhir_stack in
                let (_1, _2, _2_inlined1, _5, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, setter) = ((), (), (), (), _endpos, _startpos, (), _v) in
                let _v = _menhir_action_007 _1 _1_inlined1 _2 _2_inlined1 _5 _endpos__1_inlined1_ _startpos__1_inlined1_ getter is_readonly setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_goto_accessors : type  ttv_stack. ((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState916 ->
            _menhir_run_917 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState872 ->
            _menhir_run_873 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState818 ->
            _menhir_run_847 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_917 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_ACCESSOR (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _2_inlined1, _1_inlined1, accessors, _6) = ((), (), (), (), _v, ()) in
                let _v = _menhir_action_137 _1 _1_inlined1 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_ACCESSOR (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, accessors, _6) = ((), (), _endpos, _startpos, (), _v, ()) in
                let _v = _menhir_action_138 _1 _1_inlined1 _2 _6 _endpos__1_inlined1_ _startpos__1_inlined1_ accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_873 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _) = _menhir_stack in
                let (_1, _2, _2_inlined1, _1_inlined1, _1_inlined2, accessors, _6) = ((), (), (), (), (), _v, ()) in
                let _v = _menhir_action_139 _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _) = _menhir_stack in
                let (_1, _2, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, accessors, _6) = ((), (), (), (), _endpos, _startpos, _v, ()) in
                let _v = _menhir_action_140 _1 _1_inlined1 _1_inlined2 _2 _6 _endpos__1_inlined2_ _startpos__1_inlined2_ accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_847 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _) = _menhir_stack in
                let (_1, _2, _2_inlined1, _1_inlined1, _1_inlined2, accessors, _6) = ((), (), (), (), (), _v, ()) in
                let _v = _menhir_action_141 _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _6 accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_as_ty (_menhir_stack, _, as_ty) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, setter_arg, _, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _) = _menhir_stack in
                let (_1, _2, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, accessors, _6) = ((), (), (), (), _endpos, _startpos, _v, ()) in
                let _v = _menhir_action_142 _1 _1_inlined1 _1_inlined2 _2 _6 _endpos__1_inlined2_ _startpos__1_inlined2_ accessors as_ty func_args name params_opt setter_arg in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_839 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_is_readonly, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell0_END (_menhir_stack, _startpos__1_, _endpos__1_) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, getter) = _menhir_stack in
                let MenhirCell1_is_readonly (_menhir_stack, _menhir_s, is_readonly) = _menhir_stack in
                let (_1, _2, _2_inlined1, _5, _1_inlined1, setter) = ((), (), (), (), (), _v) in
                let _v = _menhir_action_008 _1 _1_inlined1 _2 _2_inlined1 _5 _endpos__1_ _startpos__1_ getter is_readonly setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.END ->
                let MenhirCell0_END (_menhir_stack, _startpos__1_, _endpos__1_) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, getter) = _menhir_stack in
                let MenhirCell1_is_readonly (_menhir_stack, _menhir_s, is_readonly) = _menhir_stack in
                let (_1, _2, _5, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, setter) = ((), (), (), _endpos, _startpos, (), _v) in
                let _v = _menhir_action_009 _1 _1_inlined1 _2 _5 _endpos__1_ _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ getter is_readonly setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_836 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_is_readonly as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_END (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SETTER ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.VAR ->
                    _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.UNREACHABLE ->
                    _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.TRY ->
                    _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.THROW ->
                    _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.RETURN ->
                    _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.REPEAT ->
                    _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.PRINTLN ->
                    _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.PRINT ->
                    _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.PRAGMA ->
                    _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.PASS ->
                    _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.MINUS ->
                    _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.LPAR ->
                    _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.LET ->
                    _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.IF ->
                    _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.IDENTIFIER _v_1 ->
                    _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState838
                | Tokens.FOR ->
                    _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.DEBUG ->
                    _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.CONSTANT ->
                    _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.CASE ->
                    _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.ASSERT ->
                    _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState838
                | Tokens.END ->
                    let _v_2 =
                      let _endpos__0_ = _endpos_0 in
                      _menhir_action_277 _endpos__0_
                    in
                    _menhir_run_839 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 _tok
                | _ ->
                    _eRR ())
            | Tokens.SEMI_COLON ->
                let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.SETTER ->
                    let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.WHILE ->
                        _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.VAR ->
                        _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.UNREACHABLE ->
                        _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.TRY ->
                        _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.THROW ->
                        _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.RETURN ->
                        _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.REPEAT ->
                        _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.PRINTLN ->
                        _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.PRINT ->
                        _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.PRAGMA ->
                        _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.PASS ->
                        _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.MINUS ->
                        _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.LPAR ->
                        _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.LET ->
                        _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.IF ->
                        _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.IDENTIFIER _v_5 ->
                        _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState843
                    | Tokens.FOR ->
                        _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.DEBUG ->
                        _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.CONSTANT ->
                        _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.CASE ->
                        _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.ASSERT ->
                        _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState843
                    | Tokens.END ->
                        let _v_6 =
                          let _endpos__0_ = _endpos_4 in
                          _menhir_action_277 _endpos__0_
                        in
                        _menhir_run_844 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 _tok
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_831 : type  ttv_stack. ((((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END, _menhir_box_spec) _menhir_cell1_is_readonly -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_is_readonly (_menhir_stack, _, is_readonly) = _menhir_stack in
                let MenhirCell0_END (_menhir_stack, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, setter) = _menhir_stack in
                let MenhirCell1_SETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _5, _1_inlined1, _1_inlined2, getter) = ((), (), (), (), (), _v) in
                let _v = _menhir_action_012 _1 _1_inlined1 _1_inlined2 _2 _5 _endpos__1_inlined1_ _startpos__1_inlined1_ getter is_readonly setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.END ->
                let MenhirCell1_is_readonly (_menhir_stack, _, is_readonly) = _menhir_stack in
                let MenhirCell0_END (_menhir_stack, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, setter) = _menhir_stack in
                let MenhirCell1_SETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _5, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, getter) = ((), (), (), (), _endpos, _startpos, _v) in
                let _v = _menhir_action_013 _1 _1_inlined1 _1_inlined2 _5 _endpos__1_inlined1_ _endpos__1_inlined2_ _startpos__1_inlined1_ _startpos__1_inlined2_ getter is_readonly setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_826 : type  ttv_stack. (((((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_cell1_is_readonly -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_is_readonly (_menhir_stack, _, is_readonly) = _menhir_stack in
                let MenhirCell1_SEMI_COLON (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell0_END (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, setter) = _menhir_stack in
                let MenhirCell1_SETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _2_inlined1, _5, _1_inlined1, _1_inlined2, getter) = ((), (), (), (), (), (), _v) in
                let _v = _menhir_action_010 _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _5 getter is_readonly setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.END ->
                let MenhirCell1_is_readonly (_menhir_stack, _, is_readonly) = _menhir_stack in
                let MenhirCell1_SEMI_COLON (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell0_END (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _, setter) = _menhir_stack in
                let MenhirCell1_SETTER (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1, _2, _5, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_, getter) = ((), (), (), (), (), _endpos, _startpos, _v) in
                let _v = _menhir_action_011 _1 _1_inlined1 _1_inlined2 _2 _5 _endpos__1_inlined2_ _startpos__1_inlined2_ getter is_readonly setter in
                _menhir_goto_accessors _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_820 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_maybe_empty_stmt_list (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_END (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState821, _endpos_0) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.READONLY ->
                    _menhir_run_823 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState822
                | Tokens.GETTER ->
                    let _v_1 = _menhir_action_259 () in
                    _menhir_run_824 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState822 _tok
                | _ ->
                    _eRR ())
            | Tokens.READONLY ->
                _menhir_run_823 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState821
            | Tokens.GETTER ->
                let _v_2 = _menhir_action_259 () in
                _menhir_run_829 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState821 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_823 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let _1 = () in
        let _v = _menhir_action_260 _1 in
        _menhir_goto_is_readonly _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_is_readonly : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState916 ->
            _menhir_run_834 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState872 ->
            _menhir_run_834 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState818 ->
            _menhir_run_834 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState821 ->
            _menhir_run_829 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState822 ->
            _menhir_run_824 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_834 : type  ttv_stack. ((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_is_readonly (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.GETTER ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState835
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState835
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_277 _endpos__0_
                in
                _menhir_run_836 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState835 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_829 : type  ttv_stack. ((((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_is_readonly (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.GETTER ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState830
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState830
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_277 _endpos__0_
                in
                _menhir_run_831 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_824 : type  ttv_stack. (((((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty, _menhir_box_spec) _menhir_cell1_SETTER, _menhir_box_spec) _menhir_cell1_maybe_empty_stmt_list _menhir_cell0_END, _menhir_box_spec) _menhir_cell1_SEMI_COLON as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_is_readonly (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.GETTER ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState825
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState825
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_277 _endpos__0_
                in
                _menhir_run_826 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_808 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined2) = ((), _endpos_0, (), _v, (), ()) in
                let _v = _menhir_action_078 _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), _v, (), (), _endpos, _startpos) in
                let _v = _menhir_action_079 _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_802 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined2) = ((), _endpos_0, (), _v, (), ()) in
                let _v = _menhir_action_102 _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), _v, (), (), _endpos, _startpos) in
                let _v = _menhir_action_103 _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_782 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_NORETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined2) = ((), _endpos_0, (), _v, (), ()) in
                let _v = _menhir_action_092 _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_NORETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), _v, (), (), _endpos, _startpos) in
                let _v = _menhir_action_093 _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_776 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_NORETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined2) = ((), _endpos_0, (), _v, (), ()) in
                let _v = _menhir_action_116 _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_NORETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), _v, (), (), _endpos, _startpos) in
                let _v = _menhir_action_117 _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_768 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPDEF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_NORETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined1, _1_inlined3) = ((), _endpos_0, (), _v, (), (), ()) in
                let _v = _menhir_action_094 _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPDEF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_NORETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined1, _endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) = ((), _v, (), (), _endpos, _startpos, ()) in
                let _v = _menhir_action_095 _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_762 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPDEF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_NORETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined1, _1_inlined3) = ((), _endpos_0, (), _v, (), (), ()) in
                let _v = _menhir_action_118 _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPDEF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_NORETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined1, _endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) = ((), _v, (), (), _endpos, _startpos, ()) in
                let _v = _menhir_action_119 _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_753 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPLEMENTATION (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_NORETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined1, _1_inlined3) = ((), _endpos_0, (), _v, (), (), ()) in
                let _v = _menhir_action_096 _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPLEMENTATION (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_NORETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined1, _endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) = ((), _v, (), (), _endpos, _startpos, ()) in
                let _v = _menhir_action_097 _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_747 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPLEMENTATION (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_NORETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined1, _1_inlined3) = ((), _endpos_0, (), _v, (), (), ()) in
                let _v = _menhir_action_120 _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPLEMENTATION (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_NORETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined1, _endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) = ((), _v, (), (), _endpos, _startpos, ()) in
                let _v = _menhir_action_121 _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_733 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PURE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined2) = ((), _endpos_0, (), _v, (), ()) in
                let _v = _menhir_action_080 _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PURE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), _v, (), (), _endpos, _startpos) in
                let _v = _menhir_action_081 _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_727 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PURE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined2) = ((), _endpos_0, (), _v, (), ()) in
                let _v = _menhir_action_104 _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PURE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), _v, (), (), _endpos, _startpos) in
                let _v = _menhir_action_105 _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_719 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPDEF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PURE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined1, _1_inlined3) = ((), _endpos_0, (), _v, (), (), ()) in
                let _v = _menhir_action_082 _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPDEF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PURE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined1, _endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) = ((), _v, (), (), _endpos, _startpos, ()) in
                let _v = _menhir_action_083 _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_713 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPDEF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PURE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined1, _1_inlined3) = ((), _endpos_0, (), _v, (), (), ()) in
                let _v = _menhir_action_106 _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPDEF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PURE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined1, _endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) = ((), _v, (), (), _endpos, _startpos, ()) in
                let _v = _menhir_action_107 _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_704 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPLEMENTATION (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PURE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined1, _1_inlined3) = ((), _endpos_0, (), _v, (), (), ()) in
                let _v = _menhir_action_084 _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPLEMENTATION (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PURE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined1, _endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) = ((), _v, (), (), _endpos, _startpos, ()) in
                let _v = _menhir_action_085 _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_698 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPLEMENTATION (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PURE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined1, _1_inlined3) = ((), _endpos_0, (), _v, (), (), ()) in
                let _v = _menhir_action_108 _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPLEMENTATION (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_PURE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined1, _endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) = ((), _v, (), (), _endpos, _startpos, ()) in
                let _v = _menhir_action_109 _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_688 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_READONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined2) = ((), _endpos_0, (), _v, (), ()) in
                let _v = _menhir_action_086 _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_READONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), _v, (), (), _endpos, _startpos) in
                let _v = _menhir_action_087 _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_682 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_READONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined2) = ((), _endpos_0, (), _v, (), ()) in
                let _v = _menhir_action_110 _1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_READONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), _v, (), (), _endpos, _startpos) in
                let _v = _menhir_action_111 _1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_674 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPDEF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_READONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined1, _1_inlined3) = ((), _endpos_0, (), _v, (), (), ()) in
                let _v = _menhir_action_088 _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPDEF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_READONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined1, _endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) = ((), _v, (), (), _endpos, _startpos, ()) in
                let _v = _menhir_action_089 _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_668 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPDEF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_READONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined1, _1_inlined3) = ((), _endpos_0, (), _v, (), (), ()) in
                let _v = _menhir_action_112 _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPDEF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_READONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined1, _endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) = ((), _v, (), (), _endpos, _startpos, ()) in
                let _v = _menhir_action_113 _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_659 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_recurse_limit -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPLEMENTATION (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_READONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined1, _1_inlined3) = ((), _endpos_0, (), _v, (), (), ()) in
                let _v = _menhir_action_090 _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_recurse_limit (_menhir_stack, _, recurse_limit) = _menhir_stack in
                let MenhirCell1_return_type (_menhir_stack, _, return_type) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPLEMENTATION (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_READONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined1, _endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) = ((), _v, (), (), _endpos, _startpos, ()) in
                let _v = _menhir_action_091 _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt recurse_limit return_type x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_649 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_BEGIN -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPLEMENTATION (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_READONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, x, _3, _1_inlined1, _1_inlined3) = ((), _endpos_0, (), _v, (), (), ()) in
                let _v = _menhir_action_114 _1 _1_inlined1 _1_inlined3 _2 _3 _endpos__2_ _startpos__1_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | Tokens.ACCESSOR | Tokens.CONFIG | Tokens.CONSTANT | Tokens.EOF | Tokens.FUNC | Tokens.IMPDEF | Tokens.IMPLEMENTATION | Tokens.LET | Tokens.NORETURN | Tokens.PRAGMA | Tokens.PURE | Tokens.READONLY | Tokens.TYPE | Tokens.VAR ->
                let MenhirCell1_BEGIN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_func_args (_menhir_stack, _, func_args) = _menhir_stack in
                let MenhirCell1_params_opt (_menhir_stack, _, params_opt) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
                let MenhirCell0_FUNC (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IMPLEMENTATION (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_READONLY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, x, _3, _1_inlined1, _endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3) = ((), _v, (), (), _endpos, _startpos, ()) in
                let _v = _menhir_action_115 _1 _1_inlined1 _1_inlined3 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ func_args name params_opt x in
                _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_564 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHILE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_loop_limit -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_loop_limit (_menhir_stack, _, loop_limit) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_WHILE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _4, _1_inlined1, stmt_list) = ((), _endpos_1, (), (), (), _v) in
                let _v = _menhir_action_319 _1 _1_inlined1 _2 _4 _endpos__2_ _startpos__1_ expr loop_limit stmt_list in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_loop_limit (_menhir_stack, _, loop_limit) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_WHILE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _4, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, stmt_list) = ((), (), _endpos_0, _startpos, (), _v) in
                let _v = _menhir_action_320 _1 _1_inlined1 _4 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ expr loop_limit stmt_list in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_558 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_TRY, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_list1_catcher_ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let (_1, _2, _3) = ((), (), _v) in
        let _v = _menhir_action_284 _1 _2 _3 in
        _menhir_goto_otherwise_opt _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
    
    and _menhir_goto_otherwise_opt : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_TRY, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_list1_catcher_ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_list1_catcher_ (_menhir_stack, _, c) = _menhir_stack in
                let MenhirCell1_stmt_list (_menhir_stack, _, s, _) = _menhir_stack in
                let MenhirCell1_TRY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _3, _1_inlined1, o) = ((), _endpos_0, (), (), (), _v) in
                let _v = _menhir_action_323 _1 _1_inlined1 _2 _3 _endpos__2_ _startpos__1_ c o s in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_list1_catcher_ (_menhir_stack, _, c) = _menhir_stack in
                let MenhirCell1_stmt_list (_menhir_stack, _, s, _) = _menhir_stack in
                let MenhirCell1_TRY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _3, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, o) = ((), (), _endpos, _startpos, (), _v) in
                let _v = _menhir_action_324 _1 _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ c o s in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_554 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_ty -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_ty (_menhir_stack, _, ty, _) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (_1, _4, stmt_list) = ((), (), _v) in
        let _v = _menhir_action_028 _1 _4 stmt_list ty in
        _menhir_goto_catcher _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_catcher : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHEN ->
            let _menhir_stack = MenhirCell1_catcher (_menhir_stack, _menhir_s, _v) in
            _menhir_run_546 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState562
        | Tokens.END | Tokens.OTHERWISE ->
            let x = _v in
            let _v = _menhir_action_270 x in
            _menhir_goto_list1_catcher_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_546 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState546
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState546
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState546
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState546
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.COLON ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState546, _v, _startpos_0, _endpos) in
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_COLON (_menhir_stack, _startpos, _endpos) in
                let _menhir_s = MenhirState548 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.ARROW ->
                let _v =
                  let (_endpos_name_, _startpos_name_, name) = (_endpos, _startpos_0, _v) in
                  _menhir_action_376 _endpos_name_ _startpos_name_ name
                in
                _menhir_run_552 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v MenhirState546 _tok
            | _ ->
                _eRR ())
        | Tokens.BOOLEAN ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState546
        | Tokens.BITS ->
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState546
        | Tokens.BIT ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState546
        | Tokens.ARRAY ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState546
        | _ ->
            _eRR ()
    
    and _menhir_run_552 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHEN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ARROW ->
            let _menhir_s = MenhirState553 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_goto_list1_catcher_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState562 ->
            _menhir_run_563 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState545 ->
            _menhir_run_555 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_563 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_catcher -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_catcher (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let l = _v in
        let _v = _menhir_action_271 l x in
        _menhir_goto_list1_catcher_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_555 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_TRY, ttv_result) _menhir_cell1_stmt_list as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_list1_catcher_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.OTHERWISE ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.ARROW ->
                let _menhir_s = MenhirState557 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.VAR ->
                    _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.UNREACHABLE ->
                    _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.TRY ->
                    _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.THROW ->
                    _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.RETURN ->
                    _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REPEAT ->
                    _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINTLN ->
                    _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINT ->
                    _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRAGMA ->
                    _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PASS ->
                    _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LET ->
                    _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IF ->
                    _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.FOR ->
                    _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.DEBUG ->
                    _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CONSTANT ->
                    _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CASE ->
                    _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ASSERT ->
                    _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.END ->
            let _v = _menhir_action_283 () in
            _menhir_goto_otherwise_opt _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_551 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_COLON, ttv_result) _menhir_cell1_ty -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_ty (_menhir_stack, _, ty, _) = _menhir_stack in
        let MenhirCell0_COLON (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (_1, _4, stmt_list) = ((), (), _v) in
        let _v = _menhir_action_029 _1 _4 stmt_list ty x in
        _menhir_goto_catcher _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_544 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_TRY as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_stmt_list (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.CATCH ->
            let _menhir_s = MenhirState545 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHEN ->
                _menhir_run_546 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_539 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_REPEAT as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_stmt_list (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNTIL ->
            let _menhir_s = MenhirState540 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_534 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_ELSE -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_ELSE (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, _endpos__2_, _2) = ((), _endpos, _v) in
        let _v = _menhir_action_303 _1 _2 in
        _menhir_goto_s_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
    
    and _menhir_goto_s_else : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState528 ->
            _menhir_run_536 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState532 ->
            _menhir_run_535 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_536 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_stmt_list (_menhir_stack, _, s1, _) = _menhir_stack in
                let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
                let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _3, _1_inlined1, s2) = ((), _endpos_1, (), (), (), _v) in
                let _v = _menhir_action_313 _1 _1_inlined1 _2 _3 _endpos__2_ _startpos__1_ e s1 s2 in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_stmt_list (_menhir_stack, _, s1, _) = _menhir_stack in
                let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
                let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _3, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, s2) = ((), (), _endpos_0, _startpos, (), _v) in
                let _v = _menhir_action_314 _1 _1_inlined1 _3 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ e s1 s2 in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_535 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_stmt_list (_menhir_stack, _, s1, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
        let MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_s2_, s2) = ((), (), _endpos, _v) in
        let _v = _menhir_action_301 _1 _3 _endpos_s2_ _startpos__1_ e s1 s2 in
        _menhir_goto_s_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s2_ _v _menhir_s _tok
    
    and _menhir_run_532 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_stmt_list (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ELSIF ->
            _menhir_run_529 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState532
        | Tokens.ELSE ->
            _menhir_run_533 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState532
        | Tokens.END ->
            let _v_0 =
              let _endpos__0_ = _endpos in
              _menhir_action_302 _endpos__0_
            in
            _menhir_run_535 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v_0 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_529 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState529 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_533 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_ELSE (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState533 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_528 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_stmt_list (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ELSIF ->
            _menhir_run_529 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState528
        | Tokens.ELSE ->
            _menhir_run_533 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState528
        | Tokens.END ->
            let _v_0 =
              let _endpos__0_ = _endpos in
              _menhir_action_302 _endpos__0_
            in
            _menhir_run_536 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_525 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_direction, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_loop_limit -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_loop_limit (_menhir_stack, _, limit) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
                let MenhirCell1_direction (_menhir_stack, _, dir) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
                let MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _3, body, _1_inlined1, _8) = ((), _endpos_1, (), (), _v, (), ()) in
                let _v = _menhir_action_321 _1 _1_inlined1 _2 _3 _8 _endpos__2_ _startpos__1_ body dir end_e index_name limit start_e in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_loop_limit (_menhir_stack, _, limit) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
                let MenhirCell1_direction (_menhir_stack, _, dir) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
                let MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _3, body, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, _8) = ((), (), _v, _endpos_0, _startpos, (), ()) in
                let _v = _menhir_action_322 _1 _1_inlined1 _3 _8 _endpos__1_inlined1_ _startpos__1_ _startpos__1_inlined1_ body dir end_e index_name limit start_e in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_518 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_CASE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_OF, ttv_result) _menhir_cell1_list1_case_alt_ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_list1_case_alt_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
                let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _3, _2_inlined1, _1_inlined3, otherwise_stmt, _1_inlined2) = ((), _endpos_1, (), (), (), (), _v, ()) in
                let _v = _menhir_action_317 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _2_inlined1 _3 _endpos__2_ _startpos__1_ expr otherwise_stmt in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_list1_case_alt_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
                let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _3, _2_inlined1, _endpos__1_inlined3_, _startpos__1_inlined3_, _1_inlined3, otherwise_stmt, _1_inlined2) = ((), (), (), _endpos_0, _startpos, (), _v, ()) in
                let _v = _menhir_action_318 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined3_ expr otherwise_stmt in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined3_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_514 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_pattern_list -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_pattern_list (_menhir_stack, _, pattern) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _4, _endpos_stmt_, stmt) = ((), (), _endpos, _v) in
        let _v = _menhir_action_026 _1 _4 _endpos_stmt_ _startpos__1_ pattern stmt in
        _menhir_goto_case_alt _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_case_alt : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHEN ->
            let _menhir_stack = MenhirCell1_case_alt (_menhir_stack, _menhir_s, _v) in
            _menhir_run_476 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState523
        | Tokens.END | Tokens.OTHERWISE ->
            let x = _v in
            let _v = _menhir_action_268 x in
            _menhir_goto_list1_case_alt_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_476 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState476 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MASK_LIT _v ->
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.LPAR ->
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LEQ ->
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.GEQ ->
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_041 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState041 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_053 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState053
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState053
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState053
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState053
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState053
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState053
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState053
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState053
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState053
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState053
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState053
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState053
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
            let _v = _menhir_action_289 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_pattern : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState056 ->
            _menhir_run_256 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState476 ->
            _menhir_run_182 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState040 ->
            _menhir_run_182 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState257 ->
            _menhir_run_182 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState183 ->
            _menhir_run_182 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState174 ->
            _menhir_run_182 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_256 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState257 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MASK_LIT _v ->
                _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.LPAR ->
                _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LEQ ->
                _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LBRACE ->
                _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.GEQ ->
                _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_055 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_293 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_056 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState056 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MASK_LIT _v ->
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.LPAR ->
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LEQ ->
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.GEQ ->
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_057 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState057 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_040 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState040 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MASK_LIT _v ->
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.LPAR ->
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LEQ ->
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.GEQ ->
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_132 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState132 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_144 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState144
        | Tokens.LBRACE ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v_1 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState145
            | Tokens.REAL_LIT _v_2 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState145
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
            | Tokens.MINUS ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v_5 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState145, _startpos_3, _endpos_4) in
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState146
                | Tokens.REAL_LIT _v_6 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState145, _startpos_3, _endpos_4) in
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState146
                | Tokens.RBRACE ->
                    let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_2, _endpos_desc_, _startpos_desc_, desc, _3, _endpos__4_, _4) = ((), _endpos, _startpos, _v, (), _endpos_7, ()) in
                    let _v = _menhir_action_247 _2 _3 _4 _endpos__4_ _endpos_desc_ _startpos_desc_ desc in
                    _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _startpos_desc_ _v _menhir_s _tok
                | Tokens.NOT ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState145, _startpos_3, _endpos_4) in
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState146
                | Tokens.MINUS ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState145, _startpos_3, _endpos_4) in
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState146
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState145, _startpos_3, _endpos_4) in
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState146
                | Tokens.INT_LIT _v_8 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState145, _startpos_3, _endpos_4) in
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8 MenhirState146
                | Tokens.IF ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState145, _startpos_3, _endpos_4) in
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState146
                | Tokens.IDENTIFIER _v_9 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState145, _startpos_3, _endpos_4) in
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9 MenhirState146
                | Tokens.BOOL_LIT _v_10 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState145, _startpos_3, _endpos_4) in
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10 MenhirState146
                | Tokens.BNOT ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState145, _startpos_3, _endpos_4) in
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState146
                | Tokens.BITVECTOR_LIT _v_11 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState145, _startpos_3, _endpos_4) in
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11 MenhirState146
                | Tokens.ARBITRARY ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                    let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, MenhirState145, _startpos_3, _endpos_4) in
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState146
                | _ ->
                    _eRR ())
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
            | Tokens.INT_LIT _v_12 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState145
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
            | Tokens.IDENTIFIER _v_13 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13 MenhirState145
            | Tokens.BOOL_LIT _v_14 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_14 MenhirState145
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
            | Tokens.BITVECTOR_LIT _v_15 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_15 MenhirState145
            | Tokens.ARBITRARY ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState144, _startpos_0) in
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState145
            | _ ->
                _eRR ())
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_206 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_148 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState148
        | Tokens.LBRACE ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_149 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState148
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState148
        | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.SHL | Tokens.SHR | Tokens.XOR ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_161 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_149 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState149 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_150 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState150
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState150
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (_2, _3, _endpos__4_, _4) = ((), (), _endpos_0, ()) in
            let _v = _menhir_action_202 _2 _3 _4 _endpos__4_ _endpos_desc_ _startpos_desc_ desc in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _startpos_desc_ _v _menhir_s _tok
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState150
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState150
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState150
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState150
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState150
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState150
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState150
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState150
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState150
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState150
        | _ ->
            _eRR ()
    
    and _menhir_run_155 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_EQ (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState155 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_171 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_GEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState171 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_173 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState173 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_174 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BNOT as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState174 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MASK_LIT _v ->
            _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.LPAR ->
            _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LEQ ->
            _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.GEQ ->
            _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_175 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ARBITRARY (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_COLON (_menhir_stack, _startpos, _endpos) in
            let _menhir_s = MenhirState176 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_182 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState183 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_053 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MASK_LIT _v ->
                _menhir_run_055 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.LPAR ->
                _menhir_run_056 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LEQ ->
                _menhir_run_057 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LBRACE ->
                _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_132 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_144 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.GEQ ->
                _menhir_run_171 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_173 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_175 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.ARROW | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_054 x in
            _menhir_goto_clist1_pattern_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_pattern_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState257 ->
            _menhir_run_258 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState476 ->
            _menhir_run_254 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState040 ->
            _menhir_run_254 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState174 ->
            _menhir_run_254 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState183 ->
            _menhir_run_252 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_258 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_pattern -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_pattern (_menhir_stack, _, x, _, _) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_068 _2 li x in
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos) in
            let _v = _menhir_action_292 _endpos__3_ _startpos__1_ x in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_254 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_295 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_pattern_list _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_pattern_list : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState476 ->
            _menhir_run_477 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState040 ->
            _menhir_run_263 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState174 ->
            _menhir_run_180 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_477 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHEN as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_pattern_list (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHERE ->
            let _menhir_s = MenhirState478 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            let _menhir_s = MenhirState513 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_263 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos) in
            let _v = _menhir_action_296 x in
            _menhir_goto_pattern_set _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_pattern_set : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState039 ->
            _menhir_run_265 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState217 ->
            _menhir_run_219 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState476 ->
            _menhir_run_179 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState040 ->
            _menhir_run_179 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState257 ->
            _menhir_run_179 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_179 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState183 ->
            _menhir_run_179 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState174 ->
            _menhir_run_179 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_265 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_IN -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_IN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, expr, _startpos_expr_, _) = _menhir_stack in
        let (_2, _endpos_pattern_set_, pattern_set) = ((), _endpos, _v) in
        let _v = _menhir_action_197 _2 _endpos_pattern_set_ _startpos_expr_ expr pattern_set in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_pattern_set_ _startpos_expr_ _v _menhir_s _tok
    
    and _menhir_run_219 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_IN -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_IN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, expr_pattern, _startpos_expr_pattern_, _) = _menhir_stack in
        let (_2, _endpos_pattern_set_, pattern_set) = ((), _endpos, _v) in
        let _v = _menhir_action_242 _2 _endpos_pattern_set_ _startpos_expr_pattern_ expr_pattern pattern_set in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_pattern_set_ _startpos_expr_pattern_ _v _menhir_s _tok
    
    and _menhir_run_179 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_294 _1 in
        _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_180 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BNOT, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, x, _endpos__3_) = ((), _v, _endpos) in
            let _v = _menhir_action_297 _1 _endpos__3_ _startpos__1_ x in
            _menhir_goto_pattern_set _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_252 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_pattern -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_pattern (_menhir_stack, _menhir_s, h, _startpos_h_, _) = _menhir_stack in
        let (_2, _endpos_t_, t) = ((), _endpos, _v) in
        let _v = _menhir_action_055 _2 h t in
        _menhir_goto_clist1_pattern_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _startpos_h_ _v _menhir_s _tok
    
    and _menhir_goto_list1_case_alt_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState523 ->
            _menhir_run_524 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState475 ->
            _menhir_run_515 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_524 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_case_alt -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_case_alt (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let l = _v in
        let _v = _menhir_action_269 l x in
        _menhir_goto_list1_case_alt_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_515 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_CASE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_OF as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.OTHERWISE ->
            let _menhir_stack = MenhirCell1_list1_case_alt_ (_menhir_stack, _menhir_s, _v) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.ARROW ->
                let _menhir_s = MenhirState517 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.VAR ->
                    _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.UNREACHABLE ->
                    _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.TRY ->
                    _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.THROW ->
                    _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.RETURN ->
                    _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REPEAT ->
                    _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINTLN ->
                    _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINT ->
                    _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRAGMA ->
                    _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PASS ->
                    _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LET ->
                    _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IF ->
                    _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.FOR ->
                    _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.DEBUG ->
                    _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CONSTANT ->
                    _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CASE ->
                    _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ASSERT ->
                    _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.END ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2, _3, _1_inlined1, _1_inlined2) = ((), _endpos_1, (), (), _v, ()) in
                let _v = _menhir_action_315 _1 _1_inlined1 _1_inlined2 _2 _3 _endpos__2_ _startpos__1_ expr in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.PRINTLN | Tokens.REPEAT | Tokens.RETURN | Tokens.THROW | Tokens.TRY | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
                let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _3, _1_inlined1, _1_inlined2, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), (), _v, (), _endpos, _startpos) in
                let _v = _menhir_action_316 _1 _1_inlined1 _1_inlined2 _3 _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined2_ expr in
                _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_484 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_pattern_list, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ARROW -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_ARROW (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, _2, _, _) = _menhir_stack in
        let MenhirCell1_pattern_list (_menhir_stack, _, pattern) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _4, _1_inlined1, _endpos_stmt_, stmt) = ((), (), (), _endpos, _v) in
        let _v = _menhir_action_027 _1 _1_inlined1 _2 _4 _endpos_stmt_ _startpos__1_ pattern stmt in
        _menhir_goto_case_alt _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_486 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_stmt -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_stmt (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let (_endpos_l_, l) = (_endpos, _v) in
        let _v = _menhir_action_273 l x in
        _menhir_goto_list1_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_l_ _v _menhir_s _tok
    
    and _menhir_run_652 : type  ttv_stack. (((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_ARROW (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState652 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_868 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                let _menhir_s = MenhirState870 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.COLON ->
                    _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_854 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState854) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState855
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState855
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_277 _endpos__0_
                in
                _menhir_run_856 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_652 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState854
        | _ ->
            _eRR ()
    
    and _menhir_run_814 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                let _menhir_s = MenhirState816 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.COLON ->
                    _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_800 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState800) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState801
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState801
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_277 _endpos__0_
                in
                _menhir_run_802 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_652 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState800
        | _ ->
            _eRR ()
    
    and _menhir_run_774 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState774) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState775
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState775
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_277 _endpos__0_
                in
                _menhir_run_776 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_652 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState774
        | _ ->
            _eRR ()
    
    and _menhir_run_760 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState760) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState761
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState761
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_277 _endpos__0_
                in
                _menhir_run_762 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_652 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState760
        | _ ->
            _eRR ()
    
    and _menhir_run_745 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState745) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState746
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState746
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_277 _endpos__0_
                in
                _menhir_run_747 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_652 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState745
        | _ ->
            _eRR ()
    
    and _menhir_run_725 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState725) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState726
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState726
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_277 _endpos__0_
                in
                _menhir_run_727 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_652 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState725
        | _ ->
            _eRR ()
    
    and _menhir_run_711 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState711) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState712
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState712
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_277 _endpos__0_
                in
                _menhir_run_713 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_652 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState711
        | _ ->
            _eRR ()
    
    and _menhir_run_696 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState696) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState697
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState697
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_277 _endpos__0_
                in
                _menhir_run_698 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_652 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState696
        | _ ->
            _eRR ()
    
    and _menhir_run_680 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState680) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState681
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState681
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_277 _endpos__0_
                in
                _menhir_run_682 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_652 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState680
        | _ ->
            _eRR ()
    
    and _menhir_run_666 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState666) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState667
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState667
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_277 _endpos__0_
                in
                _menhir_run_668 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_652 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState666
        | _ ->
            _eRR ()
    
    and _menhir_run_646 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_func_args (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, MenhirState646) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.IDENTIFIER _v_0 ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState647
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState647
            | Tokens.END ->
                let _v_1 =
                  let _endpos__0_ = _endpos in
                  _menhir_action_277 _endpos__0_
                in
                _menhir_run_649 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            _menhir_run_652 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState646
        | _ ->
            _eRR ()
    
    and _menhir_run_878 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState878
        | _ ->
            _eRR ()
    
    and _menhir_run_867 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState867
        | _ ->
            _eRR ()
    
    and _menhir_run_853 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState853
        | _ ->
            _eRR ()
    
    and _menhir_run_813 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState813
        | _ ->
            _eRR ()
    
    and _menhir_run_799 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState799
        | _ ->
            _eRR ()
    
    and _menhir_run_773 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState773
        | _ ->
            _eRR ()
    
    and _menhir_run_759 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState759
        | _ ->
            _eRR ()
    
    and _menhir_run_744 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState744
        | _ ->
            _eRR ()
    
    and _menhir_run_724 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState724
        | _ ->
            _eRR ()
    
    and _menhir_run_710 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState710
        | _ ->
            _eRR ()
    
    and _menhir_run_695 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState695
        | _ ->
            _eRR ()
    
    and _menhir_run_679 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState679
        | _ ->
            _eRR ()
    
    and _menhir_run_665 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState665
        | _ ->
            _eRR ()
    
    and _menhir_run_638 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_params_opt (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            _menhir_run_639 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState638
        | _ ->
            _eRR ()
    
    and _menhir_run_635 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_opt_typed_identifier -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_opt_typed_identifier (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_053 _2 h t in
        _menhir_goto_clist1_opt_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_691 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_PURE (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IMPLEMENTATION ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_IMPLEMENTATION (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.FUNC ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_FUNC (_menhir_stack, _startpos_1) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_2, _endpos) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState694
                    | Tokens.LPAR ->
                        let _v_3 = _menhir_action_285 () in
                        _menhir_run_695 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState694 _tok
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.IMPDEF ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_IMPDEF (_menhir_stack, _startpos_4) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.FUNC ->
                let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_FUNC (_menhir_stack, _startpos_5) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_6, _endpos) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState709
                    | Tokens.LPAR ->
                        let _v_7 = _menhir_action_285 () in
                        _menhir_run_710 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 MenhirState709 _tok
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.FUNC ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_FUNC (_menhir_stack, _startpos_8) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_9, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState723
                | Tokens.LPAR ->
                    let _v_10 = _menhir_action_285 () in
                    _menhir_run_724 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10 MenhirState723 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_736 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v_1 ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState737
            | Tokens.REAL_LIT _v_2 ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState737
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState737
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState737
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState737
            | Tokens.INT_LIT _v_3 ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState737
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState737
            | Tokens.IDENTIFIER _v_4 ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState737
            | Tokens.BOOL_LIT _v_5 ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState737
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState737
            | Tokens.BITVECTOR_LIT _v_6 ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState737
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState737
            | Tokens.SEMI_COLON ->
                let _v_7 = _menhir_action_030 () in
                _menhir_run_738 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_738 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
            let MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_136 _1 _endpos__2_ _startpos__1_ e x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_740 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_NORETURN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IMPLEMENTATION ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_IMPLEMENTATION (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.FUNC ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_FUNC (_menhir_stack, _startpos_1) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_2, _endpos) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState743
                    | Tokens.LPAR ->
                        let _v_3 = _menhir_action_285 () in
                        _menhir_run_744 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState743 _tok
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.IMPDEF ->
            let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_IMPDEF (_menhir_stack, _startpos_4) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.FUNC ->
                let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_FUNC (_menhir_stack, _startpos_5) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_6, _endpos) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState758
                    | Tokens.LPAR ->
                        let _v_7 = _menhir_action_285 () in
                        _menhir_run_759 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 MenhirState758 _tok
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.FUNC ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_FUNC (_menhir_stack, _startpos_8) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_9, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState772
                | Tokens.LPAR ->
                    let _v_10 = _menhir_action_285 () in
                    _menhir_run_773 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10 MenhirState772 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_785 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState785 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_572 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_573 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_796 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IMPLEMENTATION (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.FUNC ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_FUNC (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_1, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState798
                | Tokens.LPAR ->
                    let _v_2 = _menhir_action_285 () in
                    _menhir_run_799 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState798 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.ACCESSOR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_3, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState812
                | Tokens.LPAR ->
                    let _v_4 = _menhir_action_285 () in
                    _menhir_run_813 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState812 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_850 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IMPDEF (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.FUNC ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_FUNC (_menhir_stack, _startpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_1, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState852
                | Tokens.LPAR ->
                    let _v_2 = _menhir_action_285 () in
                    _menhir_run_853 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState852 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.ACCESSOR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_3, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACE ->
                    _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState866
                | Tokens.LPAR ->
                    let _v_4 = _menhir_action_285 () in
                    _menhir_run_867 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState866 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_876 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState877
            | Tokens.LPAR ->
                let _v_1 = _menhir_action_285 () in
                _menhir_run_878 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState877 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_890 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState890 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_572 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_573 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_901 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CONFIG (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState901 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_572 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_573 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_909 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_ACCESSOR (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                _menhir_run_630 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState910
            | Tokens.LPAR ->
                let _v_0 = _menhir_action_285 () in
                _menhir_run_911 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState910 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_059 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_RDIV (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState059 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_032 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_POW (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState032 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_061 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_PLUS (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState061 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_071 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_OR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState071 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_073 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState073
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState073
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState073
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState073
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_199 _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_e_ _v _menhir_s _tok
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState073
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState073
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState073
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState073
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState073
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState073
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState073
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState073
        | _ ->
            _eRR ()
    
    and _menhir_run_063 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_MUL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState063 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_065 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_MOD (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState065 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_076 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState076 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_078 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState078 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_026 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LLBRACKET (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState026 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_084 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState084 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_039 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_IN (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState039 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BNOT ->
            _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_218 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IN as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState218 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            _menhir_run_174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_090 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_IMPL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState090 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_086 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_GT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState086 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_088 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_GEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState088 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_092 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState092
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState092
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState092
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState092
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, expr, _startpos_expr_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_198 _1 _2 _endpos__1_ _startpos__1_ _startpos_expr_ expr in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_expr_ _v _menhir_s _tok
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState092
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState092
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState092
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState092
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState092
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState092
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState092
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState092
        | _ ->
            _eRR ()
    
    and _menhir_run_043 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_DOT (_menhir_stack, _menhir_s) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LBRACKET (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState044 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_045 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_2, _endpos_x_, x) = ((), _endpos, _v) in
            let _v = _menhir_action_193 _2 _endpos_x_ _startpos_e_ e x in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_e_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_067 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DIVRM (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState067 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_069 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DIV (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState069 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_080 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_COLON_COLON (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState080 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_095 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BOR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState095 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_097 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BEQ (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState097 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_099 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BAND (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState099 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_101 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState101 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_020 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_082 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_AND (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState082 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_897 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, x) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
            let (_1, _endpos__2_, _4, x_inlined1) = ((), _endpos_0, (), _v) in
            let _v = _menhir_action_127 _1 _4 _endpos__2_ _startpos__1_ name x x_inlined1 in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState897
        | _ ->
            _eRR ()
    
    and _menhir_run_893 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_EQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
            let (_1, _endpos__2_, x, _4) = ((), _endpos_0, _v, ()) in
            let _v = _menhir_action_126 _1 _4 _endpos__2_ _startpos__1_ name x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState893
        | _ ->
            _eRR ()
    
    and _menhir_run_792 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_LET, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, x) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _4, x_inlined1) = ((), _endpos_0, (), _v) in
            let _v = _menhir_action_125 _1 _4 _endpos__2_ _startpos__1_ name x x_inlined1 in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState792
        | _ ->
            _eRR ()
    
    and _menhir_run_788 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_LET, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_EQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, x, _4) = ((), _endpos_0, _v, ()) in
            let _v = _menhir_action_124 _1 _4 _endpos__2_ _startpos__1_ name x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState788
        | _ ->
            _eRR ()
    
    and _menhir_run_656 : type  ttv_stack. (((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type, _menhir_box_spec) _menhir_cell1_RECURSELIMIT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState656
        | Tokens.BEGIN ->
            let MenhirCell1_RECURSELIMIT (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_1, _2) = ((), _v) in
            let _v = _menhir_action_299 _1 _2 in
            _menhir_goto_recurse_limit _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_recurse_limit : type  ttv_stack. ((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState884 ->
            _menhir_run_885 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState859 ->
            _menhir_run_860 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState805 ->
            _menhir_run_806 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState779 ->
            _menhir_run_780 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState765 ->
            _menhir_run_766 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState750 ->
            _menhir_run_751 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState730 ->
            _menhir_run_731 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState716 ->
            _menhir_run_717 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState701 ->
            _menhir_run_702 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState685 ->
            _menhir_run_686 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState671 ->
            _menhir_run_672 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState654 ->
            _menhir_run_657 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_860 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState861
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState861
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_277 _endpos__0_
            in
            _menhir_run_862 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_806 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState807
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState807
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_277 _endpos__0_
            in
            _menhir_run_808 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_780 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState781
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState781
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_277 _endpos__0_
            in
            _menhir_run_782 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_766 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState767
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState767
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_277 _endpos__0_
            in
            _menhir_run_768 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_751 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState752
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState752
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_277 _endpos__0_
            in
            _menhir_run_753 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_731 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState732
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState732
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_277 _endpos__0_
            in
            _menhir_run_733 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_717 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState718
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState718
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_277 _endpos__0_
            in
            _menhir_run_719 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_702 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState703
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState703
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_277 _endpos__0_
            in
            _menhir_run_704 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_686 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState687
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState687
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_277 _endpos__0_
            in
            _menhir_run_688 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_672 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState673
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState673
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_277 _endpos__0_
            in
            _menhir_run_674 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_657 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args, _menhir_box_spec) _menhir_cell1_return_type as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_recurse_limit (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.IDENTIFIER _v_0 ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState658
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState658
        | Tokens.END ->
            let _v_1 =
              let _endpos__0_ = _endpos in
              _menhir_action_277 _endpos__0_
            in
            _menhir_run_659 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_597 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, x) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _4, x_inlined1) = ((), _endpos_0, (), _v) in
            let _v = _menhir_action_129 _1 _4 _endpos__2_ _startpos__1_ name x x_inlined1 in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState597
        | _ ->
            _eRR ()
    
    and _menhir_run_576 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_EQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, x, _4) = ((), _endpos_0, _v, ()) in
            let _v = _menhir_action_128 _1 _4 _endpos__2_ _startpos__1_ name x in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState576
        | _ ->
            _eRR ()
    
    and _menhir_run_541 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_REPEAT, ttv_result) _menhir_cell1_stmt_list as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.LOOPLIMIT ->
            _menhir_run_311 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState541
        | Tokens.SEMI_COLON ->
            let _v_0 = _menhir_action_274 () in
            _menhir_run_542 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_311 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LOOPLIMIT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState311 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_542 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_REPEAT, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
            let MenhirCell1_stmt_list (_menhir_stack, _, stmt_list, _) = _menhir_stack in
            let MenhirCell1_REPEAT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _3, loop_limit) = ((), _endpos, (), _v) in
            let _v = _menhir_action_348 _1 _3 _endpos__2_ _startpos__1_ expr loop_limit stmt_list in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_530 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_stmt_list, ttv_result) _menhir_cell1_ELSIF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState530) in
            let _menhir_s = MenhirState531 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState530
        | _ ->
            _eRR ()
    
    and _menhir_run_509 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_call, ttv_result) _menhir_cell1_setter_access, ttv_result) _menhir_cell1_slices as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_slices (_menhir_stack, _, desc_inlined1, _startpos_desc_inlined1_, _endpos_desc_inlined1_) = _menhir_stack in
            let MenhirCell1_setter_access (_menhir_stack, _, setter_access) = _menhir_stack in
            let MenhirCell1_call (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (_endpos__2_, _4, rhs) = (_endpos_0, (), _v) in
            let _v = _menhir_action_337 _4 _endpos__2_ _endpos_desc_ _endpos_desc_inlined1_ _startpos_desc_ _startpos_desc_inlined1_ desc desc_inlined1 rhs setter_access in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState509
        | _ ->
            _eRR ()
    
    and _menhir_run_505 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_call, ttv_result) _menhir_cell1_setter_access, ttv_result) _menhir_cell1_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_EQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_setter_access (_menhir_stack, _, setter_access) = _menhir_stack in
            let MenhirCell1_call (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (_endpos__2_, _3, rhs) = (_endpos_0, (), _v) in
            let _v = _menhir_action_336 _3 _endpos__2_ _endpos_desc_ _startpos_desc_ desc rhs setter_access in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState505
        | _ ->
            _eRR ()
    
    and _menhir_run_498 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_call, ttv_result) _menhir_cell1_DOT _menhir_cell0_LBRACKET, ttv_result) _menhir_cell1_clist2_IDENTIFIER_ _menhir_cell0_RBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_clist2_IDENTIFIER_ (_menhir_stack, _, x) = _menhir_stack in
            let MenhirCell0_LBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_DOT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_call (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (_endpos__2_, _2_inlined1, _4, rhs) = (_endpos_0, (), (), _v) in
            let _v = _menhir_action_338 _2_inlined1 _4 _endpos__2_ _endpos_desc_ _startpos_desc_ desc rhs x in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState498
        | _ ->
            _eRR ()
    
    and _menhir_run_489 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_lexpr as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_lexpr (_menhir_stack, _menhir_s, le, _startpos_le_) = _menhir_stack in
            let (_endpos__2_, _2_inlined1, e) = (_endpos_0, (), _v) in
            let _v = _menhir_action_335 _2_inlined1 _endpos__2_ _startpos_le_ e le in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState489
        | _ ->
            _eRR ()
    
    and _menhir_run_482 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_ASSERT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_ASSERT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, e) = ((), _endpos_0, _v) in
            let _v = _menhir_action_328 _1 _endpos__2_ _startpos__1_ e in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState482
        | _ ->
            _eRR ()
    
    and _menhir_run_479 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_pattern_list as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_ARROW (_menhir_stack, MenhirState479) in
            let _menhir_s = MenhirState480 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState479
        | _ ->
            _eRR ()
    
    and _menhir_run_474 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_CASE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.OF ->
            let _menhir_stack = MenhirCell1_OF (_menhir_stack, MenhirState474) in
            let _menhir_s = MenhirState475 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHEN ->
                _menhir_run_476 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState474
        | _ ->
            _eRR ()
    
    and _menhir_run_469 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_CONSTANT, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, x) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
            let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_, _endpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _4, x_inlined1) = ((), _endpos_0, (), _v) in
            let _v = _menhir_action_332 _1 _4 _endpos__1_ _endpos__2_ _startpos__1_ decl_item x x_inlined1 in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState469
        | _ ->
            _eRR ()
    
    and _menhir_run_465 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_CONSTANT, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_EQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
            let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_, _endpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, x, _4) = ((), _endpos_0, _v, ()) in
            let _v = _menhir_action_331 _1 _4 _endpos__1_ _endpos__2_ _startpos__1_ decl_item x in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState465
        | _ ->
            _eRR ()
    
    and _menhir_run_454 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_direction as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.LOOPLIMIT ->
            _menhir_run_311 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState454
        | Tokens.DO ->
            let _v_0 = _menhir_action_274 () in
            _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState454 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_455 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_direction, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_loop_limit (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.DO ->
            let _menhir_s = MenhirState456 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_450 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.TO ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_menhir_s, _1) = (MenhirState450, ()) in
            let _v = _menhir_action_146 _1 in
            _menhir_goto_direction _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.DOWNTO ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_menhir_s, _1) = (MenhirState450, ()) in
            let _v = _menhir_action_147 _1 in
            _menhir_goto_direction _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState450
        | _ ->
            _eRR ()
    
    and _menhir_goto_direction : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_direction (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v_0 ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState453
        | Tokens.REAL_LIT _v_1 ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState453
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.INT_LIT _v_2 ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState453
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.IDENTIFIER _v_3 ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState453
        | Tokens.BOOL_LIT _v_4 ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState453
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | Tokens.BITVECTOR_LIT _v_5 ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState453
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState453
        | _ ->
            _eRR ()
    
    and _menhir_run_425 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState425) in
            let _menhir_s = MenhirState426 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState425
        | _ ->
            _eRR ()
    
    and _menhir_run_420 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_LET, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, x) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
            let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _4, x_inlined1) = ((), _endpos_0, (), _v) in
            let _v = _menhir_action_330 _1 _4 _endpos__2_ _startpos__1_ decl_item x x_inlined1 in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState420
        | _ ->
            _eRR ()
    
    and _menhir_run_416 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_LET, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_EQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
            let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, x, _4) = ((), _endpos_0, _v, ()) in
            let _v = _menhir_action_329 _1 _4 _endpos__2_ _startpos__1_ decl_item x in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState416
        | _ ->
            _eRR ()
    
    and _menhir_run_395 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LLBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.RRBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RRBRACKET (_menhir_stack, MenhirState395, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LLBRACKET ->
                _menhir_run_394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState396
            | Tokens.DOT ->
                _menhir_run_397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState396
            | Tokens.COMMA | Tokens.EQ | Tokens.LBRACKET | Tokens.RPAR ->
                let _v_1 = _menhir_action_003 () in
                _menhir_run_400 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState395
        | _ ->
            _eRR ()
    
    and _menhir_run_372 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_RETURN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState372
        | Tokens.SEMI_COLON ->
            let x = _v in
            let _v = _menhir_action_282 x in
            _menhir_goto_option_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_run_367 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_THROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, e) = ((), _endpos_0, _v) in
            let _v = _menhir_action_349 _1 _endpos__2_ _startpos__1_ e in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState367
        | _ ->
            _eRR ()
    
    and _menhir_run_353 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, x) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _4, x_inlined1) = ((), _endpos_0, (), _v) in
            let _v = _menhir_action_334 _1 _4 _endpos__2_ _startpos__1_ decl_item x x_inlined1 in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState353
        | _ ->
            _eRR ()
    
    and _menhir_run_336 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_EQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, x, _4) = ((), _endpos_0, _v, ()) in
            let _v = _menhir_action_333 _1 _4 _endpos__2_ _startpos__1_ decl_item x in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState336
        | _ ->
            _eRR ()
    
    and _menhir_run_312 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState312
        | Tokens.DO | Tokens.SEMI_COLON ->
            let MenhirCell1_LOOPLIMIT (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_1, _2) = ((), _v) in
            let _v = _menhir_action_275 _1 _2 in
            _menhir_goto_loop_limit _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_loop_limit : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState541 ->
            _menhir_run_542 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState454 ->
            _menhir_run_455 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState310 ->
            _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_313 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHILE, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_loop_limit (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.DO ->
            let _menhir_s = MenhirState314 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_310 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHILE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.LOOPLIMIT ->
            _menhir_run_311 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState310
        | Tokens.DO ->
            let _v_0 = _menhir_action_274 () in
            _menhir_run_313 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState310 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_309 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_NOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState309
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_188 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_303 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_201 _endpos__3_ _startpos__1_ x in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState303) in
            let _menhir_s = MenhirState305 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState303
        | _ ->
            _eRR ()
    
    and _menhir_run_301 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.ELSIF ->
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.ELSE ->
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState301
        | _ ->
            _eRR ()
    
    and _menhir_run_136 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState136 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_140 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_ELSE (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState140 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_299 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState299) in
            let _menhir_s = MenhirState300 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState299
        | _ ->
            _eRR ()
    
    and _menhir_run_296 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BNOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState296
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState296
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState296
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState296
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_186 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_283 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SLICING as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState283
        | Tokens.COMMA | Tokens.RBRACE ->
            let MenhirCell1_SLICING (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_258 _2 e1 e2 in
            _menhir_goto_int_constraint _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_int_constraint : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_int_constraint (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState280 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_050 x in
            _menhir_goto_clist1_int_constraint_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _menhir_fail ()
    
    and _menhir_goto_clist1_int_constraint_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState020 ->
            _menhir_run_285 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState280 ->
            _menhir_run_284 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_285 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_069 x in
        _menhir_goto_constraint_kind _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_284 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_int_constraint -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_int_constraint (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_051 _2 h t in
        _menhir_goto_clist1_int_constraint_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_281 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.SLICING ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_SLICING (_menhir_stack, MenhirState281) in
            let _menhir_s = MenhirState282 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState281
        | Tokens.COMMA | Tokens.RBRACE ->
            let expr = _v in
            let _v = _menhir_action_257 expr in
            _menhir_goto_int_constraint _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_274 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState274
        | Tokens.COMMA | Tokens.RBRACKET ->
            let MenhirCell1_COLON (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_307 _2 e1 e2 in
            _menhir_goto_slice _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_slice : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_slice (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState267 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.COLON ->
                _menhir_run_035 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACKET ->
            let x = _v in
            let _v = _menhir_action_056 x in
            _menhir_goto_clist1_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _menhir_fail ()
    
    and _menhir_goto_clist1_slice_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState034 ->
            _menhir_run_276 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState267 ->
            _menhir_run_275 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_276 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACKET -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_311 x in
        _menhir_goto_slices _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_slices : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState503 ->
            _menhir_run_507 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState401 ->
            _menhir_run_402 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState259 ->
            _menhir_run_251 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState184 ->
            _menhir_run_251 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState126 ->
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState108 ->
            _menhir_run_112 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState905 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState897 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState893 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState792 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState788 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState656 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState597 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState576 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState541 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState425 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState530 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState474 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState479 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState509 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState505 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState498 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState489 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState482 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState469 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState465 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState454 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState450 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState420 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState416 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState395 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState372 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState367 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState353 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState336 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState310 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState312 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState309 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState303 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState299 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState301 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState296 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState281 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState283 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState025 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState027 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState029 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState031 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState033 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState268 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState274 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState272 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState270 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState036 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState038 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState255 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState250 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState245 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState243 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState241 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState239 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState237 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState235 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState228 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState225 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState223 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState221 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState216 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState213 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState211 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState209 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState207 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState205 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState203 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState200 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState198 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState196 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState194 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState192 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState190 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState188 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState186 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState172 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState158 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState156 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState133 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState135 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState137 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState139 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState141 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState058 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState106 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState118 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState100 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState098 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState096 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState091 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState094 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState075 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState089 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState087 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState085 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState079 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState083 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState081 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState077 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState072 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState062 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState070 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState068 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState066 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState064 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState060 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState054 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState042 ->
            _menhir_run_051 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_507 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_call, ttv_result) _menhir_cell1_setter_access as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_slices (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState508 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_402 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_access -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        let MenhirCell1_access (_menhir_stack, _, access) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (_endpos_desc_inlined1_, _startpos_desc_inlined1_, desc_inlined1) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_016 _endpos_desc_ _endpos_desc_inlined1_ _startpos_desc_ _startpos_desc_inlined1_ access desc desc_inlined1 in
        _menhir_goto_basic_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_251 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
        let (_endpos_slices_, slices) = (_endpos, _v) in
        let _v = _menhir_action_236 _endpos_slices_ _startpos_e_ e slices in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_slices_ _startpos_e_ _v _menhir_s _tok
    
    and _menhir_run_112 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v_0 ->
            let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                let _menhir_stack = MenhirCell1_slices (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v_0, _startpos_1, _endpos_2) in
                _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState113
            | Tokens.COLON ->
                let _menhir_stack = MenhirCell1_slices (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v_0, _startpos_1, _endpos_2) in
                _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState113
            | Tokens.COMMA | Tokens.RBRACE ->
                let (s, x) = (_v, _v_0) in
                let _v = _menhir_action_017 s x in
                _menhir_goto_bitfield _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_108 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState108 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RBRACE ->
            let _v = _menhir_action_358 () in
            _menhir_goto_tclist0_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _eRR ()
    
    and _menhir_goto_tclist0_bitfield_ : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_020 x in
        _menhir_goto_bitfields _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
    
    and _menhir_goto_bitfields : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState107 ->
            _menhir_run_129 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState113 ->
            _menhir_run_123 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_129 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_BITS _menhir_cell0_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RPAR -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let (_endpos__1_, _1) = (_endpos, _v) in
        let _v = _menhir_action_022 _1 in
        _menhir_goto_bitfields_opt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _tok
    
    and _menhir_goto_bitfields_opt : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_BITS _menhir_cell0_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RPAR -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_BITS (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_bitfields_opt_, bitfields_opt) = ((), _endpos, _v) in
        let _v = _menhir_action_374 _1 _endpos_bitfields_opt_ _startpos__1_ bitfields_opt x in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_bitfields_opt_ _v _menhir_s _tok
    
    and _menhir_run_123 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_slices _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell1_slices (_menhir_stack, _menhir_s, s, _, _) = _menhir_stack in
        let bf = _v in
        let _v = _menhir_action_018 bf s x in
        _menhir_goto_bitfield _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_bitfield : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACKET ->
                let _menhir_stack = MenhirCell1_bitfield (_menhir_stack, _menhir_s, _v) in
                _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState126
            | Tokens.RBRACE ->
                let (x, x_inlined1) = (_v, ()) in
                let _v = _menhir_action_364 x x_inlined1 in
                _menhir_goto_tclist1_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_363 x in
            _menhir_goto_tclist1_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_tclist1_bitfield_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState126 ->
            _menhir_run_127 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState108 ->
            _menhir_run_109 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_127 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_bitfield -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_bitfield (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_365 _2 h t in
        _menhir_goto_tclist1_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_109 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _1 = _v in
        let _v = _menhir_action_359 _1 in
        _menhir_goto_tclist0_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
    
    and _menhir_run_051 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
        let (_endpos_slices_, slices) = (_endpos, _v) in
        let _v = _menhir_action_191 _endpos_slices_ _startpos_e_ e slices in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_slices_ _startpos_e_ _v _menhir_s _tok
    
    and _menhir_run_275 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_slice -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_slice (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_057 _2 h t in
        _menhir_goto_clist1_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_272 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_PLUS_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState272
        | Tokens.COMMA | Tokens.RBRACKET ->
            let MenhirCell1_PLUS_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_308 _2 e1 e2 in
            _menhir_goto_slice _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_270 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_STAR_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState270
        | Tokens.COMMA | Tokens.RBRACKET ->
            let MenhirCell1_STAR_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_310 _2 e1 e2 in
            _menhir_goto_slice _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_268 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.STAR_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_STAR_COLON (_menhir_stack, MenhirState268) in
            let _menhir_s = MenhirState269 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.PLUS_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_PLUS_COLON (_menhir_stack, MenhirState268) in
            let _menhir_s = MenhirState271 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState268 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_COLON (_menhir_stack, _menhir_s, _startpos, _endpos) in
            let _menhir_s = MenhirState273 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState268
        | Tokens.COMMA | Tokens.RBRACKET ->
            let expr = _v in
            let _v = _menhir_action_306 expr in
            _menhir_goto_slice _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_255 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BNOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState255
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState255
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState255
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState255
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_231 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_250 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState250
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState250
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState250
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState250
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState250
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState250
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState250
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState250
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState250
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState250
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState250
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState250
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_AND (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_207 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_245 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_BAND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState245
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_BAND (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_208 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_243 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_BEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState243
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_BEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_210 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_241 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_BOR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState241
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_BOR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_209 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_239 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_COLON_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState239
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState239
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState239
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState239
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState239
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState239
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState239
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState239
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState239
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState239
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState239
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState239
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_COLON_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_230 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_237 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState237
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState237
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState237
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState237
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState237
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_DIV (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_211 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_235 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_DIVRM as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState235
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState235
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState235
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState235
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState235
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_DIVRM (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_212 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_228 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_EQ_OP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState228
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_EQ_OP (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_214 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_225 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_GEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState225
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_GEQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_217 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_223 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState223
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_GT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_216 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_221 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_IMPL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState221
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_IMPL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_218 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_216 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_LEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState216
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_LEQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_220 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_213 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_LLBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.RRBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LLBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_2, _endpos__4_, _4, e2) = ((), _endpos_0, (), _v) in
            let _v = _menhir_action_237 _2 _4 _endpos__4_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _startpos_e1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState213
        | _ ->
            _eRR ()
    
    and _menhir_run_211 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState211
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_LT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_219 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_209 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState209
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState209
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState209
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState209
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState209
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState209
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState209
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState209
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState209
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState209
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState209
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState209
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MINUS (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_222 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_207 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState207
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState207
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState207
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState207
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState207
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MOD (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_223 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_205 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_MUL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState205
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState205
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState205
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState205
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState205
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MUL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_224 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_203 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_NEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState203
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_NEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_215 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_200 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState200
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_OR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_225 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_198 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState198
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState198
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState198
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState198
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState198
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState198
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState198
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState198
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState198
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState198
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState198
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState198
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_PLUS (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_221 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_196 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_POW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState196
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_POW (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_229 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_194 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_RDIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState194
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState194
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState194
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState194
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState194
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_RDIV (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_226 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_192 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_SHL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState192
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState192
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState192
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState192
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState192
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_SHL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_227 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_190 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_SHR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState190
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState190
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState190
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState190
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState190
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_SHR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_228 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_188 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_SLICING as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState188
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let MenhirCell1_SLICING (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_2, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_288 _2 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_186 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_XOR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState186
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_XOR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_213 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_172 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_GEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState172
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let MenhirCell1_GEQ (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_expr_, expr) = ((), _endpos, _v) in
            let _v = _menhir_action_291 _1 _endpos_expr_ _startpos__1_ expr in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_158 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState158) in
            let _menhir_s = MenhirState159 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState158
        | Tokens.RBRACE | Tokens.RPAR | Tokens.SEMI_COLON ->
            let x = _v in
            let _v = _menhir_action_046 x in
            _menhir_goto_clist1_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_expr_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState347 ->
            _menhir_run_348 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState305 ->
            _menhir_run_306 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState737 ->
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState458 ->
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState385 ->
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState380 ->
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState375 ->
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState350 ->
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState344 ->
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState010 ->
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState165 ->
            _menhir_run_166 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState428 ->
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState342 ->
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_163 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState159 ->
            _menhir_run_160 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_348 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_as_ty, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE, ttv_result) _menhir_cell1_COMMA as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_clist1_expr_ (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos) in
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v_0 ->
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState350
                | Tokens.REAL_LIT _v_1 ->
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState350
                | Tokens.NOT ->
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState350
                | Tokens.MINUS ->
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState350
                | Tokens.LPAR ->
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState350
                | Tokens.INT_LIT _v_2 ->
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState350
                | Tokens.IF ->
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState350
                | Tokens.IDENTIFIER _v_3 ->
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState350
                | Tokens.BOOL_LIT _v_4 ->
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState350
                | Tokens.BNOT ->
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState350
                | Tokens.BITVECTOR_LIT _v_5 ->
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState350
                | Tokens.ARBITRARY ->
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState350
                | Tokens.RPAR ->
                    let _v_6 = _menhir_action_030 () in
                    _menhir_run_351 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 _tok
                | _ ->
                    _eRR ())
            | Tokens.SEMI_COLON ->
                let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (_2, _3, _endpos__5_, _5, params) = ((), (), _endpos, (), _v) in
                let _v = _menhir_action_158 _2 _3 _5 name params in
                _menhir_goto_elided_param_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__5_ _startpos_name_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_351 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_as_ty, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE, ttv_result) _menhir_cell1_COMMA, ttv_result) _menhir_cell1_clist1_expr_ _menhir_cell0_RBRACE _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_clist1_expr_ (_menhir_stack, _, params) = _menhir_stack in
            let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
            let (_2, x, _3, _endpos__3_inlined1_, _5) = ((), _v, (), _endpos, ()) in
            let _v = _menhir_action_159 _2 _3 _5 name params x in
            _menhir_goto_elided_param_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_inlined1_ _startpos_name_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_elided_param_call : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState904 ->
            _menhir_run_907 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState896 ->
            _menhir_run_899 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState791 ->
            _menhir_run_794 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState596 ->
            _menhir_run_599 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState468 ->
            _menhir_run_471 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState419 ->
            _menhir_run_422 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState340 ->
            _menhir_run_355 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_907 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_CONFIG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _endpos_desc_, _startpos_desc_, desc, _4) = ((), _endpos_0, _endpos, _startpos, _v, ()) in
            let _v = _menhir_action_134 _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc name ty in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_899 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
            let (_1, _endpos__2_, _endpos_desc_, _startpos_desc_, desc, _4) = ((), _endpos_0, _endpos, _startpos, _v, ()) in
            let _v = _menhir_action_132 _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc name ty in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_794 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_LET, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _endpos_desc_, _startpos_desc_, desc, _4) = ((), _endpos_0, _endpos, _startpos, _v, ()) in
            let _v = _menhir_action_131 _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc name ty in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_599 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_ignored_or_identifier (_menhir_stack, _, name) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _endpos_desc_, _startpos_desc_, desc, _4) = ((), _endpos_0, _endpos, _startpos, _v, ()) in
            let _v = _menhir_action_133 _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc name ty in
            _menhir_goto_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_471 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_CONSTANT, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
            let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_, _endpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _endpos_desc_, _startpos_desc_, desc, _4) = ((), _endpos_0, _endpos, _startpos, _v, ()) in
            let _v = _menhir_action_340 _1 _4 _endpos__1_ _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc lhs ty in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_422 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LET, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
            let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _endpos_desc_, _startpos_desc_, desc, _4) = ((), _endpos_0, _endpos, _startpos, _v, ()) in
            let _v = _menhir_action_339 _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc lhs ty in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_355 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_as_ty -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_as_ty (_menhir_stack, _, ty) = _menhir_stack in
            let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _endpos_desc_, _startpos_desc_, desc, _4) = ((), _endpos_0, _endpos, _startpos, _v, ()) in
            let _v = _menhir_action_341 _1 _4 _endpos__2_ _endpos_desc_ _startpos__1_ _startpos_desc_ desc lhs ty in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_306 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_067 _2 li x in
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos) in
            let _v = _menhir_action_204 _endpos__3_ _startpos__1_ x in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_166 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _1 = _v in
        let _v = _menhir_action_031 _1 in
        _menhir_goto_clist0_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_clist0_expr_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState737 ->
            _menhir_run_738 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState458 ->
            _menhir_run_459 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState385 ->
            _menhir_run_386 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState380 ->
            _menhir_run_381 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState375 ->
            _menhir_run_376 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState350 ->
            _menhir_run_351 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState344 ->
            _menhir_run_345 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState010 ->
            _menhir_run_297 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState165 ->
            _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_345 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_as_ty, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE, ttv_result) _menhir_cell1_RBRACE _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_RBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
            let (_2, x, _3, _endpos__3_inlined1_) = ((), _v, (), _endpos) in
            let _v = _menhir_action_157 _2 _3 name x in
            _menhir_goto_elided_param_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_inlined1_ _startpos_name_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_297 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos) in
            let _v = _menhir_action_023 name x in
            _menhir_goto_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_name_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_call : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState925 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState886 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState880 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState861 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState855 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState835 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState843 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState838 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState819 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState830 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState825 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState807 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState801 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState781 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState775 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState767 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState761 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState752 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState746 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState732 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState726 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState718 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState712 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState703 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState697 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState687 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState681 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState673 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState667 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState658 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState647 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState000 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState314 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState364 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState557 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState553 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState550 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState373 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState426 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState531 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState533 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState456 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState517 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState513 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState480 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState485 ->
            _menhir_run_491 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState476 ->
            _menhir_run_253 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState040 ->
            _menhir_run_253 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState056 ->
            _menhir_run_253 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState257 ->
            _menhir_run_253 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState174 ->
            _menhir_run_253 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState183 ->
            _menhir_run_253 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState904 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState896 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState892 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState791 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState787 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState737 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState655 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState596 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState575 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState001 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState540 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState424 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState529 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState449 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState453 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState473 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState478 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState508 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState504 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState497 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState488 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState481 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState468 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState464 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState458 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState428 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState419 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState415 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState394 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState385 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState380 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState375 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState369 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState365 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState340 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState342 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState347 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState350 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState344 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState335 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState311 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState004 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState005 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState006 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState305 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState008 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState300 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState010 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState012 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState020 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState280 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState282 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState022 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState026 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState028 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState030 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState032 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState034 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState267 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState273 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState271 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState269 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState035 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState037 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState173 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState249 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState244 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState242 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState240 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState238 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState236 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState234 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState226 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState224 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState222 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState220 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState215 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState212 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState210 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState208 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState206 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState204 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState201 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState199 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState197 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState195 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState193 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState191 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState189 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState187 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState185 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState171 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState145 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState149 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState165 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState159 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState155 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState150 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState146 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState132 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState134 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState136 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState138 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState140 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState057 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState105 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState117 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState099 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState097 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState095 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState090 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState092 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState073 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState088 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState086 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState084 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState078 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState082 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState080 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState076 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState071 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState061 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState069 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState067 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState065 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState063 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState059 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState053 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState041 ->
            _menhir_run_052 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_491 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos__2_, _startpos_call_, call) = (_endpos_0, _startpos, _v) in
            let _v = _menhir_action_327 _endpos__2_ _startpos_call_ call in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_call (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_DOT (_menhir_stack, MenhirState491) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACKET ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LBRACKET (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState494 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_442 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.IDENTIFIER _v ->
                _menhir_run_500 _menhir_stack _menhir_lexbuf _menhir_lexer _v
            | _ ->
                _eRR ())
        | Tokens.EQ | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_call (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _v_4 = _menhir_action_304 () in
            _menhir_run_503 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState491 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_500 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_DOT -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_DOT (_menhir_stack, MenhirState500) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_500 _menhir_stack _menhir_lexbuf _menhir_lexer _v
            | _ ->
                _eRR ())
        | Tokens.EQ | Tokens.LBRACKET ->
            let _v_1 = _menhir_action_304 () in
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_502 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_DOT _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let MenhirCell1_DOT (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, t) = ((), _v) in
        let _v = _menhir_action_305 _1 _endpos_desc_ _startpos_desc_ desc t in
        _menhir_goto_setter_access _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_setter_access : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState491 ->
            _menhir_run_503 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState500 ->
            _menhir_run_502 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_503 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_call as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_setter_access (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState503
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_EQ (_menhir_stack, MenhirState503) in
            let _menhir_s = MenhirState504 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_253 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_call_, _startpos_call_, call) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_235 _endpos_call_ _startpos_call_ call in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_call_ _startpos_call_ _v _menhir_s _tok
    
    and _menhir_run_052 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_call_, _startpos_call_, call) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_190 _endpos_call_ _startpos_call_ call in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_call_ _startpos_call_ _v _menhir_s _tok
    
    and _menhir_run_167 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE, ttv_result) _menhir_cell1_clist1_expr_ _menhir_cell0_RBRACE _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_clist1_expr_ (_menhir_stack, _, x) = _menhir_stack in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
            let (x_inlined1, _endpos__3_inlined1_) = (_v, _endpos) in
            let _v = _menhir_action_025 name x x_inlined1 in
            _menhir_goto_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_inlined1_ _startpos_name_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_163 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_clist1_expr_ (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos) in
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v_0 ->
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState165
                | Tokens.REAL_LIT _v_1 ->
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState165
                | Tokens.NOT ->
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState165
                | Tokens.MINUS ->
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState165
                | Tokens.LPAR ->
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState165
                | Tokens.INT_LIT _v_2 ->
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState165
                | Tokens.IF ->
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState165
                | Tokens.IDENTIFIER _v_3 ->
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState165
                | Tokens.BOOL_LIT _v_4 ->
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState165
                | Tokens.BNOT ->
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState165
                | Tokens.BITVECTOR_LIT _v_5 ->
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState165
                | Tokens.ARBITRARY ->
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState165
                | Tokens.RPAR ->
                    let _v_6 = _menhir_action_030 () in
                    _menhir_run_167 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 _tok
                | _ ->
                    _eRR ())
            | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
                let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (x, _endpos__3_) = (_v, _endpos) in
                let _v = _menhir_action_024 name x in
                _menhir_goto_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_name_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_160 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, h, _, _) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_047 _2 h t in
        _menhir_goto_clist1_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_156 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_EQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState156
        | Tokens.COMMA | Tokens.RBRACE ->
            let MenhirCell1_EQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
            let y = _v in
            let _v = _menhir_action_249 x y in
            (match (_tok : MenhirBasics.token) with
            | Tokens.COMMA ->
                let _menhir_stack = MenhirCell1_field_assign (_menhir_stack, _menhir_s, _v) in
                let _menhir_s = MenhirState153 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_s = MenhirState154 in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.EQ ->
                        _menhir_run_155 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | Tokens.RBRACE ->
                let x = _v in
                let _v = _menhir_action_048 x in
                _menhir_goto_clist1_field_assign_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _menhir_fail ())
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_field_assign_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState145 ->
            _menhir_run_169 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState342 ->
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState149 ->
            _menhir_run_161 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState153 ->
            _menhir_run_157 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_169 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_248 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_161 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_203 _endpos__3_ _endpos_desc_ _startpos_desc_ desc x in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_157 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_field_assign -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_field_assign (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_049 _2 h t in
        _menhir_goto_clist1_field_assign_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_141 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState141
        | Tokens.ARROW | Tokens.BEGIN | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_ELSE (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_1, _endpos__2_, _2) = ((), _endpos, _v) in
            let _v = _menhir_action_154 _1 _2 in
            _menhir_goto_e_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_e_else : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState301 ->
            _menhir_run_302 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState135 ->
            _menhir_run_143 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState139 ->
            _menhir_run_142 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_302 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr (_menhir_stack, _, e2, _, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e1, _, _) = _menhir_stack in
        let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_e_else_, e_else) = ((), (), _endpos, _v) in
        let _v = _menhir_action_189 _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_else_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_143 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr (_menhir_stack, _, e2, _, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e1, _, _) = _menhir_stack in
        let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_e_else_, e_else) = ((), (), _endpos, _v) in
        let _v = _menhir_action_234 _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_else_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_142 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr (_menhir_stack, _, e1, _, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, c, _, _) = _menhir_stack in
        let MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_e2_, e2) = ((), (), _endpos, _v) in
        let _v = _menhir_action_155 _1 _3 _endpos_e2_ _startpos__1_ c e1 e2 in
        _menhir_goto_e_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _v _menhir_s _tok
    
    and _menhir_run_139 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.ELSIF ->
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.ELSE ->
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState139
        | _ ->
            _eRR ()
    
    and _menhir_run_137 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSIF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState137) in
            let _menhir_s = MenhirState138 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState137
        | _ ->
            _eRR ()
    
    and _menhir_run_135 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.ELSIF ->
            _menhir_run_136 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.ELSE ->
            _menhir_run_140 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState135
        | _ ->
            _eRR ()
    
    and _menhir_run_133 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState133) in
            let _menhir_s = MenhirState134 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState133
        | _ ->
            _eRR ()
    
    and _menhir_run_118 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_ARRAY as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.RRBRACKET ->
            let _menhir_s = MenhirState118 in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RRBRACKET (_menhir_stack, _menhir_s, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.OF ->
                let _menhir_s = MenhirState120 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState118
        | _ ->
            _eRR ()
    
    and _menhir_run_106 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BITS _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.SHR ->
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.SHL ->
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.RPAR ->
            let _menhir_s = MenhirState106 in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, _menhir_s, _endpos) in
            let _menhir_s = MenhirState107 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                _menhir_run_108 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RECURSELIMIT | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.SUBTYPES | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
                let _v = _menhir_action_021 () in
                _menhir_goto_bitfields_opt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.POW ->
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.PLUS ->
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.OR ->
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.NEQ ->
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.MUL ->
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.MOD ->
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.MINUS ->
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.LT ->
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.LLBRACKET ->
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.LEQ ->
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.LBRACKET ->
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.IN ->
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.IMPL ->
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.GT ->
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.GEQ ->
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.EQ_OP ->
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.DOT ->
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.DIVRM ->
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.DIV ->
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.COLON_COLON ->
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.BOR ->
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.BEQ ->
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.BAND ->
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.AS ->
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | Tokens.AND ->
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState106
        | _ ->
            _eRR ()
    
    and _menhir_run_100 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_BAND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState100
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_BAND (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_163 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_098 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_BEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState098
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_BEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_165 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_096 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_BOR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState096
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_BOR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_164 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_094 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_EQ_OP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState094
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_EQ_OP (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_169 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_091 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_IMPL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState091
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_IMPL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_173 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_089 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_GEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState089
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_GEQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_172 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_087 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState087
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_GT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_171 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_085 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState085
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_LEQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_175 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_083 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState083
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState083
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState083
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState083
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState083
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState083
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState083
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState083
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState083
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState083
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState083
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState083
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_AND (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_162 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_081 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COLON_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState081
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState081
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState081
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState081
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState081
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState081
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState081
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState081
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState081
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState081
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState081
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState081
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_COLON_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_185 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_079 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState079
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_LT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_174 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_077 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState077
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState077
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState077
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState077
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState077
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState077
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState077
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState077
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState077
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState077
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState077
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState077
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MINUS (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_177 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_075 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_NEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState075
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_NEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_170 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_072 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState072
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_OR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_180 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_070 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState070
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState070
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState070
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState070
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState070
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_DIV (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_166 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_068 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DIVRM as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState068
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState068
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState068
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState068
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState068
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_DIVRM (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_167 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_066 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState066
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState066
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState066
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState066
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState066
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MOD (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_178 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_064 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_MUL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState064
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState064
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState064
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState064
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState064
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MUL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_179 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_062 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState062
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState062
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState062
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState062
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState062
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState062
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState062
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState062
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState062
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState062
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState062
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState062
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_PLUS (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_176 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_060 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RDIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState060
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState060
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState060
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState060
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState060
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_RDIV (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_181 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_058 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState058
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let MenhirCell1_LEQ (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_expr_, expr) = ((), _endpos, _v) in
            let _v = _menhir_action_290 _1 _endpos_expr_ _startpos__1_ expr in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_054 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState054
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState054
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState054
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState054
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_232 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_042 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_NOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState042
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState042
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState042
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState042
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_233 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_038 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SHL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState038
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState038
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState038
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState038
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState038
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_SHL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_182 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_036 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState036
        | Tokens.COMMA | Tokens.RBRACKET ->
            let MenhirCell1_COLON (_menhir_stack, _menhir_s, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (desc, e) = ((), _v) in
            let _v = _menhir_action_309 _endpos_desc_ _startpos_desc_ desc e in
            _menhir_goto_slice _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_033 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_POW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState033
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState033
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState033
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState033
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_POW (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_184 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_031 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SHR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState031
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState031
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState031
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState031
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState031
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_SHR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_183 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_029 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_XOR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState029
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState029
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState029
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState029
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState029
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState029
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState029
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState029
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState029
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState029
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState029
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState029
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_XOR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_168 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_027 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LLBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_028 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_030 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_037 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.RRBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LLBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_2, _endpos__4_, _4, e2) = ((), _endpos_0, (), _v) in
            let _v = _menhir_action_192 _2 _4 _endpos__4_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _startpos_e1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_059 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_032 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_071 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_073 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_063 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_065 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_076 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_078 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_084 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_086 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_088 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_092 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_067 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_069 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_080 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_095 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_097 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_099 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_101 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState027
        | _ ->
            _eRR ()
    
    and _menhir_run_025 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_026 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState025
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState025
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_039 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState025
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_043 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState025
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE | Tokens.XOR ->
            let MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_187 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist0_ty_ : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LPAR -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_375 _endpos__3_ _startpos__1_ x in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
    
    and _menhir_run_414 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LET as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_EQ (_menhir_stack, MenhirState414) in
            let _menhir_s = MenhirState415 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState414
        | _ ->
            _eRR ()
    
    and _menhir_run_334 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_VAR as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_EQ (_menhir_stack, MenhirState334) in
            let _menhir_s = MenhirState335 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState334
        | _ ->
            _eRR ()
    
    and _menhir_run_330 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState331 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_330 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            let (_endpos_desc_, _startpos_desc_, desc) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_038 _endpos_desc_ _startpos_desc_ desc in
            _menhir_goto_clist1_annotated_IDENTIFIER__ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_annotated_IDENTIFIER__ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState329 ->
            _menhir_run_333 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState331 ->
            _menhir_run_332 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_333 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (_2, li) = ((), _v) in
        let _v = _menhir_action_063 _2 _endpos_desc_ _startpos_desc_ desc li in
        let _menhir_stack = MenhirCell1_clist2_annotated_IDENTIFIER__ (_menhir_stack, _menhir_s, _v) in
        _menhir_run_114 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState357
    
    and _menhir_run_332 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_039 _2 _endpos_desc_ _startpos_desc_ desc t in
        _menhir_goto_clist1_annotated_IDENTIFIER__ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_859 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_655 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState859
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_298 () in
            _menhir_run_860 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState859
        | _ ->
            _eRR ()
    
    and _menhir_run_805 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_655 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState805
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_298 () in
            _menhir_run_806 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState805
        | _ ->
            _eRR ()
    
    and _menhir_run_779 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_655 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState779
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_298 () in
            _menhir_run_780 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState779
        | _ ->
            _eRR ()
    
    and _menhir_run_765 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_655 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState765
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_298 () in
            _menhir_run_766 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState765
        | _ ->
            _eRR ()
    
    and _menhir_run_750 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_NORETURN _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_655 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState750
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_298 () in
            _menhir_run_751 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState750
        | _ ->
            _eRR ()
    
    and _menhir_run_730 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_655 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState730
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_298 () in
            _menhir_run_731 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState730
        | _ ->
            _eRR ()
    
    and _menhir_run_716 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_655 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState716
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_298 () in
            _menhir_run_717 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState716
        | _ ->
            _eRR ()
    
    and _menhir_run_701 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_PURE _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_655 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState701
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_298 () in
            _menhir_run_702 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState701
        | _ ->
            _eRR ()
    
    and _menhir_run_685 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_655 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState685
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_298 () in
            _menhir_run_686 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState685
        | _ ->
            _eRR ()
    
    and _menhir_run_671 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPDEF _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_655 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState671
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_298 () in
            _menhir_run_672 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState671
        | _ ->
            _eRR ()
    
    and _menhir_run_654 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_READONLY _menhir_cell0_IMPLEMENTATION _menhir_cell0_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_return_type (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            _menhir_run_655 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState654
        | Tokens.BEGIN ->
            let _v_0 = _menhir_action_298 () in
            _menhir_run_657 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState654
        | _ ->
            _eRR ()
    
    and _menhir_run_623 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_OF as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _1 = _v in
        let _v = _menhir_action_378 _1 in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_594 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier, _menhir_box_spec) _menhir_cell1_COLON -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let MenhirCell1_COLON (_menhir_stack, _menhir_s, _, _) = _menhir_stack in
            let (_1, _2) = ((), _v) in
            let _v = _menhir_action_014 _1 _2 in
            _menhir_goto_as_ty _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | Tokens.SEMI_COLON ->
            let _1 = _v in
            let _v = _menhir_action_382 _1 in
            _menhir_goto_ty_or_collection _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_as_ty : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState914 ->
            _menhir_run_915 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState902 ->
            _menhir_run_903 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState891 ->
            _menhir_run_895 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState870 ->
            _menhir_run_871 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState816 ->
            _menhir_run_817 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState786 ->
            _menhir_run_790 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState631 ->
            _menhir_run_632 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState574 ->
            _menhir_run_595 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState583 ->
            _menhir_run_584 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState463 ->
            _menhir_run_467 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState414 ->
            _menhir_run_418 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState357 ->
            _menhir_run_358 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState334 ->
            _menhir_run_338 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState113 ->
            _menhir_run_124 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_915 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_ACCESSOR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SETTER ->
                _menhir_run_819 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState916
            | Tokens.READONLY ->
                _menhir_run_823 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState916
            | Tokens.GETTER ->
                let _v_0 = _menhir_action_259 () in
                _menhir_run_834 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState916 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_819 : type  ttv_stack. ((((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_SETTER (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.IDENTIFIER _v ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState819
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState819
        | Tokens.END ->
            let _v =
              let _endpos__0_ = _endpos in
              _menhir_action_277 _endpos__0_
            in
            _menhir_run_820 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState819 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_903 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState904 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_341 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_341 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_as_ty as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_010 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState341
        | Tokens.LBRACE ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v_1 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState341, _startpos_0) in
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState342
            | Tokens.REAL_LIT _v_2 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState341, _startpos_0) in
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState342
            | Tokens.RBRACE ->
                let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState341, _startpos_0) in
                    let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState342, _endpos_3) in
                    let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_4) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.STRING_LIT _v_5 ->
                        _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState344
                    | Tokens.REAL_LIT _v_6 ->
                        _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState344
                    | Tokens.NOT ->
                        _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState344
                    | Tokens.MINUS ->
                        _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState344
                    | Tokens.LPAR ->
                        _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState344
                    | Tokens.INT_LIT _v_7 ->
                        _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 MenhirState344
                    | Tokens.IF ->
                        _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState344
                    | Tokens.IDENTIFIER _v_8 ->
                        _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8 MenhirState344
                    | Tokens.BOOL_LIT _v_9 ->
                        _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9 MenhirState344
                    | Tokens.BNOT ->
                        _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState344
                    | Tokens.BITVECTOR_LIT _v_10 ->
                        _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10 MenhirState344
                    | Tokens.ARBITRARY ->
                        _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState344
                    | Tokens.RPAR ->
                        let _v_11 = _menhir_action_030 () in
                        _menhir_run_345 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11 _tok
                    | _ ->
                        _eRR ())
                | Tokens.SEMI_COLON ->
                    let (_2, _startpos_name_, name, _endpos__3_, _3) = ((), _startpos, _v, _endpos_3, ()) in
                    let _v = _menhir_action_156 _2 _3 name in
                    _menhir_goto_elided_param_call _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_name_ _v _menhir_s _tok
                | _ ->
                    _eRR ())
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState341, _startpos_0) in
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState341, _startpos_0) in
                _menhir_run_150 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState341, _startpos_0) in
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
            | Tokens.INT_LIT _v_12 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState341, _startpos_0) in
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState342
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState341, _startpos_0) in
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
            | Tokens.IDENTIFIER _v_13 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState341, _startpos_0) in
                _menhir_run_148 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13 MenhirState342
            | Tokens.COMMA ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState341, _startpos_0) in
                let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState342) in
                let _menhir_s = MenhirState347 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING_LIT _v ->
                    _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.ARBITRARY ->
                    _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.BOOL_LIT _v_20 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState341, _startpos_0) in
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_20 MenhirState342
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState341, _startpos_0) in
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
            | Tokens.BITVECTOR_LIT _v_21 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState341, _startpos_0) in
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v_21 MenhirState342
            | Tokens.ARBITRARY ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState341, _startpos_0) in
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState342
            | _ ->
                _eRR ())
        | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RDIV | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.XOR ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_161 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_895 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState896 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_341 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_871 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPDEF _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SETTER ->
                _menhir_run_819 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState872
            | Tokens.READONLY ->
                _menhir_run_823 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState872
            | Tokens.GETTER ->
                let _v_0 = _menhir_action_259 () in
                _menhir_run_834 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState872 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_817 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_IMPLEMENTATION _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_func_args _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SETTER ->
                _menhir_run_819 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState818
            | Tokens.READONLY ->
                _menhir_run_823 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState818
            | Tokens.GETTER ->
                let _v_0 = _menhir_action_259 () in
                _menhir_run_834 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState818 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_790 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_LET, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState791 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_341 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_632 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let x_inlined1 = _v in
        let _v = _menhir_action_280 x x_inlined1 in
        _menhir_goto_opt_typed_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_595 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR, _menhir_box_spec) _menhir_cell1_ignored_or_identifier as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState596 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_341 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_584 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let y = _v in
        let _v = _menhir_action_384 x y in
        _menhir_goto_typed_identifier _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_typed_identifier : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState641 ->
            _menhir_run_640 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState639 ->
            _menhir_run_640 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState586 ->
            _menhir_run_585 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState580 ->
            _menhir_run_585 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_640 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_typed_identifier (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState641 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_583 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_060 x in
            _menhir_goto_clist1_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_typed_identifier_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState639 ->
            _menhir_run_643 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState641 ->
            _menhir_run_642 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_643 : type  ttv_stack. ((ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_params_opt, _menhir_box_spec) _menhir_cell1_LPAR -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _1 = _v in
        let _v = _menhir_action_035 _1 in
        _menhir_goto_clist0_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
    
    and _menhir_run_642 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_typed_identifier -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_typed_identifier (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_061 _2 h t in
        _menhir_goto_clist1_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_585 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v_0 ->
                let _menhir_stack = MenhirCell1_typed_identifier (_menhir_stack, _menhir_s, _v) in
                _menhir_run_583 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState586
            | Tokens.RBRACE ->
                let (x, x_inlined1) = (_v, ()) in
                let _v = _menhir_action_367 x x_inlined1 in
                _menhir_goto_tclist1_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_366 x in
            _menhir_goto_tclist1_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_tclist1_typed_identifier_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState580 ->
            _menhir_run_588 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState586 ->
            _menhir_run_587 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_588 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_LBRACE -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (x, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_251 x in
        _menhir_goto_fields _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
    
    and _menhir_run_587 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_typed_identifier -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_typed_identifier (_menhir_stack, _menhir_s, h) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_368 _2 h t in
        _menhir_goto_tclist1_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_467 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_CONSTANT, ttv_result) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState468 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_341 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_418 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LET, ttv_result) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState419 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_341 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_358 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_clist2_annotated_IDENTIFIER__ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_clist2_annotated_IDENTIFIER__ (_menhir_stack, _, _2_inlined1) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, as_ty) = ((), _endpos, _v) in
            let _v = _menhir_action_343 _1 _2_inlined1 _endpos__2_ _startpos__1_ as_ty in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_338 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_decl_item (_menhir_stack, _, ldi) = _menhir_stack in
            let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, x) = ((), _endpos, _v) in
            let _v = _menhir_action_342 _1 _endpos__2_ _startpos__1_ ldi x in
            _menhir_goto_stmt _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_as_ty (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState340 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING_LIT _v ->
                _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_341 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.ARBITRARY ->
                _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_124 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_slices _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell1_slices (_menhir_stack, _menhir_s, s, _, _) = _menhir_stack in
        let ty = _v in
        let _v = _menhir_action_019 s ty x in
        _menhir_goto_bitfield _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_549 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_COLON as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ARROW ->
            let _menhir_s = MenhirState550 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINTLN ->
                _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_295 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_ARBITRARY _menhir_cell0_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_COLON (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_ARBITRARY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2, _endpos_ty_, ty) = ((), (), _endpos, _v) in
        let _v = _menhir_action_200 _1 _2 _endpos_ty_ _startpos__1_ ty in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_289 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
            let _menhir_s = MenhirState290 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_058 x in
            _menhir_goto_clist1_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_clist1_ty_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState018 ->
            _menhir_run_292 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState290 ->
            _menhir_run_291 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_292 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LPAR -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _1 = _v in
        let _v = _menhir_action_033 _1 in
        _menhir_goto_clist0_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v
    
    and _menhir_run_291 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_ty -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_ty (_menhir_stack, _menhir_s, h, _) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_059 _2 h t in
        _menhir_goto_clist1_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_247 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_AS -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_AS (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, expr_pattern, _startpos_expr_pattern_, _) = _menhir_stack in
        let (_2, _endpos_ty_, ty) = ((), _endpos, _v) in
        let _v = _menhir_action_240 _2 _endpos_ty_ _startpos_expr_pattern_ expr_pattern ty in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos_expr_pattern_ _v _menhir_s _tok
    
    and _menhir_run_177 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_ARBITRARY _menhir_cell0_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_COLON (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_ARBITRARY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2, _endpos_ty_, ty) = ((), (), _endpos, _v) in
        let _v = _menhir_action_245 _1 _2 _endpos_ty_ _startpos__1_ ty in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_130 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_AS -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_AS (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, expr, _startpos_expr_, _) = _menhir_stack in
        let (_2, _endpos_ty_, ty) = ((), _endpos, _v) in
        let _v = _menhir_action_195 _2 _endpos_ty_ _startpos_expr_ expr ty in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos_expr_ _v _menhir_s _tok
    
    and _menhir_run_122 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_COLON -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_COLON (_menhir_stack, _menhir_s, _, _) = _menhir_stack in
        let (_1, _2) = ((), _v) in
        let _v = _menhir_action_014 _1 _2 in
        _menhir_goto_as_ty _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_121 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_ARRAY, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RRBRACKET -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_RRBRACKET (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
        let MenhirCell1_ARRAY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2, _endpos_t_, t, _4, _5) = ((), (), _endpos, _v, (), ()) in
        let _v = _menhir_action_377 _1 _2 _4 _5 _endpos_t_ _startpos__1_ e t in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _menhir_s _tok
    
    and _menhir_run_187 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SLICING (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState187 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_189 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SHR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState189 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_191 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SHL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState191 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_193 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_RDIV (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState193 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_195 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_POW (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState195 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_197 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_PLUS (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState197 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_199 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_OR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState199 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_201 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState201
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState201
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState201
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState201
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_244 _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_e_ _v _menhir_s _tok
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState201
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState201
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState201
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState201
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState201
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState201
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState201
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState201
        | _ ->
            _eRR ()
    
    and _menhir_run_204 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_MUL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState204 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_206 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_MOD (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState206 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_208 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState208 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_210 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState210 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_212 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LLBRACKET (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState212 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_215 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState215 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_217 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_IN (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState217 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            _menhir_run_040 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BNOT ->
            _menhir_run_218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_220 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_IMPL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState220 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_222 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_GT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState222 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_224 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_GEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState224 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_226 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState226
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState226
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState226
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState226
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, expr_pattern, _startpos_expr_pattern_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_243 _1 _2 _endpos__1_ _startpos__1_ _startpos_expr_pattern_ expr_pattern in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_expr_pattern_ _v _menhir_s _tok
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState226
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState226
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState226
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState226
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState226
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState226
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState226
        | Tokens.ARBITRARY ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState226
        | _ ->
            _eRR ()
    
    and _menhir_run_229 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_DOT (_menhir_stack, _menhir_s) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LBRACKET (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState230 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_045 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_2, _endpos_x_, x) = ((), _endpos, _v) in
            let _v = _menhir_action_238 _2 _endpos_x_ _startpos_e_ e x in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_e_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_234 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DIVRM (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState234 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_236 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DIV (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState236 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_238 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_COLON_COLON (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState238 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_240 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BOR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState240 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_242 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BEQ (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState242 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_244 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BAND (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState244 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_246 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState246 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_016 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_018 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_020 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_019 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_102 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_103 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_104 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_115 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_116 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_249 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_AND (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState249 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING_LIT _v ->
            _menhir_run_002 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_003 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_007 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_009 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_012 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_013 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.ARBITRARY ->
            _menhir_run_014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_184 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.XOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_185 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.SLICING ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_187 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_189 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_191 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_193 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_195 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_197 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_199 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_201 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_204 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_206 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_208 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_210 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_212 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_215 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_217 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_220 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_222 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_224 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_226 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_229 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_234 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_236 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_238 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_240 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_242 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_244 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_246 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_249 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState184
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let (_endpos_expr_pattern_, _startpos_expr_pattern_, expr_pattern) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_287 _endpos_expr_pattern_ _startpos_expr_pattern_ expr_pattern in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_pattern_ _startpos_expr_pattern_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_024 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let (_endpos_value_, _startpos_value_, value) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_160 _endpos_value_ _startpos_value_ value in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_value_ _startpos_value_ _v _menhir_s _tok
    
    let _menhir_run_000 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState000 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    let _menhir_run_570 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_571 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState570
        | Tokens.TYPE ->
            _menhir_run_601 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState570
        | Tokens.READONLY ->
            _menhir_run_626 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState570
        | Tokens.PURE ->
            _menhir_run_691 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState570
        | Tokens.PRAGMA ->
            _menhir_run_736 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState570
        | Tokens.NORETURN ->
            _menhir_run_740 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState570
        | Tokens.LET ->
            _menhir_run_785 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState570
        | Tokens.IMPLEMENTATION ->
            _menhir_run_796 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState570
        | Tokens.IMPDEF ->
            _menhir_run_850 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState570
        | Tokens.FUNC ->
            _menhir_run_876 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState570
        | Tokens.CONSTANT ->
            _menhir_run_890 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState570
        | Tokens.CONFIG ->
            _menhir_run_901 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState570
        | Tokens.ACCESSOR ->
            _menhir_run_909 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState570
        | Tokens.EOF ->
            let _v = _menhir_action_266 () in
            _menhir_run_921 _menhir_stack _v
        | _ ->
            _eRR ()
    
    let _menhir_run_925 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_stmts =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState925 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_001 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_315 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_360 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_364 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_365 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_369 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_373 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINTLN ->
            _menhir_run_374 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_379 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_384 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_388 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_391 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_412 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_424 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_427 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_447 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_462 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
  end
  
  let stmts =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_stmts v = _menhir_run_925 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let spec =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_spec v = _menhir_run_570 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let opn =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_opn v = _menhir_run_000 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
end
